@@ -67,41 +67,39 @@ protected:
     virtual void hideEvent(QHideEvent *event);
 
 private:
-    QVBoxLayout *mainLayout;
+    QVBoxLayout *m_mainLayout;
 
-    QLabel *helpMessage1Label;
+    QLabel *m_help1Label;
 
-    QHBoxLayout *idLayout;
-    QLabel *userIDIconLabel;
-    QLabel *userIdLabel;
-    QLineEdit *userIdLineEdit;
-
-    QPushButton *getVerifierButton;
+    QHBoxLayout *m_idLayout;
+    QLabel *m_userIdIconLabel;
+    QLabel *m_userIdLabel;
+    QLineEdit *m_userIdLineEdit;
+    QPushButton *m_getVerifierButton;
 
     QFrame *separatorLine;
 
-    QLabel *helpMessage2Label;
+    QLabel *m_help2Label;
 
-    QHBoxLayout *verifierLayout;
-    QLabel *verifierIconLabel;
-    QLabel *verifierLabel;
-    QLineEdit *verifierLineEdit;
-
-    QPushButton *authorizeApplicationButton;
+    QHBoxLayout *m_verifierLayout;
+    QLabel *m_verifierIconLabel;
+    QLabel *m_verifierLabel;
+    QLineEdit *m_verifierLineEdit;
+    QPushButton *m_authorizeButton;
 
 
-    QLabel *errorsLabel;
-    QLabel *authorizationStatusLabel;
+    QLabel *m_errorsLabel;
+    QLabel *m_authorizationStatusLabel;
 
-    QLabel *unlockExplanationLabel;
-    QPushButton *unlockButton;
+    QLabel *m_unlockExplanationLabel;
+    QPushButton *m_unlockButton;
 
-    QHBoxLayout *buttonsLayout;
-    QPushButton *saveButton;
-    QPushButton *cancelButton;
+    QHBoxLayout *m_buttonsLayout;
+    QPushButton *m_saveButton;
+    QPushButton *m_cancelButton;
 
 
-    PumpController *pController;
+    PumpController *m_pumpController;
 };
 
 #endif // ACCOUNT_H
