@@ -23,58 +23,57 @@
 ASActivity::ASActivity(QVariantMap activityMap, QString userId,
                        QObject *parent) : QObject(parent)
 {
-    this->id = activityMap.value("id").toString();
-
-    this->ownUserId = userId;
+    m_id = activityMap.value("id").toString();
+    m_ownUserId = userId;
 
     // Get the author of the _activity_ (not the object)
-    this->asAuthor = new ASPerson(activityMap.value("actor").toMap(), this);
+    m_author = new ASPerson(activityMap.value("actor").toMap(), this);
 
     // Get the object included with the activity: the post itself, or whatever
-    this->asObject = new ASObject(activityMap.value("object").toMap(), this);
+    m_object = new ASObject(activityMap.value("object").toMap(), this);
 
     // If the object is a person, as in an activity where someone adds someone else
-    if (asObject->getType() == "person")
+    if (m_object->getType() == QStringLiteral("person"))
     {
-        this->asPersonObject = new ASPerson(activityMap.value("object").toMap(), this);
+        m_personObject = new ASPerson(activityMap.value("object").toMap(), this);
     }
     else
     {
         // Otherwise, at least initialize empty, but valid
-        this->asPersonObject = new ASPerson(QVariantMap(), this);
+        m_personObject = new ASPerson(QVariantMap(), this);
     }
 
     // Get possible "target"
-    this->asTarget = new ASObject(activityMap.value("target").toMap(), this);
+    m_target = new ASObject(activityMap.value("target").toMap(), this);
 
     // FIXME: add bools hasAuthor, hasObject and hasTarget, maybe?
 
 
     // Activity verb: post, share...
-    verb = activityMap.value("verb").toString();
+    m_verb = activityMap.value("verb").toString();
 
-    if (verb == "share")
+    if (m_verb == QStringLiteral("share"))
     {
-        shared = true;
-        sharedByName = asAuthor->getNameWithFallback();
-        sharedById = asAuthor->getId();
-        sharedByAvatar = asAuthor->getAvatar();
+        m_shared = true;
+        m_sharedByName = m_author->getNameWithFallback();
+        m_sharedById = m_author->getId();
+        m_sharedByAvatar = m_author->getAvatarUrl();
     }
     else
     {
-        shared = false;
+        m_shared = false;
     }
 
 
     // Timestamps
-    createdAt = activityMap.value("published").toString();
-    updatedAt = activityMap.value("updated").toString();
+    m_createdAt = activityMap.value("published").toString();
+    m_updatedAt = activityMap.value("updated").toString();
 
     // Software used to generate the activity: webUI, a client, a service...
-    generator = activityMap.value("generator").toMap().value("displayName").toString();
+    m_generator = activityMap.value("generator").toMap().value("displayName").toString();
 
     // Content of the activity, usually a description like "User followed someone"
-    content = activityMap.value("content").toString();
+    m_content = activityMap.value("content").toString();
 
 
     // Audience: To
@@ -84,15 +83,17 @@ ASActivity::ASActivity(QVariantMap activityMap, QString userId,
         aToMap = toVariant.toMap();
 
         QString toId = aToMap.value("id").toString();
-        if (toId == "http://activityschema.org/collection/public")
+        if (toId == QStringLiteral("http://activityschema.org/collection/public"))
         {
-            recipientsToString += "<b>" + tr("Public") + "</b>, ";
+            m_recipientsToString += QStringLiteral("<b>")
+                                  + tr("Public")
+                                  + QStringLiteral("</b>, ");
         }
         else
         {
             QString displayName = aToMap.value("displayName").toString().trimmed();
             // If name's empty, and ID is from a person
-            if (displayName.isEmpty() && toId.startsWith("acct:"))
+            if (displayName.isEmpty() && toId.startsWith(QStringLiteral("acct:")))
             {
                 displayName = "&lt;" + ASPerson::cleanupId(toId) + "&gt;";
             }
@@ -106,20 +107,20 @@ ASActivity::ASActivity(QVariantMap activityMap, QString userId,
 
             if (!displayName.isEmpty())
             {
-                if (ASPerson::cleanupId(toId) == this->ownUserId)
+                if (ASPerson::cleanupId(toId) == m_ownUserId)
                 {
                     displayName = "<b><big>" + displayName + "</big></b>";
                 }
 
-                recipientsToString += "<a href=\""
+                m_recipientsToString += "<a href=\""
                                       + aToMap.value("url").toString() + "\">"
                                       + displayName + "</a>, ";
             }
 
-            recipientsIdList.append(ASPerson::cleanupId(toId));
+            m_recipientsIdList.append(ASPerson::cleanupId(toId));
         }
     }
-    recipientsToString.remove(-2, 2); // remove last comma and space
+    m_recipientsToString.remove(-2, 2); // remove last comma and space
 
 
     // and Cc
@@ -129,9 +130,9 @@ ASActivity::ASActivity(QVariantMap activityMap, QString userId,
         aCcMap = ccVariant.toMap();
 
         QString ccId = aCcMap.value("id").toString();
-        if (ccId == "http://activityschema.org/collection/public")
+        if (ccId == QStringLiteral("http://activityschema.org/collection/public"))
         {
-            recipientsCcString += "<b>" + tr("Public") + "</b>, ";
+            m_recipientsCcString += "<b>" + tr("Public") + "</b>, ";
         }
         else
         {
@@ -151,30 +152,30 @@ ASActivity::ASActivity(QVariantMap activityMap, QString userId,
 
             if (!displayName.isEmpty())
             {
-                if (ASPerson::cleanupId(ccId) == this->ownUserId)
+                if (ASPerson::cleanupId(ccId) == m_ownUserId)
                 {
                     displayName = "<b><i><big>" + displayName + "</big></i></b>";
                 }
 
-                recipientsCcString += "<a href=\""
+                m_recipientsCcString += "<a href=\""
                                       + aCcMap.value("url").toString() + "\">"
                                       + displayName + "</a>, ";
             }
 
-            recipientsIdList.append(ASPerson::cleanupId(ccId));
+            m_recipientsIdList.append(ASPerson::cleanupId(ccId));
         }
     }
-    recipientsCcString.remove(-2, 2);
+    m_recipientsCcString.remove(-2, 2);
 
 
-    qDebug() << "ASActivity created" << this->id;
+    qDebug() << "ASActivity created" << m_id;
 }
 
 
 
 ASActivity::~ASActivity()
 {
-    qDebug() << "ASActivity destroyed" << this->id;
+    qDebug() << "ASActivity destroyed" << m_id;
 }
 
 
@@ -183,89 +184,89 @@ ASActivity::~ASActivity()
 
 ASPerson *ASActivity::author()
 {
-    return this->asAuthor;
+    return m_author;
 }
 
 ASObject *ASActivity::object()
 {
-    return this->asObject;
+    return m_object;
 }
 
 ASObject *ASActivity::target()
 {
-    return this->asTarget;
+    return m_target;
 }
 
 ASPerson *ASActivity::personObject()
 {
-    return this->asPersonObject;
+    return m_personObject;
 }
 
 
 QString ASActivity::getId()
 {
-    return this->id;
+    return m_id;
 }
 
 QString ASActivity::getVerb()
 {
-    return this->verb;
+    return m_verb;
 }
 
 QString ASActivity::getGenerator()
 {
-    return this->generator;
+    return m_generator;
 }
 
 QString ASActivity::getCreatedAt()
 {
-    return this->createdAt;
+    return m_createdAt;
 }
 
 QString ASActivity::getUpdatedAt()
 {
-    return this->updatedAt;
+    return m_updatedAt;
 }
 
 QString ASActivity::getContent()
 {
-    return this->content;
+    return m_content;
 }
 
 QString ASActivity::getToString()
 {
-    return this->recipientsToString;
+    return m_recipientsToString;
 }
 
 QString ASActivity::getCCString()
 {
-    return this->recipientsCcString;
+    return m_recipientsCcString;
 }
 
 QStringList ASActivity::getRecipientsIdList()
 {
-    return this->recipientsIdList;
+    return m_recipientsIdList;
 }
 
 
 bool ASActivity::isShared()
 {
-    return this->shared;
+    return m_shared;
 }
 
 QString ASActivity::getSharedByName()
 {
-    return this->sharedByName;
+    return m_sharedByName;
 }
 
 QString ASActivity::getSharedById()
 {
-    return this->sharedById;
+    return m_sharedById;
 }
 
 QString ASActivity::getSharedByAvatar()
 {
-    return this->sharedByAvatar;
+    return m_sharedByAvatar;
 }
 
 
@@ -279,11 +280,11 @@ QString ASActivity::generateTooltip()
 
 
     // Content
-    QString activityObjectContent = this->asObject->getContent();
+    QString activityObjectContent = m_object->getContent();
 
-    if (this->asObject->getDeletedTime().isEmpty())
+    if (m_object->getDeletedTime().isEmpty())
     {
-        QString objectType = this->asObject->getType();
+        QString objectType = m_object->getType();
         if (ASObject::canDisplayObject(objectType)) // False also for empty type
         {
             if (!activityObjectContent.startsWith("<p"))
@@ -299,17 +300,15 @@ QString ASActivity::generateTooltip()
     }
     else
     {
-        activityObjectContent.prepend("["
-                                      + this->asObject->getDeletedOnString()
-                                      + "]");
+        activityObjectContent.prepend("[" + m_object->getDeletedOnString() + "]");
     }
 
 
     if (!activityObjectContent.isEmpty())
     {
         // Object's author name and ID
-        QString activityObjectAuthorName = this->asObject->author()->getNameWithFallback();
-        QString activityObjectAuthorId = this->asObject->author()->getId();
+        QString activityObjectAuthorName = m_object->author()->getNameWithFallback();
+        QString activityObjectAuthorId = m_object->author()->getId();
 
         // If there's a name and/or an ID, show them
         if (!activityObjectAuthorName.isEmpty())
@@ -320,7 +319,7 @@ QString ASActivity::generateTooltip()
         }
 
         // Title, only if there's content, too; redundant otherwise
-        QString activityObjectTitle = this->asObject->getTitle();
+        QString activityObjectTitle = m_object->getTitle();
         if (!activityObjectTitle.isEmpty())
         {
             activityTooltip.append("<b><u>"
@@ -332,21 +331,21 @@ QString ASActivity::generateTooltip()
         activityTooltip.append(activityObjectContent + "<br>");
 
         // Object ID, might be interesting to show if it's a person
-        if (this->asObject->getType() == "person")
+        if (m_object->getType() == QStringLiteral("person"))
         {
             activityTooltip.append("<br><i>"
-                                   + this->asObject->getId()
-                                   + "</i><br><br>");
+                                   + m_object->getId()
+                                   + "</i><br /><br />");
         }
     }
 
 
     // Target info
-    QString activityTargetName = this->asTarget->getTitle();
-    QString activityTargetUrl = this->asTarget->getUrl();
+    QString activityTargetName = m_target->getTitle();
+    QString activityTargetUrl = m_target->getUrl();
     if (activityTargetUrl.isEmpty())
     {
-        activityTargetUrl = this->asTarget->getId();
+        activityTargetUrl = m_target->getId();
     }
     if (!activityTargetUrl.isEmpty())
     {
@@ -365,7 +364,7 @@ QString ASActivity::generateTooltip()
 
         // Show type of target object
         activityTooltip.append("<br>"
-                               + ASObject::getTranslatedType(asTarget->getType()));
+                               + ASObject::getTranslatedType(m_target->getType()));
     }
 
 
@@ -403,11 +402,11 @@ QString ASActivity::generateSnippet(int charLimit)
     QString snippet;
 
 
-    QString authorName = this->asObject->author()->getNameWithFallback();
+    QString authorName = m_object->author()->getNameWithFallback();
     // If author name IS empty, probably means the author of the activity is the
     // author of the object (like posting a comment), so this wouldn't be useful
-    if (this->asObject->author()->getId() != this->author()->getId()
-        && !authorName.isEmpty())
+    if (m_object->author()->getId() != this->author()->getId()
+     && !authorName.isEmpty())
     {
         /*
          * For some reason, when creating a structure like:
@@ -423,7 +422,7 @@ QString ASActivity::generateSnippet(int charLimit)
                        + tr("%1 by %2",
                             "1=kind of object: note, comment, etc; "
                             "2=author's name")
-                         .arg(ASObject::getTranslatedType(this->asObject->getType()))
+                         .arg(ASObject::getTranslatedType(m_object->getType()))
                          .arg("</i></small>"
                               "<b><small><i>"
                               + authorName
@@ -432,13 +431,13 @@ QString ASActivity::generateSnippet(int charLimit)
     }
 
 
-    QString objectContent = this->asObject->getContent();
+    QString objectContent = m_object->getContent();
     if (!objectContent.isEmpty())
     {
         /*   //// Disabled: Showing the title is always redundant
              //// considering how the Pump.io core generates the
              //// activities descriptions.
-        QString objectTitle = this->asObject->getTitle();
+        QString objectTitle = m_object->getTitle();
         if (!objectTitle.isEmpty())
         {
             snippet.append("<b><u>" + objectTitle + "</u></b><br>");
@@ -466,11 +465,11 @@ QString ASActivity::generateSnippet(int charLimit)
 
 void ASActivity::setFilterMatches(QVariantMap newFilterMatches)
 {
-    this->filterMatches = newFilterMatches;
+    m_filterMatches = newFilterMatches;
 }
 
 
 QVariantMap ASActivity::getFilterMatches()
 {
-    return this->filterMatches;
+    return m_filterMatches;
 }
