@@ -80,31 +80,31 @@ public slots:
 
 
 private:
-    ASPerson *asAuthor;
-    ASObject *asObject;
-    ASObject *asTarget;
-    ASPerson *asPersonObject;
+    ASPerson *m_author;
+    ASObject *m_object;
+    ASObject *m_target;
+    ASPerson *m_personObject;
 
-    QString id;
-    QString verb;
-    QString generator;
-    QString createdAt;
-    QString updatedAt;
-    QString content;
+    QString m_id;
+    QString m_verb;
+    QString m_generator;
+    QString m_createdAt;
+    QString m_updatedAt;
+    QString m_content;
 
-    QString recipientsToString;
-    QString recipientsCcString;
+    QString m_recipientsToString;
+    QString m_recipientsCcString;
 
-    QStringList recipientsIdList;
+    QStringList m_recipientsIdList;
 
-    QString ownUserId;
+    QString m_ownUserId;
 
-    bool shared;
-    QString sharedByName;
-    QString sharedById;
-    QString sharedByAvatar;
+    bool m_shared;
+    QString m_sharedByName;
+    QString m_sharedById;
+    QString m_sharedByAvatar;
 
-    QVariantMap filterMatches;
+    QVariantMap m_filterMatches;
 };
 
 #endif // ASACTIVITY_H
