@@ -23,33 +23,35 @@
 ASObject::ASObject(QVariantMap objectMap,
                    QObject *parent) : QObject(parent)
 {
-    this->originalObjectMap = objectMap;
+    m_originalObjectMap = objectMap;
 
     /// Meta information
-    id = ASPerson::cleanupId(objectMap.value("id").toString());
+    m_id = ASPerson::cleanupId(objectMap.value("id").toString());
 
-    type = objectMap.value("objectType").toString();
-    url = objectMap.value("url").toString();
-    createdAt = objectMap.value("published").toString();
-    updatedAt = objectMap.value("updated").toString();
+    m_type = objectMap.value("objectType").toString();
+    m_url = objectMap.value("url").toString();
+    m_createdAt = objectMap.value("published").toString();
+    m_updatedAt = objectMap.value("updated").toString();
 
     // FIXME: still missing some fields...
     QVariantMap locationMap = objectMap.value("location").toMap();
-    locationName = locationMap.value("displayName").toString();
-    locationFormatted = locationMap.value("address").toMap().value("formatted").toString();
-    locationCountry = locationMap.value("address").toMap().value("country").toString();
+    m_locationName = locationMap.value("displayName").toString();
+    m_locationFormatted = locationMap.value("address").toMap()
+                                     .value("formatted").toString();
+    m_locationCountry = locationMap.value("address").toMap()
+                                   .value("country").toString();
 
 
     // Author
-    this->asAuthor = new ASPerson(objectMap.value("author").toMap(), this);
+    m_author = new ASPerson(objectMap.value("author").toMap(), this);
 
     // This will hold the date when the object was deleted, or empty if it wasn't
-    deleted = objectMap.value("deleted").toString();
+    m_deleted = objectMap.value("deleted").toString();
 
-    liked = objectMap.value("liked").toString();
+    m_liked = objectMap.value("liked").toBool();
 
     // The object to which this one replies, if any (note to which a comment replies, etc)
-    inReplyToMap = objectMap.value("inReplyTo").toMap();
+    m_inReplyToMap = objectMap.value("inReplyTo").toMap();
 
 
     ///
@@ -57,194 +59,192 @@ ASObject::ASObject(QVariantMap objectMap,
     ///
 
 
-    if (type == "image")
+    if (m_type == QStringLiteral("image"))
     {
         /* Get the "small" version.
          * See if there's a proxy URL for the image first
          * (for private images on remote servers)
          */
         qDebug() << "Trying Proxyed thumbnail image";
-        smallImageUrl = objectMap.value("image").toMap()
-                                 .value("pump_io").toMap()
-                                 .value("proxyURL").toString();
+        m_smallImageUrl = objectMap.value("image").toMap()
+                                   .value("pump_io").toMap()
+                                   .value("proxyURL").toString();
 
         // And if that's empty, use regular image->url
-        if (smallImageUrl.isEmpty())
+        if (m_smallImageUrl.isEmpty())
         {
             qDebug() << "Trying direct thumbnail image";
-            smallImageUrl = objectMap.value("image").toMap()
-                                     .value("url").toString();
+            m_smallImageUrl = objectMap.value("image").toMap()
+                                       .value("url").toString();
         }
 
 
         // Same for the full size image
-        imageUrl = objectMap.value("fullImage").toMap()
-                            .value("pump_io").toMap()
-                            .value("proxyURL").toString();
+        m_imageUrl = objectMap.value("fullImage").toMap()
+                              .value("pump_io").toMap()
+                              .value("proxyURL").toString();
         qDebug() << "Trying Proxyed fullImage";
 
         // If that's empty, use regular fullImage->url field
-        if (imageUrl.isEmpty())
+        if (m_imageUrl.isEmpty())
         {
             qDebug() << "Trying direct fullImage";
-            imageUrl = objectMap.value("fullImage").toMap()
-                                .value("url").toString();
+            m_imageUrl = objectMap.value("fullImage").toMap()
+                                  .value("url").toString();
         }
 
-        imageWidth = objectMap.value("fullImage").toMap()
-                              .value("width").toInt();
-        imageHeight = objectMap.value("fullImage").toMap()
-                               .value("height").toInt();
+        m_imageWidth = objectMap.value("fullImage").toMap()
+                                .value("width").toInt();
+        m_imageHeight = objectMap.value("fullImage").toMap()
+                                 .value("height").toInt();
 
         // If it's STILL empty, use the thumbnail also as full image
-        if (imageUrl.isEmpty())
+        if (m_imageUrl.isEmpty())
         {
-            imageUrl = smallImageUrl;
-            imageWidth = objectMap.value("image").toMap()
-                                  .value("width").toInt();
-            imageHeight = objectMap.value("image").toMap()
-                                   .value("height").toInt();
+            m_imageUrl = m_smallImageUrl;
+            m_imageWidth = objectMap.value("image").toMap()
+                                    .value("width").toInt();
+            m_imageHeight = objectMap.value("image").toMap()
+                                     .value("height").toInt();
         }        
 
         // And if there's no small image for some reason, use the full one as thumbnail
-        if (smallImageUrl.isEmpty())
+        if (m_smallImageUrl.isEmpty())
         {
-            smallImageUrl = imageUrl;
+            m_smallImageUrl = m_imageUrl;
         }
 
-        qDebug() << "postImage:" << imageUrl << "> Small:" << smallImageUrl;
+        qDebug() << "postImage:" << m_imageUrl << "> Small:" << m_smallImageUrl;
 
         // To have a filename with extension, even when downloading from proxyURL's
-        attachmentPureUrl = objectMap.value("fullImage").toMap()
-                                     .value("url").toString();
-        if (attachmentPureUrl.isEmpty())
+        m_attachmentPureUrl = objectMap.value("fullImage").toMap()
+                                       .value("url").toString();
+        if (m_attachmentPureUrl.isEmpty())
         {
-            attachmentPureUrl = objectMap.value("image").toMap()
-                                         .value("url").toString();
+            m_attachmentPureUrl = objectMap.value("image").toMap()
+                                           .value("url").toString();
         }
     }
 
 
     // Get audio file URL
-    if (type == "audio")
+    if (m_type == QStringLiteral("audio"))
     {
         // To have a filename with extension, even when downloading from proxyURL's
-        attachmentPureUrl = objectMap.value("stream").toMap().value("url").toString();
+        m_attachmentPureUrl = objectMap.value("stream").toMap()
+                                       .value("url").toString();
 
-        audioUrl = objectMap.value("stream").toMap()
-                            .value("pump_io").toMap()
-                            .value("proxyURL").toString();
-        if (audioUrl.isEmpty())
+        m_audioUrl = objectMap.value("stream").toMap()
+                              .value("pump_io").toMap()
+                              .value("proxyURL").toString();
+        if (m_audioUrl.isEmpty())
         {
             qDebug() << "No proxyed link to audio, fetching regular link";
-            audioUrl = attachmentPureUrl;
+            m_audioUrl = m_attachmentPureUrl;
         }
     }
 
     // Get video file URL
-    if (type == "video")
+    if (m_type == QStringLiteral("video"))
     {
         // To have a filename with extension, even when downloading from proxyURL's
-        attachmentPureUrl = objectMap.value("stream").toMap().value("url").toString();
+        m_attachmentPureUrl = objectMap.value("stream").toMap()
+                                       .value("url").toString();
 
-        videoUrl = objectMap.value("stream").toMap()
-                            .value("pump_io").toMap()
-                            .value("proxyURL").toString();
-        if (videoUrl.isEmpty())
+        m_videoUrl = objectMap.value("stream").toMap()
+                              .value("pump_io").toMap()
+                              .value("proxyURL").toString();
+        if (m_videoUrl.isEmpty())
         {
             qDebug() << "No proxyed link to video, fetching regular link";
-            videoUrl = attachmentPureUrl;
+            m_videoUrl = m_attachmentPureUrl;
         }
     }
 
     // Get general file URL
-    if (type == "file")
+    if (m_type == QStringLiteral("file"))
     {
         // To have a filename with extension, even when downloading from proxyURL's
-        attachmentPureUrl = objectMap.value("fileUrl").toString();
+        m_attachmentPureUrl = objectMap.value("fileUrl").toString();
 
         // FIXME: there are no proxyURL for misc files ATM; not my fault though =)
-        fileUrl = objectMap.value("fileUrl").toMap()
-                           .value("pump_io").toMap()
-                           .value("proxyURL").toString();
-        if (fileUrl.isEmpty())
+        m_fileUrl = objectMap.value("fileUrl").toMap()
+                             .value("pump_io").toMap()
+                             .value("proxyURL").toString();
+        if (m_fileUrl.isEmpty())
         {
             qDebug() << "No proxyed link to general file, fetching regular link";
-            fileUrl = attachmentPureUrl;
+            m_fileUrl = m_attachmentPureUrl;
         }
 
-        mimeType = objectMap.value("mimeType").toString();
-        qDebug() << "file mimeType:" << mimeType;
+        m_mimeType = objectMap.value("mimeType").toString();
+        qDebug() << "File mimeType:" << m_mimeType;
     }
 
 
     // If it's a group, get member count, etc.
-    if (type == "group")
+    if (m_type == QStringLiteral("group"))
     {
-        memberCount = objectMap.value("members").toMap()
-                               .value("totalItems").toInt();
-        memberUrl = objectMap.value("members").toMap()
-                             .value("url").toString();
+        m_memberCount = objectMap.value("members").toMap()
+                                 .value("totalItems").toInt();
+        m_memberUrl = objectMap.value("members").toMap()
+                               .value("url").toString();
     }
 
 
 
     // Title can be in non-image posts, too!
-    title = objectMap.value("displayName").toString().trimmed();
-    summary = objectMap.value("summary").toString();
-    content = objectMap.value("content").toString();
+    m_title = objectMap.value("displayName").toString().trimmed();
+    m_summary = objectMap.value("summary").toString();
+    m_content = objectMap.value("content").toString();
 
-    likesCount = objectMap.value("likes").toMap().value("totalItems").toString();
-    if (likesCount.isEmpty())
-    {
-        likesCount = "0";
-    }
-    commentsCount = objectMap.value("replies").toMap().value("totalItems").toString();
-    sharesCount = objectMap.value("shares").toMap().value("totalItems").toString();
+    m_likesCount = objectMap.value("likes").toMap().value("totalItems").toInt();
+    m_commentsCount = objectMap.value("replies").toMap().value("totalItems").toInt();
+    m_sharesCount = objectMap.value("shares").toMap().value("totalItems").toInt();
 
     // Get last likes, comments and shares list here, used from Post()
-    lastLikesList = objectMap.value("likes").toMap().value("items").toList();
-    lastCommentsList = objectMap.value("replies").toMap().value("items").toList();
-    lastSharesList = objectMap.value("shares").toMap().value("items").toList();
+    m_lastLikesList = objectMap.value("likes").toMap().value("items").toList();
+    m_lastCommentsList = objectMap.value("replies").toMap().value("items").toList();
+    m_lastSharesList = objectMap.value("shares").toMap().value("items").toList();
 
-    proxiedUrls = false;
+    m_proxiedUrls = false;
 
     // Get URL for likes; first, proxyURL if it exists
-    likesUrl = objectMap.value("likes").toMap().value("pump_io").toMap()
-                                               .value("proxyURL").toString();
+    m_likesUrl = objectMap.value("likes").toMap().value("pump_io").toMap()
+                                                 .value("proxyURL").toString();
     // If still empty, get regular URL (that means the post is in the same server we are)
-    if (likesUrl.isEmpty())
+    if (m_likesUrl.isEmpty())
     {
-        likesUrl = objectMap.value("likes").toMap().value("url").toString();
+        m_likesUrl = objectMap.value("likes").toMap().value("url").toString();
     }
 
     // Get URL for comments; first, proxyURL if it exists
-    commentsUrl = objectMap.value("replies").toMap().value("pump_io").toMap()
-                                                    .value("proxyURL").toString();
-    if (commentsUrl.isEmpty()) // If still empty, get regular URL
+    m_commentsUrl = objectMap.value("replies").toMap().value("pump_io").toMap()
+                                                      .value("proxyURL").toString();
+    if (m_commentsUrl.isEmpty()) // If still empty, get regular URL
     {
-        commentsUrl = objectMap.value("replies").toMap().value("url").toString();
+        m_commentsUrl = objectMap.value("replies").toMap().value("url").toString();
     }
     else
     {
-        this->proxiedUrls = true;
+        m_proxiedUrls = true;
     }
 
     // FIXME: get sharesUrl...
 
-    qDebug() << "ASObject created" << this->id;
+    qDebug() << "ASObject created" << m_id;
 }
 
 ASObject::~ASObject()
 {
-    qDebug() << "ASObject destroyed" << this->id;
+    qDebug() << "ASObject destroyed" << m_id;
 }
 
 
 
 void ASObject::updateAuthorFromPerson(ASPerson *person)
 {
-    this->asAuthor->updateDataFromPerson(person);
+    m_author->updateDataFromPerson(person);
 }
 
 
@@ -253,64 +253,64 @@ void ASObject::updateAuthorFromPerson(ASPerson *person)
 
 ASPerson *ASObject::author()
 {
-    return this->asAuthor;
+    return m_author;
 }
 
 QString ASObject::getId()
 {
-    return this->id;
+    return m_id;
 }
 
 QString ASObject::getType()
 {
-    return this->type;
+    return m_type;
 }
 
 QString ASObject::getTranslatedType(QString typeString)
 {
     QString translatedTypeString;
 
-    if (typeString == "note")
+    if (typeString == QStringLiteral("note"))
     {
         translatedTypeString = tr("Note",
                                   "Noun, an object type");
     }
-    else if (typeString == "article")
+    else if (typeString == QStringLiteral("article"))
     {
         translatedTypeString = tr("Article",
                                   "Noun, an object type");
     }
-    else if (typeString == "image")
+    else if (typeString == QStringLiteral("image"))
     {
         translatedTypeString = tr("Image",
                                   "Noun, an object type");
     }
-    else if (typeString == "audio")
+    else if (typeString == QStringLiteral("audio"))
     {
         translatedTypeString = tr("Audio",
                                   "Noun, an object type");
     }
-    else if (typeString == "video")
+    else if (typeString == QStringLiteral("video"))
     {
         translatedTypeString = tr("Video",
                                   "Noun, an object type");
     }
-    else if (typeString == "file")
+    else if (typeString == QStringLiteral("file"))
     {
         translatedTypeString = tr("File",
                                   "Noun, an object type");
     }
-    else if (typeString == "comment")
+    else if (typeString == QStringLiteral("comment"))
     {
         translatedTypeString = tr("Comment",
                                   "Noun, as in object type: a comment");
     }
-    else if (typeString == "group")
+    else if (typeString == QStringLiteral("group"))
     {
         translatedTypeString = tr("Group",
                                   "Noun, an object type");
     }
-    else if (typeString == "collection")
+    else if (typeString == QStringLiteral("collection"))
     {
         translatedTypeString = tr("Collection",
                                   "Noun, an object type");
@@ -328,46 +328,46 @@ QString ASObject::getTranslatedType(QString typeString)
 
 QString ASObject::getUrl()
 {
-    return this->url;
+    return m_url;
 }
 
 QString ASObject::getCreatedAt()
 {
-    return this->createdAt;
+    return m_createdAt;
 }
 
 QString ASObject::getUpdatedAt()
 {
-    return this->updatedAt;
+    return m_updatedAt;
 }
 
 QString ASObject::getLocationName()
 {
-    return this->locationName;
+    return m_locationName;
 }
 
 QString ASObject::getLocationFormatted()
 {
-    return this->locationFormatted;
+    return m_locationFormatted;
 }
 
 QString ASObject::getLocationCountry()
 {
-    return this->locationCountry;
+    return m_locationCountry;
 }
 
 QString ASObject::getLocationTooltip()
 {
-    QString locationTooltip = this->locationFormatted;
+    QString locationTooltip = m_locationFormatted;
 
-    if (!this->locationCountry.isEmpty())
+    if (!m_locationCountry.isEmpty())
     {
         if (!locationTooltip.isEmpty())
         {
             locationTooltip.append("\n");
         }
 
-        locationTooltip.append("(" + this->locationCountry +  ")");
+        locationTooltip.append("(" + m_locationCountry +  ")");
     }
 
     // If still empty, return informational string
@@ -382,15 +382,16 @@ QString ASObject::getLocationTooltip()
 
 QString ASObject::getDeletedTime()
 {
-    return this->deleted;
+    return m_deleted;
 }
 
+
 QString ASObject::getDeletedOnString()
 {
     QString deletedOnString;
-    if (!this->deleted.isEmpty())
+    if (!m_deleted.isEmpty())
     {
-        deletedOnString = this->makeDeletedOnString(this->deleted);
+        deletedOnString = this->makeDeletedOnString(m_deleted);
     }
 
     return deletedOnString;
@@ -402,145 +403,145 @@ QString ASObject::makeDeletedOnString(QString deletionTime)
 }
 
 
-QString ASObject::isLiked()
+bool ASObject::isLiked()
 {
-    return this->liked;
+    return m_liked;
 }
 
 
 QString ASObject::getTitle()
 {
-    return this->title;
+    return m_title;
 }
 
 QString ASObject::getSummary()
 {
-    return this->summary;
+    return m_summary;
 }
 
 QString ASObject::getContent()
 {
-    return this->content;
+    return m_content;
 }
 
 QString ASObject::getImageUrl()
 {
-    return this->imageUrl;
+    return m_imageUrl;
 }
 
 QString ASObject::getSmallImageUrl()
 {
-    return this->smallImageUrl;
+    return m_smallImageUrl;
 }
 
 int ASObject::getImageWidth()
 {
-    return this->imageWidth;
+    return m_imageWidth;
 }
 
 int ASObject::getImageHeight()
 {
-    return this->imageHeight;
+    return m_imageHeight;
 }
 
 QString ASObject::getAudioUrl()
 {
-    return this->audioUrl;
+    return m_audioUrl;
 }
 
 QString ASObject::getVideoUrl()
 {
-    return this->videoUrl;
+    return m_videoUrl;
 }
 
 QString ASObject::getFileUrl()
 {
-    return this->fileUrl;
+    return m_fileUrl;
 }
 
 QString ASObject::getMimeType()
 {
-    return this->mimeType;
+    return m_mimeType;
 }
 
 QString ASObject::getAttachmentPureUrl()
 {
-    return this->attachmentPureUrl;
+    return m_attachmentPureUrl;
 }
 
 int ASObject::getMemberCount()
 {
-    return this->memberCount;
+    return m_memberCount;
 }
 
 QString ASObject::getMemberUrl()
 {
-    return this->memberUrl;
+    return m_memberUrl;
 }
 
-QString ASObject::getLikesCount()
+int ASObject::getLikesCount()
 {
-    return this->likesCount;
+    return m_likesCount;
 }
 
-QString ASObject::getCommentsCount()
+int ASObject::getCommentsCount()
 {
-    return this->commentsCount;
+    return m_commentsCount;
 }
 
-QString ASObject::getSharesCount()
+int ASObject::getSharesCount()
 {
-    return this->sharesCount;
+    return m_sharesCount;
 }
 
 bool ASObject::hasProxiedUrls()
 {
-    return this->proxiedUrls;
+    return m_proxiedUrls;
 }
 
 QVariantList ASObject::getLastLikesList()
 {
-    return this->lastLikesList;
+    return m_lastLikesList;
 }
 
 QVariantList ASObject::getLastCommentsList()
 {
-    return this->lastCommentsList;
+    return m_lastCommentsList;
 }
 
 QVariantList ASObject::getLastSharesList()
 {
-    return this->lastSharesList;
+    return m_lastSharesList;
 }
 
 QString ASObject::getLikesUrl()
 {
-    return this->likesUrl;
+    return m_likesUrl;
 }
 
 QString ASObject::getCommentsUrl()
 {
-    return this->commentsUrl;
+    return m_commentsUrl;
 }
 
 QString ASObject::getSharesUrl()
 {
-    return this->sharesUrl;
+    return m_sharesUrl;
 }
 
 QVariantMap ASObject::getOriginalObject()
 {
-    return this->originalObjectMap;
+    return m_originalObjectMap;
 }
 
 QVariantMap ASObject::getInReplyTo()
 {
-    return this->inReplyToMap;
+    return m_inReplyToMap;
 }
 
 QString ASObject::getInReplyToId()
 {
-    return inReplyToMap.value("id").toString();
+    return m_inReplyToMap.value("id").toString();
 }
 
 
@@ -671,14 +672,14 @@ bool ASObject::canDisplayObject(QString objectType)
 {
     bool canDisplay = false;
 
-    if (objectType == "note"
-     || objectType == "article"
-     || objectType == "image"
-     || objectType == "audio"
-     || objectType == "video"
-     || objectType == "file"
-     || objectType == "comment"
-     || objectType == "group")
+    if (objectType == QStringLiteral("note")
+     || objectType == QStringLiteral("article")
+     || objectType == QStringLiteral("image")
+     || objectType == QStringLiteral("audio")
+     || objectType == QStringLiteral("video")
+     || objectType == QStringLiteral("file")
+     || objectType == QStringLiteral("comment")
+     || objectType == QStringLiteral("group"))
     {
         canDisplay = true;
     }
