@@ -57,7 +57,7 @@ public:
     QString getDeletedTime();
     QString getDeletedOnString();
     static QString makeDeletedOnString(QString deletionTime);
-    QString isLiked();
+    bool isLiked();
 
     QString getTitle();
     QString getSummary();
@@ -76,9 +76,9 @@ public:
     int getMemberCount();
     QString getMemberUrl();
 
-    QString getLikesCount();
-    QString getCommentsCount();
-    QString getSharesCount();
+    int getLikesCount();
+    int getCommentsCount();
+    int getSharesCount();
     bool hasProxiedUrls();
 
     QVariantList getLastLikesList();
@@ -112,53 +112,54 @@ public slots:
 
 
 private:
-    ASPerson *asAuthor;
+    ASPerson *m_author;
 
-    QString id;
-    QString type;
-    QString url;
-    QString createdAt;
-    QString updatedAt;
-    QString locationName;
-    QString locationFormatted;
-    QString locationCountry;
+    QString m_id;
+    QString m_type;
+    QString m_url;
+    QString m_createdAt;
+    QString m_updatedAt;
+    QString m_locationName;
+    QString m_locationFormatted;
+    QString m_locationCountry;
 
-    QString deleted;
-    QString liked;
+    QString m_deleted;
+    bool m_liked;
 
 
-    QString title;
-    QString summary;
-    QString content;
+    QString m_title;
+    QString m_summary;
+    QString m_content;
 
-    QString imageUrl;
-    QString smallImageUrl;
-    int imageWidth;
-    int imageHeight;
-    QString audioUrl;
-    QString videoUrl;
-    QString fileUrl;
-    QString mimeType;
-    QString attachmentPureUrl; // To have filename with extension when using a proxyURL
+    QString m_imageUrl;
+    QString m_smallImageUrl;
+    int m_imageWidth;
+    int m_imageHeight;
+    QString m_audioUrl;
+    QString m_videoUrl;
+    QString m_fileUrl;
+    QString m_mimeType;
+    QString m_attachmentPureUrl; // To have filename with extension when using a proxyURL
 
-    int memberCount;
-    QString memberUrl;
+    // Properties for group objects
+    int m_memberCount;
+    QString m_memberUrl;
 
-    QString likesCount;
-    QString commentsCount;
-    QString sharesCount;
+    int m_likesCount;
+    int m_commentsCount;
+    int m_sharesCount;
 
-    QVariantList lastLikesList;
-    QVariantList lastCommentsList;
-    QVariantList lastSharesList;
+    QVariantList m_lastLikesList;
+    QVariantList m_lastCommentsList;
+    QVariantList m_lastSharesList;
 
-    QString likesUrl;
-    QString commentsUrl;
-    QString sharesUrl;
-    bool proxiedUrls;
+    QString m_likesUrl;
+    QString m_commentsUrl;
+    QString m_sharesUrl;
+    bool m_proxiedUrls;
 
-    QVariantMap originalObjectMap;
-    QVariantMap inReplyToMap;
+    QVariantMap m_originalObjectMap;
+    QVariantMap m_inReplyToMap;
 };
 
 #endif // ASOBJECT_H
