@@ -38,7 +38,7 @@ public:
 
 
     QString getId();
-    static QString cleanupId(QString originalId);
+    static QString cleanupId(QString id);
 
     QString getName();
     QString getNameWithFallback();
@@ -46,7 +46,7 @@ public:
     QString getHometown();
     QString getBio();
 
-    QString getAvatar();
+    QString getAvatarUrl();
     QString getUrl();
 
     QString getTooltipInfo();
@@ -61,28 +61,31 @@ public:
     QString getCreatedAt();
     QString getupdatedAt();
 
+
 signals:
 
+
 public slots:
 
+
 private:
-    QString id;
+    QString m_id;
 
-    QString name;
-    QString hometown;
-    QString bio;
+    QString m_name;
+    QString m_hometown;
+    QString m_bio;
 
-    QString avatar;
-    QString url;
+    QString m_avatar;
+    QString m_url;
 
-    QString outboxLink;
+    QString m_outboxLink;
 
-    QString followed;
-    //int followingCount;
-    //int followersCount;
+    bool m_followed;
+    //int m_followingCount;
+    //int m_followersCount;
 
-    QString createdAt;
-    QString updatedAt;
+    QString m_createdAt;
+    QString m_updatedAt;
 };
 
 #endif // ASPERSON_H
