@@ -31,6 +31,7 @@
 #include <QLineEdit>
 #include <QPushButton>
 #include <QAction>
+#include <QMenu>
 #include <QCloseEvent>
 #include <QHideEvent>
 #include <QSettings>
@@ -56,18 +57,43 @@ public:
     void saveSelected();
     void restoreSelected();
 
+    QMenu *getSelectorMenu();
+    void setDefaultAudience(bool toPublic);
+    void clearPublicAndFollowers();
+
+    void setPublic(bool state);
+    bool isPublicSelected();
+    void setFollowers(bool state);
+    bool isFollowersSelected();
+
+    void setListsMenu(QVariantList newLists);
+    void checkListWithId(QString id);
+
+    QString updatedAudienceLabels();
+
+    QVariantList getAudienceList(bool *onlyToFollowers);
+
+    int getRecipientsCount();
+
 
 signals:
-    void audienceSelected(QString selectorType,
-                          QStringList contactsList,
-                          QStringList urlsList);
+    void audienceChanged();
+
+    void publicSelected();
+    void followersSelected();
 
 
 public slots:
     void copyToSelected(QIcon contactIcon, QString contactString,
+                        QString contactName, QString contactId,
                         QString contactUrl);
     void setAudience();
 
+    void onListToggled(QAction *listAction);
+
+    void onPublicToggled(bool checked);
+    void onFollowersToggled(bool checked);
+
 
 protected:
     virtual void closeEvent(QCloseEvent *event);
@@ -100,8 +126,18 @@ private:
     QPushButton *doneButton;
     QPushButton *cancelButton;
 
+
+    QMenu *m_selectorMenu;
+    QAction *m_publicAction;
+    QAction *m_followersAction;
+    QMenu *m_listsMenu;
+
+
+
     QAction *doneAction;
     QAction *cancelAction;
+
+    PumpController *m_pumpController;
 };
 
 #endif // AUDIENCESELECTOR_H
