@@ -27,8 +27,8 @@ AvatarButton::AvatarButton(ASPerson *person,
                            QSize avatarSize,
                            QWidget *parent) : QToolButton(parent)
 {
-    this->pController = pumpController;
-    this->globalObj = globalObject;
+    m_pumpController = pumpController;
+    m_globalObject = globalObject;
 
     this->setPopupMode(QToolButton::InstantPopup);
     this->setStyleSheet("QToolButton { border: none;       "
@@ -39,12 +39,12 @@ AvatarButton::AvatarButton(ASPerson *person,
                         "                       palette(highlight) }");
     this->setIconSize(avatarSize);
     this->setMinimumSize(avatarSize);
-    this->iconWidth = avatarSize.width();
+    m_iconWidth = avatarSize.width();
 
     this->setToolTip(person->getTooltipInfo());
 
     // Get local file name for avatar, which is stored in base64 hash form
-    QString avatarFile = MiscHelpers::getCachedAvatarFilename(person->getAvatar());
+    QString avatarFile = MiscHelpers::getCachedAvatarFilename(person->getAvatarUrl());
     if (QFile::exists(avatarFile))
     {
         this->updateAvatarIcon(avatarFile);
@@ -53,25 +53,25 @@ AvatarButton::AvatarButton(ASPerson *person,
     {
         this->setGenericAvatarIcon();
 
-        pController->enqueueAvatarForDownload(person->getAvatar());
-        connect(pController, &PumpController::avatarStored,
+        m_pumpController->enqueueAvatarForDownload(person->getAvatarUrl());
+        connect(m_pumpController, &PumpController::avatarStored,
                 this, &AvatarButton::redrawAvatar);
     }
 
 
-    this->authorId = person->getId();
-    this->authorName = person->getNameWithFallback();
-    this->authorUrl = person->getUrl();
-    this->authorAvatarUrl = person->getAvatar();
-    this->authorOutbox = person->getOutboxLink();
+    m_authorId = person->getId();
+    m_authorName = person->getNameWithFallback();
+    m_authorUrl = person->getUrl();
+    m_authorAvatarUrl = person->getAvatarUrl();
+    m_authorOutbox = person->getOutboxLink();
 
-    this->authorFollowed = false; // Real status will be read when creating the menu
+    m_authorFollowed = false; // Real status will be read when creating the menu
 
 
     createAvatarMenu();
-    if (!authorId.isEmpty())  // Don't add the menu for invalid users
+    if (!m_authorId.isEmpty())  // Don't add the menu for invalid users
     {
-        this->setMenu(avatarMenu);
+        this->setMenu(m_avatarMenu);
     }
 
 
@@ -92,16 +92,15 @@ void AvatarButton::setGenericAvatarIcon()
     this->setIcon(QIcon::fromTheme("user-identity",
                                    QIcon(":/images/no-avatar.png"))
                   .pixmap(this->iconSize())
-                  .scaledToWidth(this->iconWidth,
-                                 Qt::SmoothTransformation));
+                  .scaledToWidth(m_iconWidth, Qt::SmoothTransformation));
 }
 
 
 void AvatarButton::updateAvatarIcon(QString filename)
 {
-    QPixmap avatarPixmap = QPixmap(filename)
-                           .scaledToWidth(this->iconWidth,
-                                          Qt::SmoothTransformation);
+    const QPixmap avatarPixmap = QPixmap(filename)
+                                 .scaledToWidth(m_iconWidth,
+                                                Qt::SmoothTransformation);
 
     if (!avatarPixmap.isNull())
     {
@@ -121,74 +120,76 @@ void AvatarButton::updateAvatarIcon(QString filename)
  */
 void AvatarButton::createAvatarMenu()
 {
-    bool userIsAuthor = false;
-    if (authorId == pController->currentUserId())
-    {
-        userIsAuthor = true; // The post or comment is ours
-    }
+    const bool userIsAuthor = (m_authorId == m_pumpController->currentUserId());
 
-    this->avatarMenu = new QMenu(this);
-    avatarMenu->setSeparatorsCollapsible(false);
+    m_avatarMenu = new QMenu(this);
+    m_avatarMenu->setSeparatorsCollapsible(false);
 
-    this->avatarMenuIdAction = new QAction(QIcon::fromTheme("user-identity",
-                                                            QIcon(":/images/no-avatar.png")),
-                                           this->authorId, this);
-    avatarMenuIdAction->setSeparator(true); // Make it nicer and not clickable
-    avatarMenu->addAction(avatarMenuIdAction);
+    m_avatarMenuIdAction = new QAction(QIcon::fromTheme("user-identity",
+                                                        QIcon(":/images/no-avatar.png")),
+                                       m_authorId,
+                                       this);
+    m_avatarMenuIdAction->setSeparator(true); // Make it nicer and not clickable
+    m_avatarMenu->addAction(m_avatarMenuIdAction);
 
 
-    QString openProfileString = tr("Open %1's profile in web browser")
-                                .arg(this->authorName);
+    QString openProfileString;
     if (userIsAuthor)
     {
         openProfileString = tr("Open your profile in web browser");
     }
-    this->avatarMenuProfileAction = new QAction(QIcon::fromTheme("internet-web-browser",
-                                                                 QIcon(":/images/no-avatar.png")),
-                                                openProfileString,
-                                                this);
-    connect(avatarMenuProfileAction, &QAction::triggered,
-            this, &AvatarButton::openAuthorProfileInBrowser);
-    if (authorUrl.isEmpty()) // Disable if there isn't actually an URL
+    else
     {
-        avatarMenuProfileAction->setDisabled(true);
+        openProfileString = tr("Open %1's profile in web browser")
+                            .arg(m_authorName);
     }
-    avatarMenu->addAction(avatarMenuProfileAction);
+    m_avatarMenuProfileAction = new QAction(QIcon::fromTheme("internet-web-browser",
+                                                             QIcon(":/images/no-avatar.png")),
+                                            openProfileString,
+                                            this);
+    connect(m_avatarMenuProfileAction, &QAction::triggered,
+            this, &AvatarButton::openAuthorProfileInBrowser);
+    if (m_authorUrl.isEmpty()) // Disable if there isn't actually an URL
+    {
+        m_avatarMenuProfileAction->setDisabled(true);
+    }
+    m_avatarMenu->addAction(m_avatarMenuProfileAction);
 
 
-    this->avatarMenuFollowAction = new QAction("*follow/unfollow*", this);
-    // Connections and proper label are set in setFollowUnfollow()
+    m_avatarMenuFollowAction = new QAction(this);
+    // Connections and label are set in setFollowUnfollow()
 
-    this->avatarMenuMessageAction = new QAction(QIcon::fromTheme("document-edit",
-                                                                 QIcon(":/images/button-edit.png")),
-                                                tr("Send message to %1")
-                                                .arg(this->authorName),
-                                                this);
-    connect(avatarMenuMessageAction, &QAction::triggered,
+
+    m_avatarMenuMessageAction = new QAction(QIcon::fromTheme("document-edit",
+                                                             QIcon(":/images/button-edit.png")),
+                                            tr("Send message to %1")
+                                            .arg(m_authorName),
+                                            this);
+    connect(m_avatarMenuMessageAction, &QAction::triggered,
             this, &AvatarButton::sendMessageToUser);
 
 
-    this->avatarMenuBrowseAction = new QAction(QIcon::fromTheme("edit-find",
-                                                                QIcon(":/images/menu-find.png")),
-                                               tr("Browse messages"),
-                                               this);
-    connect(avatarMenuBrowseAction, &QAction::triggered,
+    m_avatarMenuBrowseAction = new QAction(QIcon::fromTheme("edit-find",
+                                                            QIcon(":/images/menu-find.png")),
+                                           tr("Browse messages"),
+                                           this);
+    connect(m_avatarMenuBrowseAction, &QAction::triggered,
             this, &AvatarButton::browseUserMessages);
 
-    // Disable 'browse' option if not available (empty or in another server)
-    if (!pController->urlIsInOurHost(this->authorOutbox))
+    // Disable 'browse' option if not available (empty or in another server; Pump issue)
+    if (!m_pumpController->urlIsInOurHost(m_authorOutbox))
     {
-        this->avatarMenuBrowseAction->setDisabled(true);
+        m_avatarMenuBrowseAction->setDisabled(true);
     }
 
 
     // Only add "follow/unfollow", "send message" and "browse messages"
     if (!userIsAuthor)  // options if we're not the author
     {
-        avatarMenu->addAction(avatarMenuFollowAction);
+        m_avatarMenu->addAction(m_avatarMenuFollowAction);
         this->syncFollowState(true);
-        avatarMenu->addAction(avatarMenuMessageAction);
-        avatarMenu->addAction(avatarMenuBrowseAction);
+        m_avatarMenu->addAction(m_avatarMenuMessageAction);
+        m_avatarMenu->addAction(m_avatarMenuBrowseAction);
     }
 
     //
@@ -203,11 +204,11 @@ void AvatarButton::createAvatarMenu()
  */
 void AvatarButton::syncFollowState(bool firstTime)
 {
-    bool authorFollowedBefore = this->authorFollowed;
+    bool authorFollowedBefore = m_authorFollowed;
 
-    this->authorFollowed = this->pController->userInFollowing(authorId);
+    m_authorFollowed = m_pumpController->userInFollowing(m_authorId);
 
-    if (this->authorFollowed != authorFollowedBefore || firstTime)
+    if (m_authorFollowed != authorFollowedBefore || firstTime)
     {
         this->setFollowUnfollow();
     }
@@ -222,75 +223,77 @@ void AvatarButton::syncFollowState(bool firstTime)
  */
 void AvatarButton::setFollowUnfollow()
 {
-    if (this->authorFollowed)
+    if (m_authorFollowed)
     {
-        this->avatarMenuFollowAction->setIcon(QIcon::fromTheme("list-remove-user",
-                                                               QIcon(":/images/list-remove.png")));
-        this->avatarMenuFollowAction->setText(tr("Stop following"));
-        connect(avatarMenuFollowAction, &QAction::triggered,
+        m_avatarMenuFollowAction->setIcon(QIcon::fromTheme("list-remove-user",
+                                                           QIcon(":/images/list-remove.png")));
+        m_avatarMenuFollowAction->setText(tr("Stop following"));
+        connect(m_avatarMenuFollowAction, &QAction::triggered,
                 this, &AvatarButton::unfollowUser);
-        disconnect(avatarMenuFollowAction, &QAction::triggered,
+        disconnect(m_avatarMenuFollowAction, &QAction::triggered,
                    this, &AvatarButton::followUser);
         //qDebug() << "post author followed, connecting to UNFOLLOW()" << this->authorId;
     }
     else
     {
-        this->avatarMenuFollowAction->setIcon(QIcon::fromTheme("list-add-user",
-                                                               QIcon(":/images/list-add.png")));
-        this->avatarMenuFollowAction->setText(tr("Follow"));
-        connect(avatarMenuFollowAction, &QAction::triggered,
+        m_avatarMenuFollowAction->setIcon(QIcon::fromTheme("list-add-user",
+                                                           QIcon(":/images/list-add.png")));
+        m_avatarMenuFollowAction->setText(tr("Follow"));
+        connect(m_avatarMenuFollowAction, &QAction::triggered,
                 this, &AvatarButton::followUser);
-        disconnect(avatarMenuFollowAction, &QAction::triggered,
+        disconnect(m_avatarMenuFollowAction, &QAction::triggered,
                    this, &AvatarButton::unfollowUser);
         //qDebug() << "post author not followed, connecting to FOLLOW()" << this->authorId;
     }
 }
 
+
 void AvatarButton::addSeparatorToMenu()
 {
-    avatarMenu->addSeparator();
+    m_avatarMenu->addSeparator();
 }
 
+
 void AvatarButton::addActionToMenu(QAction *action)
 {
-    avatarMenu->addAction(action);
+    m_avatarMenu->addAction(action);
 }
 
 
-
 ////////////////////////////////////////////////////////////////////////////
 ////////////////////////////////// SLOTS ///////////////////////////////////
 ////////////////////////////////////////////////////////////////////////////
 
 
+
 void AvatarButton::openAuthorProfileInBrowser()
 {
-    MiscHelpers::openUrl(this->authorUrl, this);
+    MiscHelpers::openUrl(m_authorUrl, this);
 }
 
 
 void AvatarButton::followUser()
 {
-    this->pController->followContact(this->authorId);
+    m_pumpController->followContact(m_authorId);
     // Actual menu will be updated when appropriate SIGNAL is received
 }
 
 
 void AvatarButton::unfollowUser()
 {
-    QString nameWithId = ASPerson::makeNameIdString(this->authorName,
-                                                    this->authorId);
+    const QString nameWithId = ASPerson::makeNameIdString(m_authorName,
+                                                          m_authorId);
 
     int confirmation = QMessageBox::question(this, tr("Stop following?"),
                                              tr("Are you sure you want to "
                                                 "stop following %1?")
                                              .arg(nameWithId),
                                              tr("&Yes, stop following"),
-                                             tr("&No"), "", 1, 1);
+                                             tr("&No"), QString(), 1, 1);
 
     if (confirmation == 0)
     {
-        this->pController->unfollowContact(this->authorId);
+        m_pumpController->unfollowContact(m_authorId);
         // Menu option will be updated when appropriate SIGNAL is received
     }
 }
@@ -298,18 +301,17 @@ void AvatarButton::unfollowUser()
 
 void AvatarButton::sendMessageToUser()
 {
-    this->globalObj->createMessageForContact(this->authorId,
-                                             this->authorName,
-                                             this->authorUrl);
-
+    m_globalObject->createMessageForContact(m_authorId,
+                                            m_authorName,
+                                            m_authorUrl);
 }
 
 void AvatarButton::browseUserMessages()
 {
-    this->globalObj->browseUserMessages(this->authorId,
-                                        this->authorName,
-                                        this->icon(),
-                                        this->authorOutbox + "/major"); // TMP!
+    m_globalObject->browseUserMessages(m_authorId,
+                                       m_authorName,
+                                       this->icon(),
+                                       m_authorOutbox + "/major"); // TMP! not future-proof
 }
 
 
@@ -320,11 +322,11 @@ void AvatarButton::browseUserMessages()
  */
 void AvatarButton::redrawAvatar(QString avatarUrl, QString avatarFilename)
 {
-    if (avatarUrl == this->authorAvatarUrl)
+    if (avatarUrl == m_authorAvatarUrl)
     {
         this->updateAvatarIcon(avatarFilename);
 
-        disconnect(pController, &PumpController::avatarStored,
+        disconnect(m_pumpController, &PumpController::avatarStored,
                    this, &AvatarButton::redrawAvatar);
     }
 }
