@@ -49,15 +49,15 @@ public slots:
 
 
 private:
-    QHBoxLayout *mainLayout;
+    QHBoxLayout *m_mainLayout;
 
-    QWidget *containerWidget;
-    QHBoxLayout *containerLayout;
+    QWidget *m_containerWidget;
+    QHBoxLayout *m_containerLayout;
 
-    QLabel *iconLabel;
-    QLabel *descriptionLabel;
-    QPushButton *okButton;
-    QPushButton *cancelButton;
+    QLabel *m_iconLabel;
+    QLabel *m_descriptionLabel;
+    QPushButton *m_okButton;
+    QPushButton *m_cancelButton;
 };
 
 #endif // BANNERNOTIFICATION_H
