@@ -24,51 +24,51 @@ ColorPicker::ColorPicker(QString description,
                          QString initialColorString,
                          QWidget *parent) : QWidget(parent)
 {
-    descriptionLabel = new QLabel(description, this);
-    descriptionLabel->setWordWrap(true);
-    descriptionLabel->setAlignment(Qt::AlignTop);
+    m_descriptionLabel = new QLabel(description, this);
+    m_descriptionLabel->setWordWrap(true);
+    m_descriptionLabel->setAlignment(Qt::AlignTop);
 
-    checkBox = new QCheckBox(this);
+    m_checkBox = new QCheckBox(this);
 
-    buttonPixmap = QPixmap(32, 32);
+    m_buttonPixmap = QPixmap(32, 32);
 
-    button = new QPushButton(tr("Change..."), this);
-    button->setIconSize(QSize(32, 32));
-    button->setDisabled(true); // Disabled initially
-    connect(button, &QAbstractButton::clicked,
+    m_button = new QPushButton(tr("Change..."), this);
+    m_button->setIconSize(QSize(32, 32));
+    m_button->setDisabled(true); // Disabled initially
+    connect(m_button, &QAbstractButton::clicked,
             this, &ColorPicker::changeColor);
 
-    connect(checkBox, &QAbstractButton::toggled,
-            button, &QWidget::setEnabled);
+    connect(m_checkBox, &QAbstractButton::toggled,
+            m_button, &QWidget::setEnabled);
 
-    layout = new QHBoxLayout();
-    layout->addWidget(descriptionLabel, 10);
-    layout->addSpacing(4);
-    layout->addStretch(1);
-    layout->addWidget(checkBox,         0);
-    layout->addSpacing(8);
-    layout->addWidget(button,           0);
-    this->setLayout(layout);
+    m_layout = new QHBoxLayout();
+    m_layout->addWidget(m_descriptionLabel, 10);
+    m_layout->addSpacing(4);
+    m_layout->addStretch(1);
+    m_layout->addWidget(m_checkBox,         0);
+    m_layout->addSpacing(8);
+    m_layout->addWidget(m_button,           0);
+    this->setLayout(m_layout);
 
 
     QColor initialColor(initialColorString);
     if (initialColor.isValid())
     {
-        this->currentColor = initialColor;
-        this->checkBox->setChecked(true);
+        m_currentColor = initialColor;
+        m_checkBox->setChecked(true);
     }
     else
     {
-        if (initialColorString.startsWith("DISABLED"))
+        if (initialColorString.startsWith(QStringLiteral("DISABLED")))
         {
-            this->currentColor = initialColorString.remove("DISABLED");
+            m_currentColor = initialColorString.remove(QStringLiteral("DISABLED"));
         }
         else
         {
-            this->currentColor = QColor(Qt::blue);
+            m_currentColor = QColor(Qt::blue);
         }
     }
-    this->setButtonColor(currentColor);
+    this->setButtonColor(m_currentColor);
 
 
     qDebug() << "ColorPicker created";
@@ -83,20 +83,21 @@ ColorPicker::~ColorPicker()
 
 void ColorPicker::setButtonColor(QColor color)
 {
-    buttonPixmap.fill(color);
-    button->setIcon(QIcon(buttonPixmap));
+    m_buttonPixmap.fill(color);
+    m_button->setIcon(QIcon(m_buttonPixmap));
 }
 
 
 QString ColorPicker::getCurrentColor()
 {
-    if (checkBox->isChecked())
+    if (m_checkBox->isChecked())
     {
-        return this->currentColor.name(); // return in #RRGGBB format
+        return m_currentColor.name(); // return in #RRGGBB format
     }
     else
     {
-        return QString("DISABLED%1").arg(currentColor.name()); // Return invalid color
+        // Return invalid color, but keeping the numeric code
+        return QString("DISABLED%1").arg(m_currentColor.name());
     }
 }
 
@@ -108,15 +109,15 @@ QString ColorPicker::getCurrentColor()
 
 void ColorPicker::changeColor()
 {
-    QColor newColor = QColorDialog::getColor(currentColor, this,
+    QColor newColor = QColorDialog::getColor(m_currentColor,
+                                             this,
                                              tr("Choose a color"));
-
     if (newColor.isValid())
     {
-        currentColor = newColor;
+        m_currentColor = newColor;
 
-        setButtonColor(currentColor);
+        setButtonColor(m_currentColor);
     }
 
-    qDebug() << "New color:" << currentColor;
+    qDebug() << "New color:" << m_currentColor;
 }
