@@ -44,6 +44,7 @@ public:
     void setButtonColor(QColor color);
     QString getCurrentColor();
 
+
 signals:
 
 
@@ -52,14 +53,14 @@ public slots:
 
 
 private:
-    QHBoxLayout *layout;
+    QHBoxLayout *m_layout;
 
-    QLabel *descriptionLabel;
-    QCheckBox *checkBox;
-    QPixmap buttonPixmap;
-    QPushButton *button;
+    QLabel *m_descriptionLabel;
+    QCheckBox *m_checkBox;
+    QPixmap m_buttonPixmap;
+    QPushButton *m_button;
 
-    QColor currentColor;
+    QColor m_currentColor;
 };
 
 #endif // COLORPICKER_H
