@@ -102,41 +102,41 @@ protected:
     virtual void resizeEvent(QResizeEvent *event);
 
 private:
-    QVBoxLayout *mainLayout;
-    QGridLayout *bottomLayout;
+    QVBoxLayout *m_mainLayout;
+    QGridLayout *m_bottomLayout;
 
-    QScrollArea *commentsScrollArea;
-    QWidget *commentsWidget;
-    QVBoxLayout *commentsLayout;
-    QTimer *scrollToBottomTimer;
+    QScrollArea *m_commentsScrollArea;
+    QWidget *m_commentsWidget;
+    QVBoxLayout *m_commentsLayout;
+    QTimer *m_scrollToBottomTimer;
 
-    QString parentPostId;
+    QString m_parentPostId;
 
-    QString reloadCommentsString;
-    QString reloadErrorString;
-    QLabel *showAllCommentsLinkLabel;
-    QTimer *getAllCommentsTimer; // To get all comments after a delay
+    QString m_reloadCommentsString;
+    QString m_reloadErrorString;
+    QLabel *m_showAllCommentsLinkLabel;
+    QTimer *m_getAllCommentsTimer; // To get all comments after a delay
 
-    Composer *commentComposer;
-    QPushButton *toolsButton;
-    QLabel *statusInfoLabel;
-    QPushButton *commentButton;
-    QPushButton *cancelButton;
+    Composer *m_commentComposer;
+    QPushButton *m_toolsButton;
+    QLabel *m_statusInfoLabel;
+    QPushButton *m_commentButton;
+    QPushButton *m_cancelButton;
 
-    bool editingMode;
-    QString editingCommentId;
+    bool m_editingMode;
+    QString m_editingCommentId;
 
-    bool fullMode;
+    bool m_fullMode;
 
-    QList<Comment *> commentsInBlock;
-    int currentCommentCount;
-    bool allCommentsShown;
+    QList<Comment *> m_commentsInBlock;
+    int m_currentCommentCount;
+    bool m_allCommentsShown;
 
-    QString parentPostAuthorId;
-    bool parentPostStandalone;
+    QString m_parentPostAuthorId;
+    bool m_parentPostStandalone;
 
-    PumpController *pController;
-    GlobalObject *globalObj;
+    PumpController *m_pumpController;
+    GlobalObject *m_globalObject;
 };
 
 #endif // COMMENTER_H
