@@ -24,166 +24,162 @@
 Composer::Composer(GlobalObject *globalObject, bool forPublisher,
                    QWidget *parent) : QTextEdit(parent)
 {
-    this->globalObj = globalObject;
-    this->forPublisher = forPublisher;
+    m_globalObject = globalObject;
+    m_forPublisher = forPublisher;
 
     this->setAcceptRichText(true);
     this->setTabChangesFocus(true);
 
-    clickToPostText = tr("Click here or press Control+N to post a note...");
+    m_clickToPostString = tr("Click here or press Control+N to post a note...");
 
 
     // A menu to insert some Unicode symbols
-    symbolsMenu = new QMenu(tr("Symbols"), this);
-    symbolsMenu->setIcon(QIcon::fromTheme("character-set"));
-    symbolsMenu->addAction(QString::fromUtf8("\342\230\272")); // Smiling face
-    symbolsMenu->addAction(QString::fromUtf8("\342\230\271")); // Sad face
-    symbolsMenu->addAction(QString::fromUtf8("\342\231\245")); // Heart
-    symbolsMenu->addAction(QString::fromUtf8("\342\231\253")); // Musical note
-    symbolsMenu->addAction(QString::fromUtf8("\342\230\225")); // Coffee
-    symbolsMenu->addAction(QString::fromUtf8("\342\234\224")); // Check mark
-    symbolsMenu->addAction(QString::fromUtf8("\342\234\230")); // Ballot X
-    symbolsMenu->addAction(QString::fromUtf8("\342\230\205")); // Black star
-    symbolsMenu->addAction(QString::fromUtf8("\342\254\205")); // Arrow to the left
-    symbolsMenu->addAction(QString::fromUtf8("\342\236\241")); // Arrow to the right
-    symbolsMenu->addAction(QString::fromUtf8("\342\231\273")); // Recycling symbol
-    symbolsMenu->addAction(QString::fromUtf8("\342\210\236")); // Infinity
-    connect(symbolsMenu, &QMenu::triggered,
+    m_symbolsMenu = new QMenu(tr("Symbols"), this);
+    m_symbolsMenu->setIcon(QIcon::fromTheme("character-set"));
+    m_symbolsMenu->addAction(QString::fromUtf8("\342\230\272")); // Smiling face
+    m_symbolsMenu->addAction(QString::fromUtf8("\342\230\271")); // Sad face
+    m_symbolsMenu->addAction(QString::fromUtf8("\342\231\245")); // Heart
+    m_symbolsMenu->addAction(QString::fromUtf8("\342\231\253")); // Musical note
+    m_symbolsMenu->addAction(QString::fromUtf8("\342\230\225")); // Coffee
+    m_symbolsMenu->addAction(QString::fromUtf8("\342\234\224")); // Check mark
+    m_symbolsMenu->addAction(QString::fromUtf8("\342\234\230")); // Ballot X
+    m_symbolsMenu->addAction(QString::fromUtf8("\342\230\205")); // Black star
+    m_symbolsMenu->addAction(QString::fromUtf8("\342\254\205")); // Arrow to the left
+    m_symbolsMenu->addAction(QString::fromUtf8("\342\236\241")); // Arrow to the right
+    m_symbolsMenu->addAction(QString::fromUtf8("\342\231\273")); // Recycling symbol
+    m_symbolsMenu->addAction(QString::fromUtf8("\342\210\236")); // Infinity
+    connect(m_symbolsMenu, &QMenu::triggered,
             this, &Composer::insertSymbol);
 
 
-    toolsMenu = new QMenu(tr("Formatting"), this);
-    toolsMenu->addAction(QIcon::fromTheme(""),
-                         tr("Normal"),
-                         this,
-                         SLOT(makeNormal()));
-    toolsMenu->addAction(QIcon::fromTheme("format-text-bold"),
-                         tr("Bold"),
-                         this,
-                         SLOT(makeBold()),
-                         QKeySequence("Ctrl+B"));
-    toolsMenu->addAction(QIcon::fromTheme("format-text-italic"),
-                         tr("Italic"),
-                         this,
-                         SLOT(makeItalic()),
-                         QKeySequence("Ctrl+I"));
-    toolsMenu->addAction(QIcon::fromTheme("format-text-underline"),
-                         tr("Underline"),
-                         this,
-                         SLOT(makeUnderline()),
-                         QKeySequence("Ctrl+U"));
-    toolsMenu->addAction(QIcon::fromTheme("format-text-strikethrough"),
-                         tr("Strikethrough"),
-                         this,
-                         SLOT(makeStrikethrough()));
+    m_toolsMenu = new QMenu(tr("Formatting"), this);
+    m_toolsMenu->addAction(tr("Normal"),
+                           this,
+                           SLOT(makeNormal()));
+    m_toolsMenu->addAction(QIcon::fromTheme("format-text-bold"),
+                           tr("Bold"),
+                           this,
+                           SLOT(makeBold()),
+                           QKeySequence("Ctrl+B"));
+    m_toolsMenu->addAction(QIcon::fromTheme("format-text-italic"),
+                           tr("Italic"),
+                           this,
+                           SLOT(makeItalic()),
+                           QKeySequence("Ctrl+I"));
+    m_toolsMenu->addAction(QIcon::fromTheme("format-text-underline"),
+                           tr("Underline"),
+                           this,
+                           SLOT(makeUnderline()),
+                           QKeySequence("Ctrl+U"));
+    m_toolsMenu->addAction(QIcon::fromTheme("format-text-strikethrough"),
+                           tr("Strikethrough"),
+                           this,
+                           SLOT(makeStrikethrough()));
 
-    toolsMenu->addSeparator();
+    m_toolsMenu->addSeparator();
 
-    toolsMenu->addAction(QIcon::fromTheme("format-font-size-more"),
-                         tr("Header"),
-                         this,
-                         SLOT(makeHeader()),
-                         QKeySequence("Ctrl+H"));
-    toolsMenu->addAction(QIcon::fromTheme("format-list-unordered"),
-                         tr("List"),
-                         this,
-                         SLOT(makeList()));
-    toolsMenu->addAction(QIcon::fromTheme("insert-table"),
-                         tr("Table"),
-                         this,
-                         SLOT(makeTable()));
-    toolsMenu->addAction(QIcon::fromTheme("format-justify-fill"),
-                         tr("Preformatted block"),
-                         this,
-                         SLOT(makePreformatted()));
-    toolsMenu->addAction(QIcon::fromTheme("format-text-italic"),
-                         tr("Quote block"),
-                         this,
-                         SLOT(makeQuote()),
-                         QKeySequence("Ctrl+O"));
+    m_toolsMenu->addAction(QIcon::fromTheme("format-font-size-more"),
+                           tr("Header"),
+                           this,
+                           SLOT(makeHeader()),
+                           QKeySequence("Ctrl+H"));
+    m_toolsMenu->addAction(QIcon::fromTheme("format-list-unordered"),
+                           tr("List"),
+                           this,
+                           SLOT(makeList()));
+    m_toolsMenu->addAction(QIcon::fromTheme("insert-table"),
+                           tr("Table"),
+                           this,
+                           SLOT(makeTable()));
+    m_toolsMenu->addAction(QIcon::fromTheme("format-justify-fill"),
+                           tr("Preformatted block"),
+                           this,
+                           SLOT(makePreformatted()));
+    m_toolsMenu->addAction(QIcon::fromTheme("format-text-italic"),
+                           tr("Quote block"),
+                           this,
+                           SLOT(makeQuote()),
+                           QKeySequence("Ctrl+O"));
 
-    toolsMenu->addSeparator();
+    m_toolsMenu->addSeparator();
 
-    toolsMenu->addAction(QIcon::fromTheme("insert-link"),
-                         tr("Make a link"),
-                         this,
-                         SLOT(makeLink()),
-                         QKeySequence("Ctrl+L"));
-    toolsMenu->addAction(QIcon::fromTheme("insert-image"),
-                         tr("Insert an image from a web site"),
-                         this,
-                         SLOT(insertImage()),
-                         QKeySequence("Ctrl+P"));
-    toolsMenu->addAction(QIcon::fromTheme("insert-horizontal-rule"),
-                         tr("Insert line"),
-                         this,
-                         SLOT(insertLine()),
-                         QKeySequence("Ctrl+Shift+L"));
+    m_toolsMenu->addAction(QIcon::fromTheme("insert-link"),
+                           tr("Make a link"),
+                           this,
+                           SLOT(makeLink()),
+                           QKeySequence("Ctrl+L"));
+    m_toolsMenu->addAction(QIcon::fromTheme("insert-image"),
+                           tr("Insert an image from a web site"),
+                           this,
+                           SLOT(insertImage()),
+                           QKeySequence("Ctrl+P"));
+    m_toolsMenu->addAction(QIcon::fromTheme("insert-horizontal-rule"),
+                           tr("Insert line"),
+                           this,
+                           SLOT(insertLine()),
+                           QKeySequence("Ctrl+Shift+L"));
 
-    toolsMenu->addSeparator();
+    m_toolsMenu->addSeparator();
 
-    toolsMenu->addMenu(symbolsMenu);
+    m_toolsMenu->addMenu(m_symbolsMenu);
 
 
-    toolsButton = new QPushButton(QIcon::fromTheme("format-list-ordered",
-                                                   QIcon(":/images/button-configure.png")),
-                                  tr("&Format",
-                                     "Button for text formatting and related options"),
-                                  this);
-    toolsButton->setMenu(toolsMenu);
-    toolsButton->setToolTip("<b></b>"
-                            + tr("Text Formatting Options"));
+    m_toolsButton = new QPushButton(QIcon::fromTheme("format-list-ordered",
+                                                     QIcon(":/images/button-configure.png")),
+                                    tr("&Format",
+                                       "Button for text formatting and related options"),
+                                    this);
+    m_toolsButton->setMenu(m_toolsMenu);
+    m_toolsButton->setToolTip("<b></b>"
+                              + tr("Text Formatting Options"));
 
 
     // Extra action for the context menu, paste as plaintext
-    this->pastePlaintextAction = new QAction(QIcon::fromTheme("paste"),
-                                             tr("Paste Text Without Formatting"),
-                                             this);
-
-    pastePlaintextAction->setShortcut(QKeySequence("Ctrl+Shift+V"));
-    connect(pastePlaintextAction, &QAction::triggered,
+    m_pastePlaintextAction = new QAction(QIcon::fromTheme("edit-paste"),
+                                         tr("Paste Text Without Formatting"),
+                                         this);
+    m_pastePlaintextAction->setShortcut(QKeySequence("Ctrl+Shift+V"));
+    connect(m_pastePlaintextAction, &QAction::triggered,
             this, &Composer::pasteAsPlaintext);
 
     // Add action to this object, in order for the shortcut to work
     // Otherwise, the action isn't available until the context menu is present
-    this->addAction(pastePlaintextAction);
+    this->addAction(m_pastePlaintextAction);
 
 
     // Nick completion stuff
-    nickCompleter = new QCompleter(globalObj->getNickCompletionModel(),
-                                   this);
-    nickCompleter->setWidget(this);
-    nickCompleter->setMaxVisibleItems(15);
-    nickCompleter->setCompletionColumn(0);
-    nickCompleter->setCaseSensitivity(Qt::CaseInsensitive);
-    nickCompleter->setModelSorting(QCompleter::CaseInsensitivelySortedModel);
-    connect(nickCompleter, SIGNAL(activated(QModelIndex)), // Old-style connect()
+    m_nickCompleter = new QCompleter(m_globalObject->getNickCompletionModel(),
+                                     this);
+    m_nickCompleter->setWidget(this);
+    m_nickCompleter->setMaxVisibleItems(15);
+    m_nickCompleter->setCompletionColumn(0);
+    m_nickCompleter->setCaseSensitivity(Qt::CaseInsensitive);
+    m_nickCompleter->setModelSorting(QCompleter::CaseInsensitivelySortedModel);
+    connect(m_nickCompleter, SIGNAL(activated(QModelIndex)), // Old-style connect()
             this, SLOT(insertCompletedNick(QModelIndex))); // due to signal overload
 
-    popupTableView = new QTableView(this);
-    popupTableView->horizontalHeader()->hide();
-    popupTableView->verticalHeader()->hide();
-    popupTableView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    popupTableView->setAlternatingRowColors(true);
-    popupTableView->setSelectionBehavior(QAbstractItemView::SelectRows);
-    popupTableView->setSelectionMode(QAbstractItemView::SingleSelection);
-    popupTableView->setEditTriggers(QAbstractItemView::NoEditTriggers);
-    nickCompleter->setPopup(popupTableView);
+    m_popupTableView = new QTableView(this);
+    m_popupTableView->horizontalHeader()->hide();
+    m_popupTableView->verticalHeader()->hide();
+    m_popupTableView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    m_popupTableView->setAlternatingRowColors(true);
+    m_popupTableView->setSelectionBehavior(QAbstractItemView::SelectRows);
+    m_popupTableView->setSelectionMode(QAbstractItemView::SingleSelection);
+    m_popupTableView->setEditTriggers(QAbstractItemView::NoEditTriggers);
+    m_nickCompleter->setPopup(m_popupTableView);
 
-    mainLayout = new QHBoxLayout();
 
-    if (this->forPublisher)  // Publisher mode
+    if (m_forPublisher)  // Publisher mode
     {
         this->setToolTip("<b></b>"
                          + tr("Type a message here to post it"));
 
-        this->setPlaceholderText(clickToPostText);
+        this->setPlaceholderText(m_clickToPostString);
     }
     else                     // or Commenter mode
     {
         this->setPlaceholderText(tr("Type a comment here"));
     }
-    this->setLayout(mainLayout);
 
     qDebug() << "Composer box created";
 }
@@ -200,9 +196,9 @@ void Composer::erase()
 {
     this->clear();
 
-    if (this->forPublisher)
+    if (m_forPublisher)
     {
-        this->setPlaceholderText(clickToPostText);
+        this->setPlaceholderText(m_clickToPostString);
     }
 }
 
@@ -232,34 +228,35 @@ void Composer::insertLink(QString url, QString title)
 
 void Composer::requestCompletion(QString partialNick)
 {
-    nickCompleter->setCompletionPrefix(partialNick);
-    popupTableView->ensurePolished();
+    m_nickCompleter->setCompletionPrefix(partialNick);
+    m_popupTableView->ensurePolished();
 
-    popupTableView->resizeColumnsToContents();
-    popupTableView->resizeRowsToContents();
-    popupTableView->ensurePolished();
+    m_popupTableView->resizeColumnsToContents();
+    m_popupTableView->resizeRowsToContents();
+    m_popupTableView->ensurePolished();
 
-    int tableWidth = popupTableView->columnWidth(0)
-                     + popupTableView->columnWidth(1) + 2;
+    int tableWidth = m_popupTableView->columnWidth(0)
+                     + m_popupTableView->columnWidth(1) + 2;
     if (tableWidth > this->width() + 2)
     {
         tableWidth = this->width() + 2;
-        popupTableView->setColumnWidth(0, (tableWidth / 4) * 3);
-        popupTableView->setColumnWidth(1, tableWidth / 4);
+        m_popupTableView->setColumnWidth(0, (tableWidth / 4) * 3);
+        m_popupTableView->setColumnWidth(1, tableWidth / 4);
     }
 
-    popupTableView->setMinimumWidth(tableWidth);
+    m_popupTableView->setMinimumWidth(tableWidth);
 
-    int rows = qMin(popupTableView->model()->rowCount(), 15);
-    int rowHeight = popupTableView->rowHeight(0) + 4;
-    popupTableView->setMinimumHeight(rows * rowHeight);
+    int rows = qMin(m_popupTableView->model()->rowCount(), 15);
+    int rowHeight = m_popupTableView->rowHeight(0) + 4;
+    m_popupTableView->setMinimumHeight(rows * rowHeight);
 
     // Popup might get disabled at some point when Composer is used in a Post
-    popupTableView->setEnabled(true);
+    m_popupTableView->setEnabled(true);
 
-    nickCompleter->complete(QRect(this->cursorRect().x(),
-                                  this->cursorRect().y() + 24,
-                                  tableWidth, 1));
+    m_nickCompleter->complete(QRect(this->cursorRect().x(),
+                                    this->cursorRect().y() + 24,
+                                    tableWidth,
+                                    1));
 }
 
 
@@ -269,13 +266,13 @@ void Composer::requestCompletion(QString partialNick)
  */
 void Composer::hideInfoMessage()
 {
-    this->setPlaceholderText("");
+    this->setPlaceholderText(QString());
 }
 
 
 QPushButton *Composer::getToolsButton()
 {
-    return this->toolsButton;
+    return m_toolsButton;
 }
 
 
@@ -289,7 +286,7 @@ QPushButton *Composer::getToolsButton()
  */
 void Composer::setPlainPasteEnabled(bool state)
 {
-    this->pastePlaintextAction->setEnabled(state);
+    m_pastePlaintextAction->setEnabled(state);
 }
 
 
@@ -337,7 +334,7 @@ void Composer::dropEvent(QDropEvent *event)
                 if (urls.count() == 1)
                 {
                     // Clear possible prior error messages
-                    emit errorHappened("");
+                    emit errorHappened(QString());
                 }
                 else
                 {
@@ -366,7 +363,7 @@ void Composer::dropEvent(QDropEvent *event)
 void Composer::keyPressEvent(QKeyEvent *event)
 {
     // Allow cancelling/accepting the autocompletion popup
-    if (this->nickCompleter->popup()->isVisible())
+    if (m_nickCompleter->popup()->isVisible())
     {
         if (event->key() == Qt::Key_Enter
          || event->key() == Qt::Key_Return
@@ -424,7 +421,7 @@ void Composer::keyPressEvent(QKeyEvent *event)
         else
         {
             // Hide it, if it was visible
-            this->nickCompleter->popup()->hide();
+            m_nickCompleter->popup()->hide();
         }
     }
 
@@ -438,31 +435,25 @@ void Composer::keyPressEvent(QKeyEvent *event)
  */
 void Composer::contextMenuEvent(QContextMenuEvent *event)
 {
-    this->customContextMenu = this->createStandardContextMenu();
+    m_customContextMenu = this->createStandardContextMenu();
 
-    // tools menu before default context menu
-    customContextMenu->insertMenu(customContextMenu->actions().at(0),
-                                  toolsMenu);
-    customContextMenu->insertSeparator(customContextMenu->actions().at(1));
+    // 'Formating' menu before default context menu
+    m_customContextMenu->insertMenu(m_customContextMenu->actions().at(0),
+                                    m_toolsMenu);
+    m_customContextMenu->insertSeparator(m_customContextMenu->actions().at(1));
 
     // And options added after default context menu
-    customContextMenu->addSeparator();
+    m_customContextMenu->addSeparator();
 
 
-    customContextMenu->addAction(pastePlaintextAction);
-    if (this->canPaste())
-    {
-        pastePlaintextAction->setEnabled(true);
-    }
-    else
-    {
-        pastePlaintextAction->setDisabled(true);
-    }
+    m_customContextMenu->addAction(m_pastePlaintextAction);
+    m_pastePlaintextAction->setEnabled(this->canPaste());
 
-    customContextMenu->exec(event->globalPos());
 
-    // FIXME: Possible leak... should delete customContextMenu?
-    customContextMenu->deleteLater();
+    m_customContextMenu->exec(event->globalPos());
+
+    // FIXME: Possible leak... should delete m_customContextMenu?
+    m_customContextMenu->deleteLater();
 
     event->accept();
 }
@@ -512,7 +503,7 @@ void Composer::insertFromMimeData(const QMimeData *source)
                                             + "\n\n\n",
                                             tr("Insert as visible image"), // Default option (Enter)
                                             tr("Insert as link"),          // ESC option
-                                            "", 0, 1);
+                                            QString(), 0, 1);
 
             if (insertionType == 0) // Default button, insert as image
             {
@@ -1034,7 +1025,7 @@ void Composer::insertCompletedNick(QModelIndex nickData)
     this->makeNormal();
 
     // Send signal for Publisher(), to add to the "To" field
-    emit nickInserted(nickId, nickName, nickUrl);
+    emit nickInserted(nickId, nickName, nickUrl, "to");
 }
 
 
@@ -1046,7 +1037,8 @@ void Composer::insertCompletedNick(QModelIndex nickData)
  */
 void Composer::cancelPost()
 {
-    int cancelConfirmed = 1;
+    int cancelConfirmed = 2;
+    int defaultButton = 1; // Initially planning for 2 buttons
 
     if (this->document()->isEmpty())
     {
@@ -1054,14 +1046,21 @@ void Composer::cancelPost()
     }
     else
     {
+        QString saveDraftString;
+        if (m_forPublisher)
+        {
+            saveDraftString = tr("Yes, but saving a &draft");
+            defaultButton = 2; // Since in this case there are 3 buttons
+        }
+
         cancelConfirmed = QMessageBox::question(this,
                                                 tr("Cancel message?"),
                                                 tr("Are you sure you want to "
                                                    "cancel this message?"),
                                                 tr("&Yes, cancel it"),
+                                                saveDraftString,
                                                 tr("&No"),
-                                                "", 1, 1);
-
+                                                defaultButton, defaultButton);
     }
 
 
@@ -1069,9 +1068,13 @@ void Composer::cancelPost()
     {
         this->erase();
 
-        // emit signal to make Publisher go back to minimum mode
+        // Emit signal to make Publisher go back to minimum mode
         emit editingCancelled();
 
         qDebug() << "Post cancelled";
     }
+    else if (cancelConfirmed == 1) // Save draft
+    {
+        emit cancelSavingDraftRequested();
+    }
 }
