@@ -23,7 +23,6 @@
 
 #include <QTextEdit>
 #include <QFocusEvent>
-#include <QHBoxLayout>
 #include <QLabel>
 #include <QPushButton>
 #include <QMenu>
@@ -69,9 +68,10 @@ signals:
     void focusReceived();
     void editingFinished();
     void editingCancelled();
+    void cancelSavingDraftRequested();
     void focusTitleRequested();
 
-    void nickInserted(QString id, QString name, QString url);
+    void nickInserted(QString id, QString name, QString url, QString listType);
 
     void fileDropped(QString fileUrl);
 
@@ -111,25 +111,23 @@ protected:
 
 
 private:
-    QHBoxLayout *mainLayout;
+    QPushButton *m_toolsButton;
+    QMenu *m_toolsMenu;
+    QMenu *m_symbolsMenu;
 
-    QPushButton *toolsButton;
-    QMenu *toolsMenu;
-    QMenu *symbolsMenu;
+    QAction *m_pastePlaintextAction;
 
-    QAction *pastePlaintextAction;
+    QMenu *m_customContextMenu;
 
-    QMenu *customContextMenu;
-
-    QCompleter *nickCompleter;
-    QTableView *popupTableView;
+    QCompleter *m_nickCompleter;
+    QTableView *m_popupTableView;
 
 
-    QString clickToPostText;
-    bool forPublisher;
+    QString m_clickToPostString;
+    bool m_forPublisher;
 
 
-    GlobalObject *globalObj;
+    GlobalObject *m_globalObject;
 };
 
 #endif // COMPOSER_H
