@@ -660,7 +660,7 @@ void ConfigDialog::createNotificationsPage(QSettings *settings)
     notificationOptionsLayout = new QFormLayout();
     notificationOptionsLayout->addRow(tr("Notification Style"),
                                       notificationStyleCombobox);
-    notificationOptionsLayout->addRow("", // Empty label on left to align with right column
+    notificationOptionsLayout->addRow(QString(), // Empty label on left to align with right column
                                       notificationsStatusLabel);
     notificationOptionsLayout->addRow(tr("Duration"),
                                       notificationDurationSpinbox);
