@@ -160,6 +160,7 @@ private:
     QSpinBox *snippetLimitSpinbox;
     QSpinBox *snippetLimitHlSpinbox;
     QComboBox *mfAvatarSizeCombobox;
+    QComboBox *mfIconTypeCombobox;
 
 
     // Page 5, posts options
@@ -204,6 +205,7 @@ private:
     QComboBox *notificationStyleCombobox;
     QSpinBox *notificationDurationSpinbox;
     QCheckBox *notificationPersistentCheckbox;
+    QCheckBox *notificationTaskbarCheckbox;
     QLabel *notificationsStatusLabel;
     QCheckBox *notifyNewTLCheckbox;
     QCheckBox *notifyHLTLCheckbox;
