@@ -25,76 +25,76 @@ ContactList::ContactList(PumpController *pumpController,
                          QString listType,
                          QWidget *parent) : QWidget(parent)
 {
-    this->pController = pumpController;
-    this->globalObj = globalObject;
+    m_pumpController = pumpController;
+    m_globalObject = globalObject;
 
 
     // Need action defined before its target lineedit, to show localized shortcut
-    goToFilterAction = new QAction(this);
-    goToFilterAction->setShortcut(QKeySequence("Ctrl+F"));
+    m_focusFilterAction = new QAction(this);
+    m_focusFilterAction->setShortcut(QKeySequence("Ctrl+F"));
 
     QString filterNote = tr("Type a partial name or ID to find a contact...")
                          + " ("
-                         + goToFilterAction->shortcut()
-                                            .toString(QKeySequence::NativeText)
+                         + m_focusFilterAction->shortcut()
+                                               .toString(QKeySequence::NativeText)
                          + ")";
 
-    this->filterLineEdit = new QLineEdit(this);
-    filterLineEdit->setPlaceholderText(filterNote);
-    filterLineEdit->setToolTip("<b></b>" + filterNote); // HTMLized for wordwrapping
-    filterLineEdit->setClearButtonEnabled(true);
-    connect(filterLineEdit, &QLineEdit::textChanged,
+    m_filterLineEdit = new QLineEdit(this);
+    m_filterLineEdit->setPlaceholderText(filterNote);
+    m_filterLineEdit->setToolTip("<b></b>" + filterNote); // HTMLized for wordwrapping
+    m_filterLineEdit->setClearButtonEnabled(true);
+    connect(m_filterLineEdit, &QLineEdit::textChanged,
             this, &ContactList::filterList);
 
-    connect(goToFilterAction, &QAction::triggered,
+    connect(m_focusFilterAction, &QAction::triggered,
             this, &ContactList::focusFilterField);
-    this->addAction(goToFilterAction);
+    this->addAction(m_focusFilterAction);
 
 
-    int iconSize = this->filterLineEdit->sizeHint().height(); // filterLineEdit->font().pixelSize()?
-    this->filterIcon = new QLabel(this);
-    filterIcon->setAlignment(Qt::AlignCenter);
-    filterIcon->setPixmap(QIcon::fromTheme("edit-find",
-                                           QIcon(":/images/menu-find.png"))
-                          .pixmap(iconSize, iconSize));
+    const int iconSize = m_filterLineEdit->sizeHint().height(); // filterLineEdit->font().pixelSize()?
+    m_filterIcon = new QLabel(this);
+    m_filterIcon->setAlignment(Qt::AlignCenter);
+    m_filterIcon->setPixmap(QIcon::fromTheme("edit-find",
+                                             QIcon(":/images/menu-find.png"))
+                                  .pixmap(iconSize, iconSize));
 
 
-    this->matchesLabel = new QLabel(this);
-    matchesLabel->hide();
+    m_matchesCountLabel = new QLabel(this);
+    m_matchesCountLabel->hide();
 
 
-    this->removeFilterButton = new QPushButton(QIcon::fromTheme("view-list-icons"),
-                                               tr("F&ull List"),
-                                               this);
-    removeFilterButton->setDisabled(true); // Disabled initially, until a search happens
-    connect(removeFilterButton, &QAbstractButton::clicked,
-            filterLineEdit, &QLineEdit::clear);
+    m_clearFilterButton = new QPushButton(QIcon::fromTheme("view-list-icons"),
+                                          tr("F&ull List"),
+                                          this);
+    m_clearFilterButton->setDisabled(true); // Disabled initially, until a search happens
+    connect(m_clearFilterButton, &QAbstractButton::clicked,
+            m_filterLineEdit, &QLineEdit::clear);
 
 
 
     // Layout
-    this->filterLayout = new QHBoxLayout();
-    filterLayout->addWidget(filterIcon, 0, Qt::AlignVCenter);
-    filterLayout->addWidget(filterLineEdit);
-    filterLayout->addWidget(matchesLabel);
-    filterLayout->addWidget(removeFilterButton);
+    m_contactsLayout = new QVBoxLayout();
 
-    this->contactsLayout = new QVBoxLayout();
+    m_contactsWidget = new QWidget(this);
+    m_contactsWidget->setLayout(m_contactsLayout);
 
-    this->contactsWidget = new QWidget(this);
-    contactsWidget->setLayout(contactsLayout);
-
-    this->contactsScrollArea = new QScrollArea(this);
-    contactsScrollArea->setWidget(contactsWidget);
-    contactsScrollArea->setWidgetResizable(true);
-    contactsScrollArea->setFrameStyle(QFrame::NoFrame);
-    contactsScrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
+    m_contactsScrollArea = new QScrollArea(this);
+    m_contactsScrollArea->setWidget(m_contactsWidget);
+    m_contactsScrollArea->setWidgetResizable(true);
+    m_contactsScrollArea->setFrameStyle(QFrame::NoFrame);
+    m_contactsScrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
 
 
-    this->mainLayout = new QVBoxLayout();
-    mainLayout->addWidget(contactsScrollArea);
-    mainLayout->addLayout(filterLayout);
-    this->setLayout(mainLayout);
+    m_filterLayout = new QHBoxLayout();
+    m_filterLayout->addWidget(m_filterIcon, 0, Qt::AlignVCenter);
+    m_filterLayout->addWidget(m_filterLineEdit);
+    m_filterLayout->addWidget(m_matchesCountLabel);
+    m_filterLayout->addWidget(m_clearFilterButton);
+
+    m_mainLayout = new QVBoxLayout();
+    m_mainLayout->addWidget(m_contactsScrollArea);
+    m_mainLayout->addLayout(m_filterLayout);
+    this->setLayout(m_mainLayout);
 
 
     // Add demo contacts
@@ -102,10 +102,10 @@ ContactList::ContactList(PumpController *pumpController,
     QVariantMap demoContactHometown;
     QVariantMap demoContactFollowed;
 
-    this->isFollowing = false;
+    m_isFollowing = false;
     if (listType == "following")
     {
-        isFollowing = true;
+        m_isFollowing = true;
 
         demoContactData.insert("displayName",  "Demo Contact");
         demoContactData.insert("id",           "democontact@pumpserver.org");
@@ -129,12 +129,13 @@ ContactList::ContactList(PumpController *pumpController,
 
 
     ASPerson *demoContactPerson = new ASPerson(demoContactData, this);
-    ContactCard *demoContactCard = new ContactCard(this->pController,
-                                                   this->globalObj,
-                                                   demoContactPerson, this);
-    this->contactsLayout->addWidget(demoContactCard);
-    this->contactsInList.append(demoContactCard);
-
+    ContactCard *demoContactCard = new ContactCard(m_pumpController,
+                                                   m_globalObject,
+                                                   demoContactPerson,
+                                                   this);
+    m_contactsLayout->addWidget(demoContactCard);
+    m_contactsInList.append(demoContactCard);
+    delete demoContactPerson;
 
     qDebug() << "ContactList created";
 }
@@ -148,18 +149,16 @@ ContactList::~ContactList()
 
 void ContactList::clearListContents()
 {
-    foreach (ContactCard *card, contactsInList)
+    foreach (ContactCard *card, m_contactsInList)
     {
-        this->contactsLayout->removeWidget(card);
+        m_contactsLayout->removeWidget(card);
         delete card;
     }
-    this->contactsInList.clear();
+    m_contactsInList.clear();
 
-    this->contactsStringForExport.clear();
-
-    if (this->isFollowing)
+    if (m_isFollowing)
     {
-        this->globalObj->clearNickCompletionModel();
+        m_globalObject->clearNickCompletionModel();
     }
 }
 
@@ -168,13 +167,12 @@ void ContactList::setListContents(QVariantList contactList)
 {
     qDebug() << "ContactList; Setting list contents";
 
-    QString contactInfoLineString;
     QStringList followingIdStringList;
 
     foreach (QVariant contact, contactList)
     {
         QVariantMap contactMap = contact.toMap();
-        if (!contactMap.keys().contains("id"))
+        if (!contactMap.keys().contains(QStringLiteral("id")))
         {
             /*
              * Temporary hack to fix user profiles when the list comes
@@ -188,19 +186,19 @@ void ContactList::setListContents(QVariantList contactList)
             contactMap.insert("id", id);
 
             QVariantMap followedMap;
-            followedMap.insert("followed", pController->userInFollowing(id));
+            followedMap.insert("followed", m_pumpController->userInFollowing(id));
             contactMap.insert("pump_io", followedMap);
 
-            id.remove("@" + pController->currentServerUrl());
+            id.remove("@" + m_pumpController->currentServerDomain());
             contactMap.insert("displayName", id);
 
-            contactMap.insert("url", pController->currentServerScheme()
-                                     + pController->currentServerUrl()
+            contactMap.insert("url", m_pumpController->currentServerScheme()
+                                     + m_pumpController->currentServerDomain()
                                      + "/" + id);
 
             QVariantMap hrefMap;
-            hrefMap.insert("href", pController->currentServerScheme()
-                                   + pController->currentServerUrl()
+            hrefMap.insert("href", m_pumpController->currentServerScheme()
+                                   + m_pumpController->currentServerDomain()
                                    + "/api/user/" + id + "/feed");
             QVariantMap outboxMap;
             outboxMap.insert("activity-outbox", hrefMap);
@@ -209,48 +207,49 @@ void ContactList::setListContents(QVariantList contactList)
 
 
         ASPerson *person = new ASPerson(contactMap, this);
-        ContactCard *contactCard = new ContactCard(this->pController,
-                                                   this->globalObj,
+        ContactCard *contactCard = new ContactCard(m_pumpController,
+                                                   m_globalObject,
                                                    person,
                                                    this);
-        this->contactsLayout->addWidget(contactCard);
-        this->contactsInList.append(contactCard);
+        m_contactsLayout->addWidget(contactCard);
+        m_contactsInList.append(contactCard);
 
-        // Info for the string list used when exporting
-        contactInfoLineString = person->getName()
-                              + "  <"
-                              + person->getId()
-                              + ">\n";
-        contactsStringForExport.append(contactInfoLineString);
-
-        if (this->isFollowing)
+        if (m_isFollowing)
         {
             // Add to internal following list for PumpController
             followingIdStringList.append(person->getId());
 
             // Add also to GlobalObject's model for nick completion
-            this->globalObj->addToNickCompletionModel(person->getId(),
-                                                      person->getNameWithFallback(),
-                                                      person->getUrl());
+            m_globalObject->addToNickCompletionModel(person->getId(),
+                                                     person->getNameWithFallback(),
+                                                     person->getUrl());
         }
-    } // end foreach
+
+        delete person;
+    } ///// End foreach
 
 
     // Batch of contacts added to list, add them also to the internal list
-    if (this->isFollowing)
+    if (m_isFollowing)
     {
-        this->pController->updateInternalFollowingIdList(followingIdStringList);
-        this->globalObj->sortNickCompletionModel(); // FIXME: should only sort when the whole list is done
+        m_pumpController->updateInternalFollowingIdList(followingIdStringList);
     }
 
-    this->filterLineEdit->clear(); // Unfilter the list
+    m_filterLineEdit->clear(); // Unfilter the list
 }
 
 
 
 QString ContactList::getContactsStringForExport()
 {
-    return this->contactsStringForExport;
+    QString allContactsString;
+
+    foreach (ContactCard *card, m_contactsInList)
+    {
+        allContactsString.append(card->getNameAndIdString() + "\n");
+    }
+
+    return allContactsString;
 }
 
 
@@ -267,7 +266,7 @@ void ContactList::filterList(QString filterText)
     if (!filterText.isEmpty())
     {
         int matchCount = 0;
-        foreach (ContactCard *card, contactsInList)
+        foreach (ContactCard *card, m_contactsInList)
         {
             if (card->getNameAndIdString().contains(filterText, Qt::CaseInsensitive))
             {
@@ -280,50 +279,49 @@ void ContactList::filterList(QString filterText)
             }
         }
 
-        matchesLabel->setText(QString("(%1)")
-                              .arg(QLocale::system().toString(matchCount)));
-        matchesLabel->show();
-        removeFilterButton->setEnabled(true);
+        m_matchesCountLabel->setText(QString("(%1)")
+                                     .arg(QLocale::system()
+                                                  .toString(matchCount)));
+        m_matchesCountLabel->show();
+        m_clearFilterButton->setEnabled(true);
     }
     else // If no filter at all, more optimized version showing all
     {
-        foreach (ContactCard *card, contactsInList)
+        foreach (ContactCard *card, m_contactsInList)
         {
             card->show();
         }
 
-        matchesLabel->setText("");
-        matchesLabel->hide();
-        removeFilterButton->setDisabled(true);
+        m_matchesCountLabel->setText(QString());
+        m_matchesCountLabel->hide();
+        m_clearFilterButton->setDisabled(true);
     }
 }
 
 
 void ContactList::addSingleContact(ASPerson *contact)
 {
-    ContactCard *card = new ContactCard(this->pController,
-                                        this->globalObj,
+    ContactCard *card = new ContactCard(m_pumpController,
+                                        m_globalObject,
                                         contact,
                                         this);
 
-    this->contactsLayout->insertWidget(0, card);
-    this->contactsInList.append(card);
+    m_contactsLayout->insertWidget(0, card);
+    m_contactsInList.append(card);
 
     emit contactCountChanged(1);
 
     // This check is actually unnecessary, since this slot is only called
-    if (this->isFollowing) // for the 'following' list
+    if (m_isFollowing) // for the 'following' list
     {
         QStringList contactsToAdd;
         contactsToAdd.append(contact->getId());
-        this->pController->updateInternalFollowingIdList(contactsToAdd);
+        m_pumpController->updateInternalFollowingIdList(contactsToAdd);
 
         // Add also to GlobalObject's model for nick completion
-        this->globalObj->addToNickCompletionModel(contact->getId(),
-                                                  contact->getNameWithFallback(),
-                                                  contact->getUrl());
-
-        this->globalObj->sortNickCompletionModel();
+        m_globalObject->addToNickCompletionModel(contact->getId(),
+                                                 contact->getNameWithFallback(),
+                                                 contact->getUrl());
     }
 
     // Other slots use this object, but this should be safe
@@ -333,7 +331,7 @@ void ContactList::addSingleContact(ASPerson *contact)
 
 void ContactList::removeSingleContact(ASPerson *contact)
 {
-    foreach (ContactCard *card, contactsInList)
+    foreach (ContactCard *card, m_contactsInList)
     {
         /* Ignore disabled cards, to avoid substracting more than once, in case
          * there were more ContactCards for the same contact, from following
@@ -345,10 +343,10 @@ void ContactList::removeSingleContact(ASPerson *contact)
         {
             emit contactCountChanged(-1);
 
-            this->pController->removeFromInternalFollowingList(contact->getId());
+            m_pumpController->removeFromInternalFollowingList(contact->getId());
 
             // Remove from GlobalObject's model for nick completion, too
-            this->globalObj->removeFromNickCompletionModel(contact->getId());
+            m_globalObject->removeFromNickCompletionModel(contact->getId());
 
             card->setDisabled(true);
         }
@@ -365,12 +363,12 @@ void ContactList::removeSingleContact(ASPerson *contact)
  */
 void ContactList::focusFilterField()
 {
-    if (this->filterLineEdit->hasFocus())
+    if (m_filterLineEdit->hasFocus())
     {
-        filterLineEdit->selectAll();
+        m_filterLineEdit->selectAll();
     }
     else
     {
-        filterLineEdit->setFocus();
+        m_filterLineEdit->setFocus();
     }
 }
