@@ -66,27 +66,25 @@ public slots:
 
 
 private:
-    PumpController *pController;
-    GlobalObject *globalObj;
+    QVBoxLayout *m_mainLayout;
+    QVBoxLayout *m_contactsLayout;
+    QHBoxLayout *m_filterLayout;
 
-    QVBoxLayout *mainLayout;
+    QWidget *m_contactsWidget;
+    QScrollArea *m_contactsScrollArea;
 
-    QAction *goToFilterAction;
-    QHBoxLayout *filterLayout;
-    QLabel *filterIcon;
-    QLineEdit *filterLineEdit;
-    QLabel *matchesLabel;
-    QPushButton *removeFilterButton;
+    QLabel *m_filterIcon;
+    QLineEdit *m_filterLineEdit;
+    QLabel *m_matchesCountLabel;
+    QPushButton *m_clearFilterButton;
+    QAction *m_focusFilterAction;
 
-    QVBoxLayout *contactsLayout;
-    QWidget *contactsWidget;
-    QScrollArea *contactsScrollArea;
 
-    QList<ContactCard *> contactsInList;
+    QList<ContactCard *> m_contactsInList;
+    bool m_isFollowing;
 
-    QString contactsStringForExport;
-
-    bool isFollowing;
+    PumpController *m_pumpController;
+    GlobalObject *m_globalObject;
 };
 
 #endif // CONTACTLIST_H
