@@ -24,171 +24,172 @@ ContactManager::ContactManager(PumpController *pumpController,
                                GlobalObject *globalObject,
                                QWidget *parent) : QWidget(parent)
 {
-    this->pController = pumpController;
-    this->globalObj = globalObject;
+    m_pumpController = pumpController;
+    m_globalObject = globalObject;
 
-    this->followingManually = false;
+    m_followingManually = false;
 
 
     // After receiving a contact list, update it
-    connect(pController, SIGNAL(contactListReceived(QString,QVariantList,int)),
-            this, SLOT(setContactListsContents(QString,QVariantList,int)));
+    connect(m_pumpController, &PumpController::contactListReceived,
+            this, &ContactManager::setContactListsContents);
 
     // After receiving the list of lists, update it
-    connect(pController, SIGNAL(listsListReceived(QVariantList)),
-            this, SLOT(setListsListContents(QVariantList)));
+    connect(m_pumpController, &PumpController::listsListReceived,
+            this, &ContactManager::setListsListContents);
 
     // After having checked if a webfinger ID is valid, follow it (or not)
-    connect(pController, SIGNAL(contactVerified(QString,int,bool,QString)),
-            this, SLOT(followContact(QString,int,bool,QString)));
+    connect(m_pumpController, &PumpController::contactVerified,
+            this, &ContactManager::followContact);
 
     // If a person can't be followed at the moment, re-enable widgets to try again
-    connect(pController, SIGNAL(cannotFollowNow(QString)),
-            this, SLOT(onCantFollowNow(QString)));
+    connect(m_pumpController, &PumpController::cannotFollowNow,
+            this, &ContactManager::onCantFollowNow);
 
 
-    mainLayout = new QVBoxLayout();
-    mainLayout->setAlignment(Qt::AlignTop);
+    m_mainLayout = new QVBoxLayout();
+    m_mainLayout->setAlignment(Qt::AlignTop);
 
 
     QString webfingerHelpMessage = tr("username@server.org or "
                                       "https://server.org/username");
 
-    topLayout = new QHBoxLayout();
-    enterAddressLabel = new QLabel(tr("&Enter address to follow:"), this);
-    enterAddressLabel->setToolTip("<b></b>"
+    m_topLayout = new QHBoxLayout();
+    m_enterAddressLabel = new QLabel(tr("&Enter address to follow:"), this);
+    m_enterAddressLabel->setToolTip("<b></b>"
                                   + webfingerHelpMessage); // HTML tags for wordwrap
     // Ensure it will get focus first, before addressLineEdit
-    enterAddressLabel->setFocusPolicy(Qt::StrongFocus);
+    m_enterAddressLabel->setFocusPolicy(Qt::StrongFocus);
 
-    addressLineEdit = new QLineEdit(this);
-    addressLineEdit->setPlaceholderText(webfingerHelpMessage);
-    addressLineEdit->setToolTip("<b></b>"
+    m_addressLineEdit = new QLineEdit(this);
+    m_addressLineEdit->setPlaceholderText(webfingerHelpMessage);
+    m_addressLineEdit->setToolTip("<b></b>"
                                 + webfingerHelpMessage);  // HTML tags to get wordwrap
-    addressLineEdit->setClearButtonEnabled(true);
-    connect(addressLineEdit, SIGNAL(textChanged(QString)),
-            this, SLOT(toggleFollowButton(QString)));
-    connect(addressLineEdit, SIGNAL(returnPressed()),
-            this, SLOT(validateContactId()));
+    m_addressLineEdit->setClearButtonEnabled(true);
+    connect(m_addressLineEdit, &QLineEdit::textChanged,
+            this, &ContactManager::toggleFollowButton);
+    connect(m_addressLineEdit, &QLineEdit::returnPressed,
+            this, &ContactManager::validateContactId);
 
-    enterAddressLabel->setBuddy(addressLineEdit);
+    m_enterAddressLabel->setBuddy(m_addressLineEdit);
 
 
-    followButton = new QPushButton(QIcon::fromTheme("list-add-user",
+    m_followButton = new QPushButton(QIcon::fromTheme("list-add-user",
                                                     QIcon(":/images/list-add.png")),
                                    tr("&Follow"),
                                    this);
-    followButton->setDisabled(true); // Disabled until an address is typed
-    connect(followButton, SIGNAL(clicked()),
-            this, SLOT(validateContactId()));
-    topLayout->addWidget(enterAddressLabel);
-    topLayout->addWidget(addressLineEdit);
-    topLayout->addWidget(followButton);
+    m_followButton->setDisabled(true); // Disabled until an address is typed
+    connect(m_followButton, &QAbstractButton::clicked,
+            this, &ContactManager::validateContactId);
+    m_topLayout->addWidget(m_enterAddressLabel);
+    m_topLayout->addWidget(m_addressLineEdit);
+    m_topLayout->addWidget(m_followButton);
 
-    mainLayout->addLayout(topLayout);
-    mainLayout->addSpacing(4);
+    m_mainLayout->addLayout(m_topLayout);
+    m_mainLayout->addSpacing(4);
 
 
     // Widgets for list of 'following' and 'followers'
-    this->followingWidget = new ContactList(this->pController,
-                                            this->globalObj,
-                                            "following",
-                                            this);
-    connect(pController, SIGNAL(contactFollowed(ASPerson*)),
-            followingWidget, SLOT(addSingleContact(ASPerson*)));
-    connect(pController, SIGNAL(contactUnfollowed(ASPerson*)),
-            followingWidget, SLOT(removeSingleContact(ASPerson*)));
+    m_followingWidget = new ContactList(m_pumpController,
+                                        m_globalObject,
+                                        QStringLiteral("following"),
+                                        this);
+    connect(m_pumpController, &PumpController::contactFollowed,
+            m_followingWidget, &ContactList::addSingleContact);
+    connect(m_pumpController, &PumpController::contactUnfollowed,
+            m_followingWidget, &ContactList::removeSingleContact);
 
-    connect(followingWidget, SIGNAL(contactCountChanged(int)),
-            this, SLOT(changeFollowingCount(int)));
+    connect(m_followingWidget, &ContactList::contactCountChanged,
+            this, &ContactManager::changeFollowingCount);
 
 
-    this->followersWidget = new ContactList(this->pController,
-                                            this->globalObj,
-                                            "followers",
-                                            this);
+    m_followersWidget = new ContactList(m_pumpController,
+                                        m_globalObject,
+                                        QStringLiteral("followers"),
+                                        this);
 
 
     // Widget for the list of 'person lists'
-    this->listsManager = new ListsManager(this->pController, this);
-    listsScrollArea = new QScrollArea(this);
-    listsScrollArea->setWidget(this->listsManager);
-    listsScrollArea->setWidgetResizable(true);
-    listsScrollArea->setFrameStyle(QFrame::NoFrame);
+    m_listsManager = new ListsManager(m_pumpController, this);
+    m_listsScrollArea = new QScrollArea(this);
+    m_listsScrollArea->setWidget(m_listsManager);
+    m_listsScrollArea->setWidgetResizable(true);
+    m_listsScrollArea->setFrameStyle(QFrame::NoFrame);
 
 
     // Widget for the list of site users; users from your own server
-    this->siteUsersList = new SiteUsersList(this->pController,
-                                            this->globalObj,
-                                            this);
+    m_siteUsersList = new SiteUsersList(m_pumpController,
+                                        m_globalObject,
+                                        this);
 
     // Options menu
-    optionsMenu = new QMenu("*options-menu*", this);
-    optionsMenu->addAction(QIcon::fromTheme("view-refresh",
-                                            QIcon(":/images/menu-refresh.png")),
-                           tr("Reload Followers"),
-                           this,
-                           SLOT(refreshFollowers()));
-    optionsMenu->addAction(QIcon::fromTheme("view-refresh",
-                                            QIcon(":/images/menu-refresh.png")),
-                           tr("Reload Following"),
-                           this,
-                           SLOT(refreshFollowing()));
-    optionsMenu->addSeparator();
-    optionsMenu->addAction(QIcon::fromTheme("document-export",
-                                            QIcon(":/images/button-download.png")),
-                           tr("Export Followers"),
-                           this,
-                           SLOT(exportFollowers()));
-    optionsMenu->addAction(QIcon::fromTheme("document-export",
-                                            QIcon(":/images/button-download.png")),
-                           tr("Export Following"),
-                           this,
-                           SLOT(exportFollowing()));
-    optionsMenu->addSeparator();
-    optionsMenu->addAction(QIcon::fromTheme("view-refresh",
-                                            QIcon(":/images/menu-refresh.png")),
-                           tr("Reload Lists"),
-                           this,
-                           SLOT(refreshPersonLists()));
+    m_optionsMenu = new QMenu(QStringLiteral("*options-menu*"), this);
+    m_optionsMenu->addAction(QIcon::fromTheme("view-refresh",
+                                              QIcon(":/images/menu-refresh.png")),
+                             tr("Reload Followers"),
+                             this,
+                             SLOT(refreshFollowers()));
+    m_optionsMenu->addAction(QIcon::fromTheme("view-refresh",
+                                              QIcon(":/images/menu-refresh.png")),
+                             tr("Reload Following"),
+                             this,
+                             SLOT(refreshFollowing()));
+    m_optionsMenu->addSeparator();
+    m_optionsMenu->addAction(QIcon::fromTheme("document-export",
+                                              QIcon(":/images/button-download.png")),
+                             tr("Export Followers"),
+                             this,
+                             SLOT(exportFollowers()));
+    m_optionsMenu->addAction(QIcon::fromTheme("document-export",
+                                              QIcon(":/images/button-download.png")),
+                             tr("Export Following"),
+                             this,
+                             SLOT(exportFollowing()));
+    m_optionsMenu->addSeparator();
+    m_optionsMenu->addAction(QIcon::fromTheme("view-refresh",
+                                              QIcon(":/images/menu-refresh.png")),
+                             tr("Reload Lists"),
+                             this,
+                             SLOT(refreshPersonLists()));
 
 
-    optionsButton = new QPushButton(QIcon::fromTheme("configure",
-                                                     QIcon(":/images/button-configure.png")),
-                                    "", this);
-    optionsButton->setMenu(optionsMenu);
+    m_optionsButton = new QPushButton(QIcon::fromTheme("configure",
+                                                       QIcon(":/images/button-configure.png")),
+                                      QString(),
+                                      this);
+    m_optionsButton->setMenu(m_optionsMenu);
 
 
-    this->tabWidget = new QTabWidget(this);
-    tabWidget->addTab(followersWidget,
-                      QIcon::fromTheme("meeting-observer",
-                                       QIcon(":/images/no-avatar.png")),
-                      "*followers*");
-    tabWidget->addTab(followingWidget,
-                      QIcon::fromTheme("meeting-participant",
-                                       QIcon(":/images/no-avatar.png")),
-                      "*following*");
-    tabWidget->addTab(listsScrollArea,
-                      QIcon::fromTheme("preferences-contact-list",
-                                       QIcon(":/images/button-edit.png")),
-                      "*lists*");
-    tabWidget->addTab(siteUsersList,
-                      QIcon::fromTheme("system-users",
-                                       QIcon(":/images/no-avatar.png")),
-                      tr("&Neighbors"));
-    tabWidget->setCornerWidget(this->optionsButton);
+    m_tabWidget = new QTabWidget(this);
+    m_tabWidget->addTab(m_followersWidget,
+                        QIcon::fromTheme("meeting-observer",
+                                         QIcon(":/images/no-avatar.png")),
+                        QString());
+    m_tabWidget->addTab(m_followingWidget,
+                        QIcon::fromTheme("meeting-participant",
+                                         QIcon(":/images/no-avatar.png")),
+                        QString());
+    m_tabWidget->addTab(m_listsScrollArea,
+                        QIcon::fromTheme("preferences-contact-list",
+                                         QIcon(":/images/button-edit.png")),
+                        QString());
+    m_tabWidget->addTab(m_siteUsersList,
+                        QIcon::fromTheme("system-users",
+                                         QIcon(":/images/button-users.png")),
+                        tr("&Neighbors"));
+    m_tabWidget->setCornerWidget(m_optionsButton);
 
 
 
 
-    this->followersCount = 0;
-    this->followingCount = 0;
-    this->listsCount = 0;
+    m_followersCount = 0;
+    m_followingCount = 0;
+    m_listsCount = 0;
     this->setTabLabels();
 
 
-    mainLayout->addWidget(tabWidget);
-    this->setLayout(mainLayout);
+    m_mainLayout->addWidget(m_tabWidget);
+    this->setLayout(m_mainLayout);
 
     qDebug() << "Contact manager created";
 }
@@ -204,18 +205,18 @@ ContactManager::~ContactManager()
 
 void ContactManager::setTabLabels()
 {
-    this->tabWidget->setTabText(0, tr("Follo&wers")
-                                   + QString(" (%1)")
-                                     .arg(QLocale::system()
-                                          .toString(this->followersCount)));
+    m_tabWidget->setTabText(0, tr("Follo&wers")
+                               + QString(" (%1)")
+                                 .arg(QLocale::system()
+                                              .toString(m_followersCount)));
 
-    this->tabWidget->setTabText(1, tr("Followin&g")
-                                   + QString(" (%1)")
-                                     .arg(QLocale::system()
-                                          .toString(this->followingCount)));
+    m_tabWidget->setTabText(1, tr("Followin&g")
+                               + QString(" (%1)")
+                                 .arg(QLocale::system()
+                                              .toString(m_followingCount)));
 
-    this->tabWidget->setTabText(2, tr("&Lists")
-                                + QString(" (%1)").arg(this->listsCount)); // Not worth localizing
+    m_tabWidget->setTabText(2, tr("&Lists")
+                               + QString(" (%1)").arg(m_listsCount)); // Not worth localizing
 }
 
 
@@ -233,14 +234,14 @@ void ContactManager::exportContactsToFile(QString listType)
                     tr("Export list of 'followers' to a file");
 
     QString suggestedFilename = "dianara-"
-                                + pController->currentUsername()
+                                + m_pumpController->currentUsername()
                                 + "-"
                                 + listType;
 
     QString filename = QFileDialog::getSaveFileName(this, dialogTitle,
                                                     QDir::homePath() + "/"
                                                     + suggestedFilename,
-                                                    "").trimmed();
+                                                    QString()).trimmed();
 
     if (filename.isEmpty()) // If dialog was cancelled, do nothing
     {
@@ -251,28 +252,42 @@ void ContactManager::exportContactsToFile(QString listType)
     qDebug() << "Exporting to:"  << filename;
 
     QFile exportFile(filename);
-    exportFile.open(QIODevice::WriteOnly);
-
-    if (listType == "following")
+    if (exportFile.open(QIODevice::WriteOnly))
     {
-        exportFile.write(this->followingWidget->getContactsStringForExport()
+        if (listType == "following")
+        {
+            exportFile.write(m_followingWidget->getContactsStringForExport()
                                                .toLocal8Bit());
-    }
-    else // "followers"
-    {
-        exportFile.write(this->followersWidget->getContactsStringForExport()
+        }
+        else // "followers"
+        {
+            exportFile.write(m_followersWidget->getContactsStringForExport()
                                                .toLocal8Bit());
-    }
+        }
 
-    exportFile.close();
+        exportFile.close();
+    }
+    else
+    {
+        QMessageBox::critical(this,
+                              tr("Error"),
+                              tr("Cannot export to this file:")
+                              + "\n"
+                              + filename
+                              + "\n\n"
+                              + tr("Please enter another file name, "
+                                   "or choose a different folder."));
+
+        qDebug() << "Cannot write to that file!";
+    }
 }
 
 
 
 void ContactManager::enableManualFollowWidgets()
 {
-    this->addressLineEdit->setEnabled(true);
-    this->followButton->setEnabled(!addressLineEdit->text().isEmpty());
+    m_addressLineEdit->setEnabled(true);
+    m_followButton->setEnabled(!m_addressLineEdit->text().isEmpty());
 }
 
 
@@ -292,33 +307,33 @@ void ContactManager::setContactListsContents(QString listType,
     {
         if (totalReceivedCount <= 200) // Only for the first batch
         {
-            this->followingWidget->clearListContents();
-            followingCount = 0;
+            m_followingWidget->clearListContents();
+            m_followingCount = 0;
         }
-        followingWidget->setListContents(contactList);
+        m_followingWidget->setListContents(contactList);
 
-        if (totalReceivedCount < pController->currentFollowingCount())
+        if (totalReceivedCount < m_pumpController->currentFollowingCount())
         {
-            pController->getContactList(listType, totalReceivedCount);
+            m_pumpController->getContactList(listType, totalReceivedCount);
         }
 
-        this->followingCount += contactList.size();
+        m_followingCount += contactList.size();
     }
     else
     {
         if (totalReceivedCount <= 200)
         {
-            this->followersWidget->clearListContents();
-            followersCount = 0;
+            m_followersWidget->clearListContents();
+            m_followersCount = 0;
         }
-        followersWidget->setListContents(contactList);
+        m_followersWidget->setListContents(contactList);
 
-        if (totalReceivedCount < pController->currentFollowersCount())
+        if (totalReceivedCount < m_pumpController->currentFollowersCount())
         {
-            pController->getContactList(listType, totalReceivedCount);
+            m_pumpController->getContactList(listType, totalReceivedCount);
         }
 
-        this->followersCount += contactList.size();
+        m_followersCount += contactList.size();
     }
 
 
@@ -334,18 +349,18 @@ void ContactManager::setContactListsContents(QString listType,
  */
 void ContactManager::setListsListContents(QVariantList listsList)
 {
-    this->listsCount = listsList.count();
+    m_listsCount = listsList.count();
     // Update tab labels with number of following or followers, which were updated before
     this->setTabLabels();
 
 
-    this->listsManager->setListsList(listsList);
+    m_listsManager->setListsList(listsList);
 }
 
 
 void ContactManager::changeFollowingCount(int difference)
 {
-    this->followingCount += difference; // FIXME: pumpController should be notified
+    m_followingCount += difference; // FIXME: pumpController should be notified
 
     this->setTabLabels();
 
@@ -353,7 +368,7 @@ void ContactManager::changeFollowingCount(int difference)
     // (following someone from an AvatarButton menu)
     if (!this->isVisible())
     {
-        this->tabWidget->setCurrentIndex(1);
+        m_tabWidget->setCurrentIndex(1);
     }
 }
 
@@ -366,7 +381,7 @@ void ContactManager::changeFollowingCount(int difference)
 void ContactManager::refreshFollowing()
 {
     qDebug() << "Refreshing list of Following...";
-    this->pController->getContactList("following");
+    m_pumpController->getContactList("following");
 }
 
 
@@ -377,7 +392,7 @@ void ContactManager::refreshFollowing()
 void ContactManager::refreshFollowers()
 {
     qDebug() << "Refreshing list of Followers...";
-    this->pController->getContactList("followers");
+    m_pumpController->getContactList("followers");
 }
 
 
@@ -406,7 +421,7 @@ void ContactManager::exportFollowers()
 void ContactManager::refreshPersonLists()
 {
     qDebug() << "Refreshing list of person lists...";
-    this->pController->getListsList();
+    m_pumpController->getListsList();
 }
 
 
@@ -419,11 +434,11 @@ void ContactManager::toggleFollowButton(QString currentAddress)
 {
     if (currentAddress.isEmpty())
     {
-        this->followButton->setDisabled(true);
+        m_followButton->setDisabled(true);
     }
     else
     {
-        this->followButton->setEnabled(true);
+        m_followButton->setEnabled(true);
     }
 }
 
@@ -440,7 +455,7 @@ void ContactManager::toggleFollowButton(QString currentAddress)
  */
 void ContactManager::validateContactId()
 {
-    QString address = this->addressLineEdit->text().trimmed();
+    QString address = m_addressLineEdit->text().trimmed();
     bool validAddress = false;
 
     qDebug() << "ContactManager::followContact(); Address entered:" << address;
@@ -467,21 +482,21 @@ void ContactManager::validateContactId()
     else
     {
         qDebug() << "Invalid webfinger address!";
-        this->addressLineEdit->setFocus();
+        m_addressLineEdit->setFocus();
     }
 
 
     if (validAddress)
     {
-        this->followingManually = true;
-        this->followingAddress = address;
+        m_followingManually = true;
+        m_followingAddress = address;
 
-        this->tabWidget->setFocus(); // Take focus away from the widgets that will be disabled now
+        m_tabWidget->setFocus(); // Take focus away from the widgets that will be disabled now
 
-        this->addressLineEdit->setDisabled(true);
-        this->followButton->setDisabled(true);
+        m_addressLineEdit->setDisabled(true);
+        m_followButton->setDisabled(true);
 
-        this->pController->followContact(address);
+        m_pumpController->followContact(address);
     }
 }
 
@@ -562,17 +577,17 @@ void ContactManager::followContact(QString userId, int httpCode,
                         "<br>",
                       tr("Yes, follow anyway"),
                       tr("No, cancel"),
-                      "", 1, 1);
+                      QString(), 1, 1);
 
         if (choice == 1)
         {
-            if (followingManually && userId == this->followingAddress)
+            if (m_followingManually && userId == m_followingAddress)
             {
                 this->enableManualFollowWidgets();
-                this->addressLineEdit->setFocus(); // Re-focus to try again, maybe
+                m_addressLineEdit->setFocus(); // Re-focus to try again, maybe
 
-                this->followingManually = false;
-                this->followingAddress.clear();
+                m_followingManually = false;
+                m_followingAddress.clear();
             }
 
             return;
@@ -580,31 +595,31 @@ void ContactManager::followContact(QString userId, int httpCode,
     }
 
     qDebug() << "About to follow this address:" << userId;
-    this->globalObj->setStatusMessage(tr("About to follow %1...")
-                                      .arg("'" + userId + "'"));
-    this->pController->followVerifiedContact(userId);
+    m_globalObject->setStatusMessage(tr("About to follow %1...")
+                                     .arg("'" + userId + "'"));
+    m_pumpController->followVerifiedContact(userId);
 
-    if (followingManually && userId == this->followingAddress)
+    if (m_followingManually && userId == m_followingAddress)
     {
-        this->enableManualFollowWidgets();
-        this->addressLineEdit->clear(); // Which will disable Follow button again
+        enableManualFollowWidgets();
+        m_addressLineEdit->clear(); // Which will disable Follow button again
 
-        this->followingManually = false;
-        this->followingAddress.clear();
+        m_followingManually = false;
+        m_followingAddress.clear();
 
         // Activate 'Following' tab
-        this->tabWidget->setFocus();
-        this->tabWidget->setCurrentIndex(1);
+        m_tabWidget->setFocus();
+        m_tabWidget->setCurrentIndex(1);
     }
 }
 
 
 void ContactManager::onCantFollowNow(QString userId)
 {
-    if (followingManually && userId == this->followingAddress)
+    if (m_followingManually && userId == m_followingAddress)
     {
-        this->enableManualFollowWidgets();
-        this->addressLineEdit->setFocus();
+        enableManualFollowWidgets();
+        m_addressLineEdit->setFocus();
     }
 }
 
