@@ -39,8 +39,8 @@ class DownloadWidget : public QFrame
     Q_OBJECT
 
 public:
-    explicit DownloadWidget(QString fileUrl,
-                            QString suggestedFN,
+    explicit DownloadWidget(QString m_fileUrl,
+                            QString suggestedFilename,
                             PumpController *pumpController,
                             QWidget *parent = 0);
     ~DownloadWidget();
@@ -63,20 +63,20 @@ public slots:
 
 
 private:
-    QHBoxLayout *mainLayout;
-    QLabel *infoLabel;
-    QPushButton *openButton;
-    QProgressBar *progressBar;
-    QPushButton *downloadButton;
-    QPushButton *cancelButton;
+    QHBoxLayout *m_layout;
+    QLabel *m_infoLabel;
+    QPushButton *m_openButton;
+    QProgressBar *m_progressBar;
+    QPushButton *m_downloadButton;
+    QPushButton *m_cancelButton;
 
-    QString fileUrl;
-    QString suggestedFilename;
+    QString m_fileUrl;
+    QString m_suggestedFilename;
 
-    PumpController *pController;
-    QNetworkReply *networkReply;
-    QFile downloadedFile;
-    bool downloading;
+    PumpController *m_pumpController;
+    QNetworkReply *m_networkReply;
+    QFile m_downloadedFile;
+    bool m_downloading;
 };
 
 #endif // DOWNLOADWIDGET_H
