@@ -53,10 +53,10 @@ public slots:
 
 
 private:
-    QList<QStringList> filteredContent;
-    QList<QStringList> filteredAuthor;
-    QList<QStringList> filteredGenerator;
-    QList<QStringList> filteredDescription;
+    QList<QStringList> m_filteredContent;
+    QList<QStringList> m_filteredAuthor;
+    QList<QStringList> m_filteredGenerator;
+    QList<QStringList> m_filteredDescription;
 };
 
 #endif // FILTERCHECKER_H
