@@ -72,33 +72,32 @@ protected:
 
 
 private:
-    QVBoxLayout *mainLayout;
-    QHBoxLayout *topLayout;
-    QGroupBox *newFilterGroupBox;
-    QVBoxLayout *middleLayout;
-    QGroupBox *currentFiltersGroupBox;
-    QHBoxLayout *bottomLayout;
+    QVBoxLayout *m_mainLayout;
+    QHBoxLayout *m_topLayout;
+    QGroupBox *m_newFilterGroupBox;
+    QVBoxLayout *m_middleLayout;
+    QGroupBox *m_currentFiltersGroupBox;
+    QHBoxLayout *m_bottomLayout;
+
+    QAction *m_closeAction;
 
 
-    QAction *closeAction;
+    QLabel *m_explanationLabel;
 
-    QLabel *explanationLabel;
+    QComboBox *m_actionTypeComboBox;
+    QComboBox *m_filterTypeComboBox;
+    QLineEdit *m_filterWordsLineEdit;
+    QPushButton *m_addFilterButton;
 
-    QComboBox *actionTypeComboBox;
-    QComboBox *filterTypeComboBox;
-    QLineEdit *filterWordsLineEdit;
-    QPushButton *addFilterButton;
+    QListWidget *m_filtersListWidget;
+    QPushButton *m_removeFilterButton;
 
-    QListWidget *currentFiltersListWidget;
-    QPushButton *removeFilterButton;
+    QPushButton *m_saveButton;
+    QPushButton *m_cancelButton;
 
-    QPushButton *saveButton;
-    QPushButton *cancelButton;
 
-    QString ruleString;
-    QVariantList filtersList;
-
-    FilterChecker *fChecker;
+    QString m_ruleTemplateString;
+    FilterChecker *m_filterChecker;
 };
 
 #endif // FILTEREDITOR_H
