@@ -62,26 +62,27 @@ FilterMatchesWidget::FilterMatchesWidget(QVariantMap filterMatchesMap,
     }
 
 
-    this->contentLabel = new QLabel("<style>span "
-                                    "{ font-weight: bold;                              "
-                                    "  color: palette(highlighted-text);               "
-                                    "  background-color: qlineargradient(spread:pad,   "
-                                    "                     x1:0, y1:0, x2:1, y2:0,      "
-                                    "                     stop:0   rgba(0, 0, 0, 0),   "
-                                    "                     stop:0.1 palette(highlight), "
-                                    "                     stop:0.9 palette(highlight), "
-                                    "                     stop:1   rgba(0, 0, 0, 0));  "
-                                    "}"
-                                    "</style>"
-                                    + filterMatchInfoString, this);
-    contentLabel->setWordWrap(true);
-    contentLabel->setAlignment(Qt::AlignCenter);
+    m_contentLabel = new QLabel("<style>span "
+                                "{ font-weight: bold;                              "
+                                "  color: palette(highlighted-text);               "
+                                "  background-color: qlineargradient(spread:pad,   "
+                                "                     x1:0, y1:0, x2:1, y2:0,      "
+                                "                     stop:0   rgba(0, 0, 0, 0),   "
+                                "                     stop:0.1 palette(highlight), "
+                                "                     stop:0.9 palette(highlight), "
+                                "                     stop:1   rgba(0, 0, 0, 0));  "
+                                "}"
+                                "</style>"
+                                + filterMatchInfoString,
+                                this);
+    m_contentLabel->setWordWrap(true);
+    m_contentLabel->setAlignment(Qt::AlignCenter);
 
 
 
-    this->mainLayout = new QHBoxLayout();
-    mainLayout->addWidget(contentLabel);
-    this->setLayout(mainLayout);
+    m_layout = new QHBoxLayout();
+    m_layout->addWidget(m_contentLabel);
+    this->setLayout(m_layout);
 
     qDebug() << "FilterMatchesWidget created";
 }
