@@ -44,12 +44,13 @@ public:
 
 signals:
 
+
 public slots:
 
 
 private:
-    QHBoxLayout *mainLayout;
-    QLabel *contentLabel;
+    QHBoxLayout *m_layout;
+    QLabel *m_contentLabel;
 
 };
 
