@@ -44,47 +44,47 @@ class FirstRunWizard : public QWidget
     Q_OBJECT
 
 public:
-    explicit FirstRunWizard(AccountDialog *accountDlg,
-                            ProfileEditor *profileEd,
-                            ConfigDialog *configDlg,
-                            HelpWidget *helpWdg,
-                            GlobalObject *globalObj,
+    explicit FirstRunWizard(AccountDialog *accountDialog,
+                            ProfileEditor *profileEditor,
+                            ConfigDialog *configDialog,
+                            HelpWidget *helpWidget,
+                            GlobalObject *globalObject,
                             QWidget *parent = 0);
     ~FirstRunWizard();
 
 signals:
 
+
 public slots:
 
+
 protected:
     virtual void closeEvent(QCloseEvent *event);
 
 
 private:
-    QVBoxLayout *mainLayout;
-    QHBoxLayout *bottomLayout;
+    QVBoxLayout *m_mainLayout;
+    QHBoxLayout *m_bottomLayout;
 
-    QLabel *explanationLabel;
+    QLabel *m_explanationLabel;
+    QPushButton *m_configAccountButton;
 
-    QPushButton *configureAccountButton;
+    QLabel *m_editProfileLabel;
+    QPushButton *m_editProfileButton;
 
-    QLabel *editProfileLabel;
-    QPushButton *editProfileButton;
+    QLabel *m_publicPostsLabel;
+    QCheckBox *m_publicPostsCheckbox;
 
-    QLabel *publicPostsLabel;
-    QCheckBox *publicPostsCheckbox;
+    QPushButton *m_helpButton;
 
-    QPushButton *helpButton;
-
-    QCheckBox *showAgainCheckbox;
-    QPushButton *closeButton;
+    QCheckBox *m_showAgainCheckbox;
+    QPushButton *m_closeButton;
 
     // Widgets from MainWindow
-    AccountDialog *accountDialog;
-    ProfileEditor *profileEditor;
-    ConfigDialog *configDialog;
-    HelpWidget *helpWidget;
-    GlobalObject *globalObject;
+    AccountDialog *m_accountDialog;
+    ProfileEditor *m_profileEditor;
+    ConfigDialog *m_configDialog;
+    HelpWidget *m_helpWidget;
 };
 
 #endif // FIRSTRUNWIZARD_H
