@@ -28,36 +28,36 @@ FontPicker::FontPicker(QString description,
     initialFont.fromString(initialFontString);
     if (initialFont.family().isEmpty()) // Invalid, so use standard font
     {
-        this->currentFont = QFont();
+        m_currentFont = QFont();
     }
     else // Valid, so use it
     {
-        this->currentFont = initialFont;
+        m_currentFont = initialFont;
     }
 
 
-    this->descriptionLabel = new QLabel(description, this);
-    descriptionLabel->setWordWrap(true);
+    m_descriptionLabel = new QLabel(description, this);
+    m_descriptionLabel->setWordWrap(true);
 
 
-    this->sampleLineEdit = new QLineEdit("AaBbCcDdEeFf", this);
-    sampleLineEdit->setReadOnly(true);
+    m_sampleLineEdit = new QLineEdit(this);
+    m_sampleLineEdit->setReadOnly(true);
     updateFontSample();
 
 
-    this->button = new QPushButton(QIcon::fromTheme("list-add-font",
-                                                    QIcon(":/images/list-add.png")),
-                                   tr("Change..."),
-                                   this);
-    connect(button, &QAbstractButton::clicked,
+    m_button = new QPushButton(QIcon::fromTheme("list-add-font",
+                                                QIcon(":/images/list-add.png")),
+                               tr("Change..."),
+                               this);
+    connect(m_button, &QAbstractButton::clicked,
             this, &FontPicker::selectFont);
 
 
-    this->layout = new QHBoxLayout();
-    layout->addWidget(descriptionLabel, 2);
-    layout->addWidget(sampleLineEdit,   5);
-    layout->addWidget(button,           1);
-    this->setLayout(layout);
+    m_layout = new QHBoxLayout();
+    m_layout->addWidget(m_descriptionLabel, 2);
+    m_layout->addWidget(m_sampleLineEdit,   5);
+    m_layout->addWidget(m_button,           1);
+    this->setLayout(m_layout);
 
     qDebug() << "FontPicker created";
 }
@@ -70,18 +70,18 @@ FontPicker::~FontPicker()
 
 void FontPicker::updateFontSample()
 {
-    this->sampleLineEdit->setFont(currentFont);
-    this->sampleLineEdit->setText(currentFont.toString());
-    this->sampleLineEdit->setCursorPosition(0);
+    m_sampleLineEdit->setFont(m_currentFont);
+    m_sampleLineEdit->setText(m_currentFont.toString());
+    m_sampleLineEdit->setCursorPosition(0);
 }
 
+
 QString FontPicker::getFontInfo()
 {
-    return this->currentFont.toString();
+    return m_currentFont.toString();
 }
 
 
-
 ////////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////// SLOTS /////////////////////////////////////
 ////////////////////////////////////////////////////////////////////////////////
@@ -92,13 +92,12 @@ void FontPicker::selectFont()
     bool fontOk = false;
 
     QFont newFont = QFontDialog::getFont(&fontOk,
-                                         this->currentFont,
+                                         m_currentFont,
                                          this,
                                          tr("Choose a font"));
-
     if (fontOk)
     {
-        this->currentFont = newFont;
+        m_currentFont = newFont;
         updateFontSample();
     }
 }
