@@ -48,19 +48,21 @@ public:
 
 signals:
 
+
 public slots:
     void selectFont();
 
 
 private:
-    QHBoxLayout *layout;
+    QHBoxLayout *m_layout;
 
-    QLabel *descriptionLabel;
-    QLineEdit *sampleLineEdit;
+    QLabel *m_descriptionLabel;
+    QLineEdit *m_sampleLineEdit;
 
-    QPushButton *button;
+    QPushButton *m_button;
 
-    QFont currentFont;
+
+    QFont m_currentFont;
 };
 
 #endif // FONTPICKER_H
