@@ -454,6 +454,16 @@ bool GlobalObject::getHideInTray()
 ///////////////////////////////////////////////////////////////////////////////
 
 
+void GlobalObject::setDataDirectory(QString dataDir)
+{
+    this->dataDirectory = dataDir;
+}
+
+QString GlobalObject::getDataDirectory()
+{
+    return this->dataDirectory;
+}
+
 
 void GlobalObject::createMessageForContact(QString id, QString name,
                                            QString url)
@@ -521,7 +531,7 @@ void GlobalObject::removeFromNickCompletionModel(QString id)
     qDebug() << "GlobalObject::removeFromNickCompletionModel()" << id;
 
     QList<QStandardItem *> allNicks;
-    allNicks = nickCompletionModel->findItems("", Qt::MatchContains);
+    allNicks = nickCompletionModel->findItems(QString(), Qt::MatchContains);
 
     foreach (QStandardItem *item, allNicks)
     {
@@ -554,6 +564,29 @@ void GlobalObject::sortNickCompletionModel()
     this->filterCompletionModel->sort(0);
 }
 
+/*
+ * Return a Display Name + URL pair for a given user ID,
+ * to be used when restoring audience from a draft
+ *
+ */
+QPair<QString, QString> GlobalObject::getDataForNick(QString id)
+{
+    QList<QStandardItem *> matchingNicks;
+    matchingNicks = nickCompletionModel->findItems(id, Qt::MatchExactly, 1);
+    if (matchingNicks.isEmpty())
+    {
+        // Return basic data for invalid case
+        return QPair<QString,QString>(id, QString());
+    }
+
+    QStandardItem *item = nickCompletionModel->item(matchingNicks.first()->row(),
+                                                    0);
+    // FIXME: add some error control
+
+    return QPair<QString,QString>(item->text(),
+                                  item->data(Qt::UserRole + 2).toString());
+}
+
 
 /*
  * Change status bar message in main window
