@@ -126,6 +126,8 @@ public:
 
     ///////////////////////////////////////////////////////////////////////////
 
+    void setDataDirectory(QString dataDir);
+    QString getDataDirectory();
 
     void createMessageForContact(QString id, QString name, QString url);
 
@@ -142,6 +144,7 @@ public:
     void removeFromNickCompletionModel(QString id);
     void clearNickCompletionModel();
     void sortNickCompletionModel();
+    QPair<QString,QString> getDataForNick(QString id);
 
     void setStatusMessage(QString message);
     void logMessage(QString message, QString url="");
@@ -241,6 +244,8 @@ private:
     //////////////////////////////////////////////////////////////////////////
 
     // Other stuff
+    QString dataDirectory;
+
     QStandardItemModel *nickCompletionModel;
     QSortFilterProxyModel *filterCompletionModel;
     int timelineHeight;
