@@ -38,12 +38,11 @@ public:
     ~HClabel();
 
     void setHighlighted(bool highlighted);
+    void setExpanded(bool isExpanded);
 
     void setBaseText(QString text);
     void setExtendedText(QString text);
 
-    void setExpanded(bool isExpanded);
-
 
 signals:
     void clicked();
@@ -58,12 +57,12 @@ protected:
 
 
 private:
-    QString baseText;
-    QString extendedText;
+    QString m_baseText;
+    QString m_extendedText;
 
-    bool expanded;
+    bool m_expanded;
 
-    QTimer *toggleTimer;
+    QTimer *m_toggleTimer;
 };
 
 #endif // HCLABEL_H
