@@ -30,7 +30,7 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
 
     QSettings settings;
     this->resize(settings.value("HelpWidget/helpWindowSize",
-                                QSize(580, 700)).toSize());
+                                QSize(640, 700)).toSize());
 
     ///////////////////////////////////////////////////////////////// Help text
     QString helpText;
@@ -65,7 +65,10 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
 
 
     // Actual contents
-    helpText.append("<a id=starting><h1>" + sectionStarting + "</h1></a>");
+    helpText.append("<a id=starting>"
+                    "<h1><img src=:/images/button-next.png/> "
+                    + sectionStarting
+                    + "</h1></a>");
 
     helpText.append(tr("The first time you start Dianara, you should see "
                        "the Account Configuration dialog. There, enter "
@@ -99,7 +102,10 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
     helpText.append("<br><hr>");
 
 
-    helpText.append("<a id=settings><h1>" + sectionSettings + "</h1></a>");
+    helpText.append("<a id=settings>"
+                    "<h1><img src=:/images/button-configure.png/> "
+                    + sectionSettings
+                    + "</h1></a>");
 
     helpText.append(tr("You can configure several things to your liking in the "
                        "settings, like the time interval between timeline "
@@ -114,7 +120,10 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
     helpText.append("<br><hr>");
 
 
-    helpText.append("<a id=timelines><h1>" + sectionTimelines + "</h1></a>");
+    helpText.append("<a id=timelines>"
+                    "<h1><img src=:/images/feed-inbox.png/> "
+                    + sectionTimelines
+                    + "</h1></a>");
 
     helpText.append(tr("There are seven timelines:")
                     + "<ul>"
@@ -159,7 +168,10 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
     helpText.append("<br><hr>");
 
 
-    helpText.append("<a id=posting><h1>" + sectionPosting + "</h1></a>");
+    helpText.append("<a id=posting>"
+                    "<h1><img src=:/images/button-post.png/> "
+                    + sectionPosting
+                    + "</h1></a>");
 
     helpText.append(tr("You can post notes by clicking in the text field at "
                        "the top of the window or by pressing Control+N. "
@@ -171,6 +183,12 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
     helpText.append(tr("It is possible to attach images, audio, video, and "
                        "general files, like PDF documents, to your post.")
                     + "<br>");
+    helpText.append("<center>"
+                    "<img src=:/images/attached-audio.png/> "
+                    "<img src=:/images/attached-image.png/> "
+                    "<img src=:/images/attached-video.png/>"
+                    "</center>"
+                    "<br><br>");
     helpText.append(tr("You can use the Format button to add formatting to "
                        "your text, like bold or italics. Some of these options "
                        "require text to be selected before they are used.")
@@ -197,7 +215,10 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
     helpText.append("<br><hr>");
 
 
-    helpText.append("<a id=contacts><h1>" + sectionContacts + "</h1></a>");
+    helpText.append("<a id=contacts>"
+                    "<h1><img src=:/images/button-users.png/> "
+                    + sectionContacts
+                    + "</h1></a>");
 
     helpText.append(tr("You can see the lists of people you follow, and who "
                        "follow you from the Contacts tab.")
@@ -234,7 +255,10 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
     helpText.append("<br><hr>");
 
 
-    helpText.append("<a id=keyboard><h1>" + sectionKeyboard + "</h1></a>");
+    helpText.append("<a id=keyboard>"
+                    "<h1><img src=:/images/button-edit.png/> " // FIXME TMP
+                    + sectionKeyboard
+                    + "</h1></a>");
 
     helpText.append(tr("The most common actions found on the menus have "
                        "keyboard shortcuts written next to them, like F5 "
@@ -272,7 +296,10 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
     helpText.append("<br><hr>");
 
 
-    helpText.append("<a id=commandline><h1>" + sectionCommandLine + "</h1></a>");
+    helpText.append("<a id=commandline>"
+                    "<h1><img src=:/images/button-configure.png/> "
+                    + sectionCommandLine
+                    + "</h1></a>");
 
     helpText.append(tr("You can use the --config parameter to run the program "
                        "with a different configuration. This can be useful to "
@@ -306,32 +333,32 @@ HelpWidget::HelpWidget(QWidget *parent) : QWidget(parent)
     ///////////////////////////////////////////////////////////////// Help text
 
 
-    helpTextBrowser = new QTextBrowser(this);
-    helpTextBrowser->setReadOnly(true);
-    helpTextBrowser->setOpenExternalLinks(true);
-    helpTextBrowser->setText(helpText);
+    m_helpTextBrowser = new QTextBrowser(this);
+    m_helpTextBrowser->setReadOnly(true);
+    m_helpTextBrowser->setOpenExternalLinks(true);
+    m_helpTextBrowser->setText(helpText);
 
-    closeButton = new QPushButton(QIcon::fromTheme("window-close",
+    m_closeButton = new QPushButton(QIcon::fromTheme("window-close",
                                                    QIcon(":/images/button-close.png")),
-                                  tr("&Close"),
-                                  this);
-    connect(closeButton, &QAbstractButton::clicked,
+                                    tr("&Close"),
+                                    this);
+    connect(m_closeButton, &QAbstractButton::clicked,
             this, &QWidget::hide);
 
     QList<QKeySequence> closeShortcuts;
     closeShortcuts << QKeySequence(Qt::Key_Escape);
     closeShortcuts << QKeySequence(Qt::Key_F1);
-    closeAction = new QAction(this);
-    closeAction->setShortcuts(closeShortcuts);
-    connect(closeAction, &QAction::triggered,
+    m_closeAction = new QAction(this);
+    m_closeAction->setShortcuts(closeShortcuts);
+    connect(m_closeAction, &QAction::triggered,
             this, &QWidget::hide);
-    this->addAction(closeAction);
+    this->addAction(m_closeAction);
 
-    mainLayout = new QVBoxLayout();
-    mainLayout->setContentsMargins(2, 2, 2, 2);
-    mainLayout->addWidget(helpTextBrowser);
-    mainLayout->addWidget(closeButton, 0, Qt::AlignRight);
-    this->setLayout(mainLayout);
+    m_layout = new QVBoxLayout();
+    m_layout->setContentsMargins(2, 2, 2, 2);
+    m_layout->addWidget(m_helpTextBrowser);
+    m_layout->addWidget(m_closeButton, 0, Qt::AlignRight);
+    this->setLayout(m_layout);
 
     qDebug() << "HelpWidget created";
 }
