@@ -41,21 +41,24 @@ public:
     explicit HelpWidget(QWidget *parent = 0);
     ~HelpWidget();
 
+
 signals:
 
+
 public slots:
 
+
 protected:
     virtual void closeEvent(QCloseEvent *event);
     virtual void hideEvent(QHideEvent *event);
 
 
 private:
-    QVBoxLayout *mainLayout;
-    QTextBrowser *helpTextBrowser;
+    QVBoxLayout *m_layout;
+    QTextBrowser *m_helpTextBrowser;
 
-    QPushButton *closeButton;
-    QAction *closeAction;
+    QPushButton *m_closeButton;
+    QAction *m_closeAction;
 };
 
 #endif // HELPWIDGET_H
