@@ -66,7 +66,8 @@ public slots:
     void enableDisableDeleteButtons();
 
     void showAddPersonDialog();
-    void addPerson(QIcon icon, QString contactString, QString contactUrl);
+    void addPerson(QIcon icon, QString contactString,
+                   QString contactName, QString contactId, QString contactUrl);
     void removePerson();
 
     void addPersonItemToList(QString personId, QString personName,
@@ -75,28 +76,29 @@ public slots:
 
 
 private:
-    PumpController *pController;
+    QVBoxLayout *m_mainLayout;
+    QHBoxLayout *m_buttonsLayout;
 
-    QVBoxLayout *mainLayout;
-    QHBoxLayout *buttonsLayout;
+    QTreeWidget *m_listsTreeWidget;
+    QPushButton *m_deleteListButton;
 
-    QTreeWidget *listsTreeWidget;
-    QPushButton *deleteListButton;
+    QPushButton *m_addPersonButton;
+    QPushButton *m_removePersonButton;
 
-    QPushButton *addPersonButton;
-    QPushButton *removePersonButton;
+    PeopleWidget *m_peopleWidget;
 
-    PeopleWidget *peopleWidget;
+    QGroupBox *m_newListGroupbox;
+    QHBoxLayout *m_groupboxMainLayout;
+    QVBoxLayout *m_groupboxLeftLayout;
 
-    QGroupBox *newListGroupbox;
-    QHBoxLayout *groupboxMainLayout;
-    QVBoxLayout *groupboxLeftLayout;
+    QLineEdit *m_newListNameLineEdit;
+    QTextEdit *m_newListDescTextEdit;
+    QPushButton *m_createListButton;
 
-    QLineEdit *newListNameLineEdit;
-    QTextEdit *newListDescTextEdit;
-    QPushButton *createListButton;
 
-    QStringList personListsUrlList;
+    QStringList m_personListsUrlList;
+
+    PumpController *m_pumpController;
 };
 
 
