@@ -37,43 +37,43 @@ LogViewer::LogViewer(QWidget *parent) : QWidget(parent)
     closeShortcuts << QKeySequence(Qt::Key_Escape);
     closeShortcuts << QKeySequence(Qt::Key_F12);
 
-    closeAction = new QAction(this);    
-    closeAction->setShortcuts(closeShortcuts);
-    connect(closeAction, &QAction::triggered,
+    m_closeAction = new QAction(this);
+    m_closeAction->setShortcuts(closeShortcuts);
+    connect(m_closeAction, &QAction::triggered,
             this, &QWidget::hide);
-    this->addAction(closeAction);
+    this->addAction(m_closeAction);
 
 
-    logTextBrowser = new QTextBrowser(this);
-    logTextBrowser->setReadOnly(true);
-    logTextBrowser->setOpenExternalLinks(true);
+    m_logTextBrowser = new QTextBrowser(this);
+    m_logTextBrowser->setReadOnly(true);
+    m_logTextBrowser->setOpenExternalLinks(true);
 
 
-    clearButton = new QPushButton(QIcon::fromTheme("edit-clear-list",
-                                                   QIcon(":/images/button-delete.png")),
-                                  tr("Clear &Log"),
-                                  this);
-    connect(clearButton, &QAbstractButton::clicked,
-            logTextBrowser, &QTextEdit::clear);
+    m_clearButton = new QPushButton(QIcon::fromTheme("edit-clear-list",
+                                                     QIcon(":/images/button-delete.png")),
+                                    tr("Clear &Log"),
+                                    this);
+    connect(m_clearButton, &QAbstractButton::clicked,
+            m_logTextBrowser, &QTextEdit::clear);
 
-    closeButton = new QPushButton(QIcon::fromTheme("window-close",
-                                                   QIcon(":/images/button-close.png")),
-                                  tr("&Close"),
-                                  this);
-    connect(closeButton, &QAbstractButton::clicked,
+    m_closeButton = new QPushButton(QIcon::fromTheme("window-close",
+                                                     QIcon(":/images/button-close.png")),
+                                    tr("&Close"),
+                                    this);
+    connect(m_closeButton, &QAbstractButton::clicked,
             this, &QWidget::hide);
 
 
     // Layout
-    buttonsLayout = new QHBoxLayout();
-    buttonsLayout->addWidget(clearButton);
-    buttonsLayout->addStretch();
-    buttonsLayout->addWidget(closeButton);
+    m_buttonsLayout = new QHBoxLayout();
+    m_buttonsLayout->addWidget(m_clearButton);
+    m_buttonsLayout->addStretch();
+    m_buttonsLayout->addWidget(m_closeButton);
 
-    mainLayout = new QVBoxLayout();
-    mainLayout->addWidget(logTextBrowser);
-    mainLayout->addLayout(buttonsLayout);
-    this->setLayout(mainLayout);
+    m_mainLayout = new QVBoxLayout();
+    m_mainLayout->addWidget(m_logTextBrowser);
+    m_mainLayout->addLayout(m_buttonsLayout);
+    this->setLayout(m_mainLayout);
 
     qDebug() << "LogViewer created";
 }
@@ -110,7 +110,7 @@ void LogViewer::hideEvent(QHideEvent *event)
  */
 void LogViewer::showEvent(QShowEvent *event)
 {
-    this->logTextBrowser->moveCursor(QTextCursor::End);
+    this->m_logTextBrowser->moveCursor(QTextCursor::End);
     event->accept();
 }
 
@@ -135,7 +135,7 @@ void LogViewer::addToLog(QString message, QString url)
                        + "</a>");
     }
 
-    logTextBrowser->append(logLine);
+    m_logTextBrowser->append(logLine);
 }
 
 
