@@ -62,14 +62,14 @@ protected:
 
 
 private:
-    QVBoxLayout *mainLayout;
-    QTextBrowser *logTextBrowser;
+    QVBoxLayout *m_mainLayout;
+    QTextBrowser *m_logTextBrowser;
 
-    QHBoxLayout *buttonsLayout;
-    QPushButton *clearButton;
-    QPushButton *closeButton;
+    QHBoxLayout *m_buttonsLayout;
+    QPushButton *m_clearButton;
+    QPushButton *m_closeButton;
 
-    QAction *closeAction;
+    QAction *m_closeAction;
 };
 
 #endif // LOGVIEWER_H
