@@ -48,13 +48,14 @@ int main(int argc, char *argv[])
 {
     QApplication dianaraApp(argc, argv);
     dianaraApp.setApplicationName("Dianara");
-    dianaraApp.setApplicationVersion("1.4.0");
+    dianaraApp.setApplicationVersion("1.4.1");
     dianaraApp.setOrganizationName("JanCoding");
     dianaraApp.setOrganizationDomain("jancoding.wordpress.com");
 
     std::cout << QString("Dianara v%1 - JanKusanagi 2012-2017\n"
                          "https://jancoding.wordpress.com/dianara\n\n")
-                        .arg(dianaraApp.applicationVersion()).toStdString();
+                 .arg(dianaraApp.applicationVersion())
+                 .toStdString();
 
     std::cout << QString("- Built with Qt v%1").arg(QT_VERSION_STR)
                                                .toStdString();
@@ -152,7 +153,7 @@ int main(int argc, char *argv[])
             }
             else if (nextParameterIsConfig)
             {
-                QString configName = "Dianara_" + argument.toLower();
+                const QString configName = "Dianara_" + argument.toLower();
                 dianaraApp.setApplicationName(configName);
                 nextParameterIsConfig = false;
 
@@ -174,8 +175,8 @@ int main(int argc, char *argv[])
             // Option to set link color (useful in GTK environments)
             if (argument.startsWith("--linkcolor=", Qt::CaseInsensitive))
             {
-                QString linkColorName = argument.split("=").last();
-                QColor linkColor = QColor(linkColorName);
+                const QString linkColorName = argument.split("=").last();
+                const QColor linkColor = QColor(linkColorName);
                 if (linkColor.isValid())
                 {
                     QPalette newPalette = dianaraApp.palette();
