@@ -27,71 +27,73 @@ MinorFeed::MinorFeed(PumpController::requestTypes minorFeedType,
                      FilterChecker *filterChecker,
                      QWidget *parent) : QFrame(parent)
 {
-    this->feedType = minorFeedType;
-    this->pController = pumpController;
-    this->globalObj = globalObject;
-    this->fChecker = filterChecker;
+    m_feedType = minorFeedType;
 
-    connect(pController, SIGNAL(minorFeedFailed(int)),
-            this, SLOT(onUpdateFailed(int)));
+    m_pumpController = pumpController;
+    connect(m_pumpController, &PumpController::minorFeedFailed,
+            this, &MinorFeed::onUpdateFailed);
+
+    m_globalObject = globalObject;
+
+    m_filterChecker = filterChecker;
 
 
     this->setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
     this->setContentsMargins(0, 0, 0, 0);
 
     // Layout for the items
-    itemsLayout = new QVBoxLayout();
-    itemsLayout->setContentsMargins(0, 0, 0, 0);
-    itemsLayout->setSpacing(1); // Very small spacing
+    m_itemsLayout = new QVBoxLayout();
+    m_itemsLayout->setContentsMargins(0, 0, 0, 0);
+    m_itemsLayout->setSpacing(1); // Very small spacing
 
     // Separator frame, to mark where new items end
-    separatorFrame = new QFrame(this);
-    separatorFrame->setFrameStyle(QFrame::HLine);
-    separatorFrame->setMinimumHeight(28);
-    separatorFrame->setContentsMargins(0, 8, 0, 8);
-    separatorFrame->hide();
+    m_separatorFrame = new QFrame(this);
+    m_separatorFrame->setFrameStyle(QFrame::HLine);
+    m_separatorFrame->setMinimumHeight(28);
+    m_separatorFrame->setContentsMargins(0, 8, 0, 8);
+    m_separatorFrame->hide();
 
     // Button to get newer items (pending stuff)
-    getPendingButton = new QPushButton(QIcon::fromTheme("view-refresh",
-                                                        QIcon(":/images/menu-refresh.png")),
-                                       "*get pending activities*",
-                                       this);
-    getPendingButton->setFlat(true);
-    connect(getPendingButton, SIGNAL(clicked()),
-            this, SLOT(updateFeed()));
-    getPendingButton->hide();
+    m_getPendingButton = new QPushButton(QIcon::fromTheme("view-refresh",
+                                                          QIcon(":/images/menu-refresh.png")),
+                                         QStringLiteral("*get pending activities*"),
+                                         this);
+    m_getPendingButton->setFlat(true);
+    connect(m_getPendingButton, &QAbstractButton::clicked,
+            this, &MinorFeed::updateFeed);
+    m_getPendingButton->hide();
 
 
     // Button to get more items (older stuff)
-    getOlderButton = new QPushButton(QIcon::fromTheme("list-add",
-                                                     QIcon(":/images/list-add.png")),
-                                     tr("Older Activities"),
-                                     this);
-    getOlderButton->setFlat(true);
-    getOlderButton->setToolTip("<b></b>"
-                               + tr("Get previous minor activities"));
-    connect(getOlderButton, SIGNAL(clicked()),
-            this, SLOT(getMoreActivities()));
+    m_getOlderButton = new QPushButton(QIcon::fromTheme("list-add",
+                                                       QIcon(":/images/list-add.png")),
+                                       tr("Older Activities"),
+                                       this);
+    m_getOlderButton->setFlat(true);
+    m_getOlderButton->setToolTip("<b></b>"
+                                 + tr("Get previous minor activities"));
+    connect(m_getOlderButton, &QAbstractButton::clicked,
+            this, &MinorFeed::getMoreActivities);
 
     // Set disabled initially; will be enabled when contents are set
-    getOlderButton->setDisabled(true);
+    m_getOlderButton->setDisabled(true);
 
 
     // Main layout
-    mainLayout = new QVBoxLayout();
-    mainLayout->setContentsMargins(1, 1, 1, 1);
-    mainLayout->addWidget(getPendingButton);
-    mainLayout->addLayout(itemsLayout, 1);
-    mainLayout->addSpacing(8);
-    mainLayout->addStretch();
-    mainLayout->addWidget(getOlderButton);
-    this->setLayout(mainLayout);
+    m_mainLayout = new QVBoxLayout();
+    m_mainLayout->setContentsMargins(1, 1, 1, 1);
+    m_mainLayout->addWidget(m_getPendingButton);
+    m_mainLayout->addLayout(m_itemsLayout, 1);
+    m_mainLayout->addSpacing(8);
+    m_mainLayout->addStretch();
+    m_mainLayout->addWidget(m_getOlderButton);
+    this->setLayout(m_mainLayout);
 
 
 
     // Demo activity, stating that there's nothing to show
     QVariantMap demoGenerator;
-    demoGenerator.insert("displayName", "Dianara");
+    demoGenerator.insert("displayName", QStringLiteral("Dianara"));
 
     QVariantMap demoActivityMap;
     demoActivityMap.insert("published", QDateTime::currentDateTimeUtc()
@@ -99,62 +101,59 @@ MinorFeed::MinorFeed(PumpController::requestTypes minorFeedType,
     demoActivityMap.insert("generator", demoGenerator);
     demoActivityMap.insert("content",   tr("There are no activities to show yet."));
 
-    ASActivity *demoActivity = new ASActivity(demoActivityMap, "", this);
+    ASActivity *demoActivity = new ASActivity(demoActivityMap, QString(), this);
 
     MinorFeedItem *demoFeedItem = new MinorFeedItem(demoActivity,
                                                     false, // Not highlighted by filter
-                                                    this->pController,
-                                                    this->globalObj,
+                                                    m_pumpController,
+                                                    m_globalObject,
                                                     this);
     demoFeedItem->setItemAsNew(false,
                                false); // Do not inform the feed
-    this->itemsLayout->addWidget(demoFeedItem);
-    this->itemsInFeed.append(demoFeedItem);
+    m_itemsLayout->addWidget(demoFeedItem);
+    m_itemsInFeed.append(demoFeedItem);
 
-    this->firstLoad = true;
-    this->gettingNew = true; // First time should be true
-    this->unreadItemsCount = 0;
-    this->highlightedItemsCount = 0;
-    this->pendingToReceiveNextTime = 0;
+    m_firstLoad = true;
+    m_gettingNew = true; // First time should be true
+    m_unreadItemsCount = 0;
+    m_highlightedItemsCount = 0;
+    m_pendingToReceiveNextTime = 0;
 
     // Remember what was the newest activity last time
     QSettings settings;
     settings.beginGroup("MinorFeedStates");
-    switch (this->feedType)
+    switch (m_feedType)
     {
     case PumpController::MinorFeedMainRequest:
-        this->previousNewestActivityId = settings
-                                         .value("previousNewestItemIdMain")
-                                         .toString();
-        this->fullFeedItemCount = settings.value("totalItemsMain").toInt();
-        this->feedBatchItemCount = 50;
+        m_previousNewestActivityId = settings.value("previousNewestItemIdMain")
+                                             .toString();
+        m_fullFeedItemCount = settings.value("totalItemsMain").toInt();
+        m_feedBatchItemCount = 50;
         break;
 
     case PumpController::MinorFeedDirectRequest:
-        this->previousNewestActivityId = settings
-                                         .value("previousNewestItemIdDirect")
-                                         .toString();
-        this->fullFeedItemCount = settings.value("totalItemsDirect").toInt();
-        this->feedBatchItemCount = 20;
+        m_previousNewestActivityId = settings.value("previousNewestItemIdDirect")
+                                             .toString();
+        m_fullFeedItemCount = settings.value("totalItemsDirect").toInt();
+        m_feedBatchItemCount = 20;
         break;
 
     case PumpController::MinorFeedActivityRequest:
-        this->previousNewestActivityId = settings
-                                         .value("previousNewestItemIdActivity")
-                                         .toString();
-        this->fullFeedItemCount = settings.value("totalItemsActivity").toInt();
-        this->feedBatchItemCount = 20;
+        m_previousNewestActivityId = settings.value("previousNewestItemIdActivity")
+                                             .toString();
+        m_fullFeedItemCount = settings.value("totalItemsActivity").toInt();
+        m_feedBatchItemCount = 20;
         break;
 
     default:
-        qDebug() << "MinorFeed created with wrong type:" << this->feedType;
+        qDebug() << "MinorFeed created with wrong type:" << m_feedType;
     }
     settings.endGroup();
 
 
     // Sync all avatar's follow state when there are changes in the Following list
-    connect(pController, SIGNAL(followingListChanged()),
-            this, SLOT(updateAvatarFollowStates()));
+    connect(m_pumpController, &PumpController::followingListChanged,
+            this, &MinorFeed::updateAvatarFollowStates);
 
     qDebug() << "MinorFeed created";
 }
@@ -165,27 +164,21 @@ MinorFeed::~MinorFeed()
     QSettings settings;
     settings.beginGroup("MinorFeedStates");
 
-    switch (this->feedType)
+    switch (m_feedType)
     {
     case PumpController::MinorFeedMainRequest:
-        settings.setValue("previousNewestItemIdMain",
-                          this->previousNewestActivityId);
-        settings.setValue("totalItemsMain",
-                          this->fullFeedItemCount);
+        settings.setValue("previousNewestItemIdMain", m_previousNewestActivityId);
+        settings.setValue("totalItemsMain", m_fullFeedItemCount);
         break;
 
     case PumpController::MinorFeedDirectRequest:
-        settings.setValue("previousNewestItemIdDirect",
-                          this->previousNewestActivityId);
-        settings.setValue("totalItemsDirect",
-                          this->fullFeedItemCount);
+        settings.setValue("previousNewestItemIdDirect", m_previousNewestActivityId);
+        settings.setValue("totalItemsDirect", m_fullFeedItemCount);
         break;
 
     case PumpController::MinorFeedActivityRequest:
-        settings.setValue("previousNewestItemIdActivity",
-                          this->previousNewestActivityId);
-        settings.setValue("totalItemsActivity",
-                          this->fullFeedItemCount);
+        settings.setValue("previousNewestItemIdActivity", m_previousNewestActivityId);
+        settings.setValue("totalItemsActivity", m_fullFeedItemCount);
         break;
 
     default:
@@ -193,7 +186,7 @@ MinorFeed::~MinorFeed()
     }
     settings.endGroup();
 
-    qDebug() << "MinorFeed destroyed; Type:" << this->feedType;
+    qDebug() << "MinorFeed destroyed; Type:" << m_feedType;
 }
 
 
@@ -201,16 +194,16 @@ MinorFeed::~MinorFeed()
 void MinorFeed::clearContents()
 {
     qDebug() << "MinorFeed::clearContents()";
-    foreach (MinorFeedItem *feedItem, itemsInFeed)
+    foreach (MinorFeedItem *feedItem, m_itemsInFeed)
     {
-        this->itemsLayout->removeWidget(feedItem);
+        m_itemsLayout->removeWidget(feedItem);
         delete feedItem;
     }
 
-    itemsInFeed.clear();
+    m_itemsInFeed.clear();
 
-    itemsLayout->removeWidget(separatorFrame);
-    separatorFrame->hide();
+    m_itemsLayout->removeWidget(m_separatorFrame);
+    m_separatorFrame->hide();
 }
 
 
@@ -223,24 +216,24 @@ void MinorFeed::clearContents()
  */
 void MinorFeed::removeOldItems(int minimumToKeep)
 {
-    int maxItems = qMax(this->feedBatchItemCount * 2, // TMP FIXME
+    int maxItems = qMax(m_feedBatchItemCount * 2, // TMP FIXME
                         minimumToKeep);
 
-    if (itemsInFeed.count() <= maxItems)
+    if (m_itemsInFeed.count() <= maxItems)
     {
         // Not too many items yet
         return;
     }
 
     int itemCounter = 0;
-    foreach (MinorFeedItem *feedItem, itemsInFeed)
+    foreach (MinorFeedItem *feedItem, m_itemsInFeed)
     {
         if (itemCounter >= maxItems)
         {
             if (!feedItem->isNew()) // Don't remove if it's unread (optional?)
             {
-                this->itemsLayout->removeWidget(feedItem);
-                this->itemsInFeed.removeOne(feedItem);
+                m_itemsLayout->removeWidget(feedItem);
+                m_itemsInFeed.removeOne(feedItem);
                 delete feedItem;
             }
         }
@@ -249,32 +242,31 @@ void MinorFeed::removeOldItems(int minimumToKeep)
     }
 
     // Update "next" link manually, based on the last item present in the feed
-    QByteArray lastItemId = itemsInFeed.last()->getActivityId().toLocal8Bit();
+    QByteArray lastItemId = m_itemsInFeed.last()->getActivityId().toLocal8Bit();
     lastItemId = lastItemId.toPercentEncoding(); // Needs to be percent-encoded
 
-    this->nextLink = this->pController->getFeedApiUrl(this->feedType)
-                   + "?before=" + lastItemId;
+    m_nextLink = m_pumpController->getFeedApiUrl(m_feedType)
+                 + "?before=" + lastItemId;
 }
 
 
 void MinorFeed::insertSeparator(int position)
 {
-    this->itemsLayout->insertWidget(position,
-                                    this->separatorFrame);
-    this->separatorFrame->show();
+    m_itemsLayout->insertWidget(position, m_separatorFrame);
+    m_separatorFrame->show();
 }
 
 
 void MinorFeed::markAllAsRead()
 {
-    foreach (MinorFeedItem *feedItem, itemsInFeed)
+    foreach (MinorFeedItem *feedItem, m_itemsInFeed)
     {
         feedItem->setItemAsNew(false,   // Mark as not new
                                false);  // Don't inform the feed
     }
 
-    this->unreadItemsCount = 0;
-    this->highlightedItemsCount = 0;
+    m_unreadItemsCount = 0;
+    m_highlightedItemsCount = 0;
 }
 
 /*
@@ -283,7 +275,7 @@ void MinorFeed::markAllAsRead()
  */
 void MinorFeed::updateFuzzyTimestamps()
 {
-    foreach (MinorFeedItem *feedItem, itemsInFeed)
+    foreach (MinorFeedItem *feedItem, m_itemsInFeed)
     {
         feedItem->setFuzzyTimeStamp();
     }
@@ -376,12 +368,12 @@ void MinorFeed::syncActivityWithTimelines(ASActivity *activity)
  */
 void MinorFeed::updateFeed()
 {
-    this->gettingNew = true;
-    this->getOlderButton->setDisabled(true);
+    m_gettingNew = true;
+    m_getOlderButton->setDisabled(true);
 
-    this->pController->getFeed(this->feedType,
-                               200, // Maximum item count allowed by API
-                               this->prevLink);
+    m_pumpController->getFeed(m_feedType,
+                              200, // Maximum item count allowed by API
+                              m_prevLink);
 }
 
 /*
@@ -390,12 +382,12 @@ void MinorFeed::updateFeed()
  */
 void MinorFeed::getMoreActivities()
 {
-    this->gettingNew = false;
-    this->getOlderButton->setDisabled(true);
+    m_gettingNew = false;
+    m_getOlderButton->setDisabled(true);
 
-    this->pController->getFeed(this->feedType,
-                               this->feedBatchItemCount,
-                               this->nextLink);
+    m_pumpController->getFeed(m_feedType,
+                              m_feedBatchItemCount,
+                              m_nextLink);
 }
 
 
@@ -404,75 +396,82 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
                                 QString previous, QString next,
                                 int totalItemCount)
 {
-    if (firstLoad)
+    if (m_firstLoad)
     {
-        this->prevLink = previous;
-        this->nextLink = next;
+        m_prevLink = previous;
+        m_nextLink = next;
 
         this->clearContents();
     }
     else
     {
-        if (gettingNew)
+        if (m_gettingNew)
         {
             if (!previous.isEmpty())
             {
-                this->prevLink = previous;
+                m_prevLink = previous;
             }
         }
         else
         {
             if (!next.isEmpty())
             {
-                this->nextLink = next;
+                m_nextLink = next;
             }
         }
     }
 
-    qDebug() << "Current MinorFeed links:" << this->prevLink << this->nextLink;
+    qDebug() << "Current MinorFeed prev/next links:" << m_prevLink << m_nextLink;
 
 
-    int activitiesListSize = activitiesList.size();
+    const int activitiesListSize = activitiesList.size();
     int totalItemDifference = -1; // TMP FIXME; for cases where it's unknown
-    if (gettingNew)
+    if (m_gettingNew)
     {
         // Check how many new items we should we expecting
-        totalItemDifference = totalItemCount - this->fullFeedItemCount;
-        this->fullFeedItemCount = totalItemCount;
+        totalItemDifference = totalItemCount - m_fullFeedItemCount;
+        m_fullFeedItemCount = totalItemCount;
         qDebug() << "MinorFeed::setFeedContents(); Should load"
                  << totalItemDifference << "items this time ###";
 
         // Check how many more items need to be received, if more than max are pending
-        pendingToReceiveNextTime += totalItemDifference;
-        pendingToReceiveNextTime -= activitiesListSize;
-        if (pendingToReceiveNextTime > 0)
+        m_pendingToReceiveNextTime += totalItemDifference;
+        m_pendingToReceiveNextTime -= activitiesListSize;
+        if (m_pendingToReceiveNextTime > 0)
         {
-            if (firstLoad)
+            if (m_firstLoad)
             {
                 // The difference in pending items is in the older activities, so doesn't count
-                this->pendingToReceiveNextTime = 0;
+                m_pendingToReceiveNextTime = 0;
 
                 // TODO: On first load, could display the "pending" number at the "older" button
             }
             else
             {
                 // Button at the top to fetch the pending activities, even more new stuff
-                this->getPendingButton->setText(tr("Get %1 newer",
-                                                   "As in: Get 3 newer (activities)")
-                                                .arg(pendingToReceiveNextTime));
-                this->getPendingButton->show();
+                m_getPendingButton->setText(tr("Get %1 newer",
+                                               "As in: Get 3 newer (activities)")
+                                            .arg(m_pendingToReceiveNextTime));
+                m_getPendingButton->show();
             }
         }
         else
         {
-            this->pendingToReceiveNextTime = 0; // In case it was less than 0
-            this->getPendingButton->hide();
+            m_pendingToReceiveNextTime = 0; // In case it was less than 0
+            m_getPendingButton->hide();
+        }
+
+        // Hide "Get newer" button also if for some reason it's present and we
+        if (activitiesListSize == 0) // confirm there's nothing else to receive
+        {
+            m_pendingToReceiveNextTime = 0;
+            m_getPendingButton->hide();
         }
     }
 
     // Remove the separator line
-    itemsLayout->removeWidget(separatorFrame);
-    separatorFrame->hide();
+    m_itemsLayout->removeWidget(m_separatorFrame);
+    m_separatorFrame->hide();
 
     int newItemsCount = 0;
     int newHighlightedItemsCount = 0;
@@ -489,16 +488,19 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
     bool needToInsertSeparator = false;
 
     QList<ASActivity *> activitiesToSync;
+    QList<ASActivity *> allProcessedActivities;
 
     foreach (QVariant activityVariant, activitiesList)
     {
         itemIsNew = false;
 
         ASActivity *activity = new ASActivity(activityVariant.toMap(),
-                                              pController->currentUserId(),
+                                              m_pumpController->currentUserId(),
                                               this);
+        allProcessedActivities.append(activity);
 
-        int filtered = this->fChecker->validateActivity(activity);
+
+        const int filtered = m_filterChecker->validateActivity(activity);
 
         // If there is no reason to filter out the item, add it to the feed
         if (filtered != FilterChecker::FilterOut)
@@ -509,13 +511,13 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
             // Determine which activities are new
             if (newestActivityId.isEmpty()) // Only first time, for newest item
             {
-                if (gettingNew)
+                if (m_gettingNew)
                 {
                     newestActivityId = activity->getId();
                 }
                 else
                 {
-                    newestActivityId = this->previousNewestActivityId;
+                    newestActivityId = m_previousNewestActivityId;
                     allNewItemsCounted = true;
                 }
             }
@@ -523,7 +525,7 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
             // Determine if this item is new, or if not anymore
             if (!allNewItemsCounted)
             {
-                if (activity->getId() == this->previousNewestActivityId)
+                if (activity->getId() == m_previousNewestActivityId)
                 {
                     allNewItemsCounted = true;
                     if (newItemsCount > 0)
@@ -534,7 +536,7 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
                 else
                 {
                     // If activity is not ours, add it to the count
-                    if (activity->author()->getId() != pController->currentUserId())
+                    if (activity->author()->getId() != m_pumpController->currentUserId())
                     {
                         ++newItemsCount;
                         itemIsNew = true;
@@ -554,15 +556,15 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
 
             MinorFeedItem *newFeedItem = new MinorFeedItem(activity,
                                                            itemHighlightedByFilter,
-                                                           this->pController,
-                                                           this->globalObj,
+                                                           m_pumpController,
+                                                           m_globalObject,
                                                            this);
             newFeedItem->setItemAsNew(itemIsNew,
                                       false); // Don't inform the feed
             if (itemIsNew)
             {
-                connect(newFeedItem, SIGNAL(itemRead(bool)),
-                        this, SLOT(decreaseNewItemsCount(bool)));
+                connect(newFeedItem, &MinorFeedItem::itemRead,
+                        this, &MinorFeed::decreaseNewItemsCount);
 
                 if (newFeedItem->getItemHighlightType() != -1)
                 {
@@ -570,7 +572,7 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
                 }
             }
 
-            if (gettingNew)
+            if (m_gettingNew)
             {
                 if (needToInsertSeparator)  // -------
                 {
@@ -579,16 +581,14 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
                     needToInsertSeparator = false;
                 }
 
-                this->itemsLayout->insertWidget(insertedItemsCount,
-                                                newFeedItem);
-                this->itemsInFeed.insert(insertedItemsCount,
-                                         newFeedItem);
+                m_itemsLayout->insertWidget(insertedItemsCount, newFeedItem);
+                m_itemsInFeed.insert(insertedItemsCount, newFeedItem);
                 ++insertedItemsCount;
             }
             else // Not new, getting 'older', so add at the bottom
             {
-                this->itemsLayout->addWidget(newFeedItem);
-                this->itemsInFeed.append(newFeedItem);
+                m_itemsLayout->addWidget(newFeedItem);
+                m_itemsInFeed.append(newFeedItem);
             }
         }
         else
@@ -602,7 +602,7 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
 
 
     // The first time stuff is received from the server, there's no need to sync
-    if (!firstLoad)
+    if (!m_firstLoad)
     {
         // Activities in activitiesToSync are stored in reverse
         foreach (ASActivity *activity, activitiesToSync)
@@ -612,9 +612,15 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
         }
     }
 
+    // Cleanup all ASActivity objects, no longer needed
+    foreach (ASActivity *activity, allProcessedActivities)
+    {
+        delete activity;
+    }
+
 
     // If there were new items, and not already added, add separator: -------
-    if (newItemsCount > 0 && this->separatorFrame->isHidden())
+    if (newItemsCount > 0 && m_separatorFrame->isHidden())
     {
         this->insertSeparator(insertedItemsCount);
     }
@@ -622,22 +628,22 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
 
     if (!newestActivityId.isEmpty()) // If some items were received should be valid
     {
-        this->previousNewestActivityId = newestActivityId;
+        m_previousNewestActivityId = newestActivityId;
     }
 
-    this->unreadItemsCount += newItemsCount;
-    this->highlightedItemsCount += newHighlightedItemsCount;
+    m_unreadItemsCount += newItemsCount;
+    m_highlightedItemsCount += newHighlightedItemsCount;
 
     qDebug() << "Minor feed updated";
-    if (gettingNew) // not when getting more, older ones
+    if (m_gettingNew) // not when getting more, older ones
     {
-        emit newItemsCountChanged(this->unreadItemsCount,
-                                  this->highlightedItemsCount);
-        emit newItemsReceived(this->feedType,
+        emit newItemsCountChanged(m_unreadItemsCount,
+                                  m_highlightedItemsCount);
+        emit newItemsReceived(m_feedType,
                               newItemsCount,
                               newHighlightedItemsCount,
                               newFilteredItemsCount,
-                              this->pendingToReceiveNextTime);
+                              m_pendingToReceiveNextTime);
         qDebug() << "New items:" << newItemsCount
                  << "; New highlighted:" << newHighlightedItemsCount;
 
@@ -650,41 +656,41 @@ void MinorFeed::setFeedContents(QVariantList activitiesList,
     }
     else
     {
-        emit newItemsReceived(this->feedType,
+        emit newItemsReceived(m_feedType,
                               activitiesListSize, // Actual number of received items
                               -1, -1, -1); // -1 highlighted, filtered and pending
                                            // means these are old items
     }
 
-    this->getOlderButton->setEnabled(true);
-    firstLoad = false;
+    m_getOlderButton->setEnabled(true);
+    m_firstLoad = false;
 }
 
 
 void MinorFeed::onUpdateFailed(int requestType)
 {
-    if (requestType == this->feedType)
+    if (requestType == m_feedType)
     {
-        this->getOlderButton->setEnabled(true);
+        m_getOlderButton->setEnabled(true);
     }
 }
 
 
 void MinorFeed::decreaseNewItemsCount(bool wasHighlighted)
 {
-    --unreadItemsCount;
+    --m_unreadItemsCount;
     if (wasHighlighted)
     {
-        --highlightedItemsCount;
+        --m_highlightedItemsCount;
     }
 
-    emit newItemsCountChanged(unreadItemsCount, highlightedItemsCount);
+    emit newItemsCountChanged(m_unreadItemsCount, m_highlightedItemsCount);
 }
 
 
 void MinorFeed::updateAvatarFollowStates()
 {
-    foreach (MinorFeedItem *feedItem, itemsInFeed)
+    foreach (MinorFeedItem *feedItem, m_itemsInFeed)
     {
         feedItem->syncAvatarFollowState();
     }
