@@ -59,7 +59,7 @@ public:
 
 signals:
     void newItemsCountChanged(int itemCount, int highlightedCount);
-    void newItemsReceived(PumpController::requestTypes feedType,
+    void newItemsReceived(PumpController::requestTypes m_feedType,
                           int itemCount, int highlightedCount,
                           int filteredCount, int pendingForNextUpdate);
 
@@ -85,33 +85,33 @@ public slots:
 
 
 private:
-    QString prevLink;
-    QString nextLink;
-    int fullFeedItemCount;
-    int pendingToReceiveNextTime;
+    QString m_prevLink;
+    QString m_nextLink;
+    int m_fullFeedItemCount;
+    int m_pendingToReceiveNextTime;
 
-    PumpController::requestTypes feedType;
-    int feedBatchItemCount;
-    bool firstLoad;
-    bool gettingNew;
+    PumpController::requestTypes m_feedType;
+    int m_feedBatchItemCount;
+    bool m_firstLoad;
+    bool m_gettingNew;
 
-    QString previousNewestActivityId;
-    QList<MinorFeedItem *> itemsInFeed;
+    QString m_previousNewestActivityId;
+    QList<MinorFeedItem *> m_itemsInFeed;
 
-    int unreadItemsCount;
-    int highlightedItemsCount;
+    int m_unreadItemsCount;
+    int m_highlightedItemsCount;
 
-    QVBoxLayout *mainLayout;
-    QVBoxLayout *itemsLayout;
-    QPushButton *getPendingButton;
-    QPushButton *getOlderButton;
+    QVBoxLayout *m_mainLayout;
+    QVBoxLayout *m_itemsLayout;
+    QPushButton *m_getPendingButton;
+    QPushButton *m_getOlderButton;
 
-    QFrame *separatorFrame;
+    QFrame *m_separatorFrame;
 
 
-    PumpController *pController;
-    GlobalObject *globalObj;
-    FilterChecker *fChecker;
+    PumpController *m_pumpController;
+    GlobalObject *m_globalObject;
+    FilterChecker *m_filterChecker;
 };
 
 #endif // MINORFEED_H
