@@ -27,11 +27,11 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
                              GlobalObject *globalObject,
                              QWidget *parent) : QFrame(parent)
 {
-    this->pController = pumpController;
-    this->globalObj = globalObject;
+    m_pumpController = pumpController;
+    m_globalObject = globalObject;
 
-    this->itemIsNew = false;
-    this->haveTargetAvatar = false;
+    m_itemIsNew = false;
+    m_haveTargetAvatar = false;
 
     // This sizePolicy prevents cut messages, and the huge space at the end
     // of the feed, after clicking "Older Activities" several times
@@ -41,26 +41,25 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
     activity->setParent(this); // reparent the passed activity
 
     // Store activity ID so MinorFeed can reconstruct "next" url's
-    this->activityId = activity->getId();
+    m_activityId = activity->getId();
 
     QFont mainFont;
     mainFont.setPointSize(mainFont.pointSize() - 2);
 
     QString authorId = activity->author()->getId();
-
-    this->itemIsOwn = (authorId == pController->currentUserId());
+    m_itemIsOwn = (authorId == m_pumpController->currentUserId());
 
 
-    avatarButton = new AvatarButton(activity->author(),
-                                    this->pController,
-                                    this->globalObj,
-                                    this->globalObj->getMfAvatarSize(),
-                                    this);
+    m_avatarButton = new AvatarButton(activity->author(),
+                                      m_pumpController,
+                                      m_globalObject,
+                                      m_globalObject->getMfAvatarSize(),
+                                      this);
 
 
-    createdAtTimestamp = activity->getCreatedAt();
+    m_createdAtTimestamp = activity->getCreatedAt();
     QString timestampTooltip = "<b>"
-                               + Timestamp::localTimeDate(createdAtTimestamp)
+                               + Timestamp::localTimeDate(m_createdAtTimestamp)
                                + "</b>";
 
     QString generator = activity->getGenerator();
@@ -94,30 +93,30 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
         }
     }
 
-    timestampLabel = new QLabel(this);
+    m_timestampLabel = new QLabel(this);
     mainFont.setBold(true);
-    timestampLabel->setFont(mainFont);
-    timestampLabel->setWordWrap(true);
-    timestampLabel->setToolTip(timestampTooltip.trimmed());
-    timestampLabel->setAlignment(Qt::AlignCenter);
-    timestampLabel->setAutoFillBackground(true);
-    timestampLabel->setForegroundRole(QPalette::Text);
-    timestampLabel->setBackgroundRole(QPalette::Base);
-    timestampLabel->setFrameStyle(QFrame::Panel | QFrame::Raised);
+    m_timestampLabel->setFont(mainFont);
+    m_timestampLabel->setWordWrap(true);
+    m_timestampLabel->setToolTip(timestampTooltip.trimmed());
+    m_timestampLabel->setAlignment(Qt::AlignCenter);
+    m_timestampLabel->setAutoFillBackground(true);
+    m_timestampLabel->setForegroundRole(QPalette::Text);
+    m_timestampLabel->setBackgroundRole(QPalette::Base);
+    m_timestampLabel->setFrameStyle(QFrame::Panel | QFrame::Raised);
     this->setFuzzyTimeStamp();
 
 
     // The description itself, like "JaneDoe updated a note",
-    activityDescriptionLabel = new QLabel(this); // To be filled later
+    m_activityDescriptionLabel = new QLabel(this); // To be filled later
     QFont descriptionFont;
-    descriptionFont.fromString(globalObj->getMinorFeedFont());
-    activityDescriptionLabel->setFont(descriptionFont);
-    activityDescriptionLabel->setWordWrap(true);
-    activityDescriptionLabel->setOpenExternalLinks(true);
-    activityDescriptionLabel->setAlignment(Qt::AlignTop);
-    activityDescriptionLabel->setSizePolicy(QSizePolicy::Ignored,
-                                            QSizePolicy::MinimumExpanding);
-    connect(activityDescriptionLabel, &QLabel::linkHovered,
+    descriptionFont.fromString(m_globalObject->getMinorFeedFont());
+    m_activityDescriptionLabel->setFont(descriptionFont);
+    m_activityDescriptionLabel->setWordWrap(true);
+    m_activityDescriptionLabel->setOpenExternalLinks(true);
+    m_activityDescriptionLabel->setAlignment(Qt::AlignTop);
+    m_activityDescriptionLabel->setSizePolicy(QSizePolicy::Ignored,
+                                              QSizePolicy::MinimumExpanding);
+    connect(m_activityDescriptionLabel, &QLabel::linkHovered,
             this, &MinorFeedItem::showUrlInfo);
 
     // Tooltip contents
@@ -125,61 +124,61 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
     if (!activityTooltip.isEmpty())
     {
         // Set the activity info as tooltip for description label
-        this->activityDescriptionLabel->setToolTip(activityTooltip);
+        m_activityDescriptionLabel->setToolTip(activityTooltip);
 
         // Set a different mouse cursor for the description label, as a hint to wait for tooltip info
-        this->activityDescriptionLabel->setCursor(Qt::WhatsThisCursor);
+        m_activityDescriptionLabel->setCursor(Qt::WhatsThisCursor);
     }
 
 
-    originalObjectMap = activity->object()->getOriginalObject();
-
-    inReplyToMap = activity->object()->getInReplyTo();
-    QString inReplyToAuthorId = ASPerson::cleanupId(inReplyToMap.value("author").toMap()
-                                                                .value("id").toString());
+    m_originalObjectMap = activity->object()->getOriginalObject();
 
+    m_inReplyToMap = activity->object()->getInReplyTo();
+    QString inReplyToAuthorId = ASPerson::cleanupId(m_inReplyToMap
+                                                    .value("author").toMap()
+                                                    .value("id").toString());
 
 
     // Highlight this item if it's about the user, with different colors
-    itemHighlightType = -1; // False
+    m_itemHighlightType = -1; // False
 
     // We are in the recipient list of the activity
-    if (activity->getRecipientsIdList().contains(pController->currentUserId()))
+    if (activity->getRecipientsIdList().contains(m_pumpController->currentUserId()))
     {
-        itemHighlightType = 0;
+        m_itemHighlightType = 0;
     }
 
     // Activity is in reply to something made by us
-    if (inReplyToAuthorId == pController->currentUserId())
+    if (inReplyToAuthorId == m_pumpController->currentUserId())
     {
-        itemHighlightType = 1;
+        m_itemHighlightType = 1;
     }
 
     // We are the object; someone added us, etc.
-    if (activity->object()->getId() == pController->currentUserId())
+    if (activity->object()->getId() == m_pumpController->currentUserId())
     {
-        itemHighlightType = 2;
+        m_itemHighlightType = 2;
     }
 
     // The object is ours; someone favorited our note, or something
-    if (activity->object()->author()->getId() == pController->currentUserId())
+    if (activity->object()->author()->getId() == m_pumpController->currentUserId())
     {
-        itemHighlightType = 3;
+        m_itemHighlightType = 3;
     }
 
     //// Special case: highlighting the item because there's a filter rule for it
-    if (highlightedByFilter && itemHighlightType == -1) // Only if there's no other reason for HL
+    if (highlightedByFilter && m_itemHighlightType == -1) // Only if there's no other reason for HL
     {
-        itemHighlightType = 4;
+        m_itemHighlightType = 4;
     }
 
 
-    if (itemHighlightType != -1)
+    if (m_itemHighlightType != -1)
     {
         // Unless the user ID is also empty!
-        if (!pController->currentUserId().isEmpty())
+        if (!m_pumpController->currentUserId().isEmpty())
         {
-            QString highlightItemColor = this->globalObj->getColor(itemHighlightType);
+            QString highlightItemColor = m_globalObject->getColor(m_itemHighlightType);
 
             if (QColor::isValidColor(highlightItemColor)) // Valid color
             {
@@ -207,169 +206,171 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
 
 
     // Add a snippet if configured to do so
-    if (this->globalObj->getMinorFeedSnippetsType() != 3) // 3=Never
+    if (m_globalObject->getMinorFeedSnippetsType() != 3)    // 3=Never
     {
-        if (this->globalObj->getMinorFeedSnippetsType() == 2 // 2=Always
-         || this->itemHighlightType != -1)       // 0/1/2 and it's highlighted
+        if (m_globalObject->getMinorFeedSnippetsType() == 2 // 2=Always
+         || m_itemHighlightType != -1)       // 0/1/2 and it's highlighted
         {
-            if (this->globalObj->getMinorFeedSnippetsType() > 0  // Always or any highlighted
-             || authorId != pController->currentUserId())        // or highlighted but not ours (0)
+            if (m_globalObject->getMinorFeedSnippetsType() > 0  // Always or any highlighted
+             || authorId != m_pumpController->currentUserId())   // or highlighted but not ours (0)
             {
                 // FIXME 1.4.x: fix this spaghetti mess!!
                 // TODO: option to not show when the object of the activity is ours
                 // i.e. "JohnDoe liked a note", our note
 
                 int snippetCharLimit;
-                if (this->itemHighlightType == -1)
+                if (m_itemHighlightType == -1)
                 {
-                    snippetCharLimit = globalObj->getSnippetsCharLimit();
+                    snippetCharLimit = m_globalObject->getSnippetsCharLimit();
                 }
                 else
                 {
-                    snippetCharLimit = globalObj->getSnippetsCharLimitHl();
+                    snippetCharLimit = m_globalObject->getSnippetsCharLimitHl();
                 }
 
                 QString snippet = activity->generateSnippet(snippetCharLimit);
                 if (!snippet.isEmpty())
                 {
-                    activityDescription.append("&nbsp;<hr>" + snippet);
+                    activityDescription.append(QStringLiteral("&nbsp;<hr>")
+                                               + snippet);
                 }
             }
         }
     }
 
-    this->activityDescriptionLabel->setText(activityDescription);
+    m_activityDescriptionLabel->setText(activityDescription);
 
 
 
 
     //////////////////////////////////////////////////////// Layout
-    leftLayout = new QVBoxLayout();
-    leftLayout->setAlignment(Qt::AlignTop);
-    leftLayout->setContentsMargins(1, 0, 1, 0);
-    leftLayout->setSpacing(1);
-    leftLayout->addWidget(avatarButton, 0, Qt::AlignTop | Qt::AlignLeft);
-    leftLayout->addStretch(0);
+    m_leftLayout = new QVBoxLayout();
+    m_leftLayout->setAlignment(Qt::AlignTop);
+    m_leftLayout->setContentsMargins(1, 0, 1, 0);
+    m_leftLayout->setSpacing(1);
+    m_leftLayout->addWidget(m_avatarButton, 0, Qt::AlignTop | Qt::AlignLeft);
+    m_leftLayout->addStretch(0);
 
 
 
     // Original post available (inReplyTo) or object available (note, image...)
-    if (!inReplyToMap.isEmpty()
+    if (!m_inReplyToMap.isEmpty()
         || (ASObject::canDisplayObject(activity->object()->getType())
             && activity->object()->getDeletedTime().isEmpty())
        )
     {
-        this->openButton = new QPushButton("+", this);
-        openButton->setSizePolicy(QSizePolicy::Ignored,
-                                  QSizePolicy::Maximum);
-        openButton->setToolTip("<b></b>"
-                               + tr("Open referenced post"));
-        connect(openButton, &QAbstractButton::clicked,
+        m_openButton = new QPushButton(QStringLiteral("+"), this);
+        m_openButton->setSizePolicy(QSizePolicy::Ignored,
+                                    QSizePolicy::Maximum);
+        m_openButton->setToolTip("<b></b>"
+                                 + tr("Open referenced post"));
+        connect(m_openButton, &QAbstractButton::clicked,
                 this, &MinorFeedItem::openOriginalPost);
-        leftLayout->addWidget(openButton, 0, Qt::AlignHCenter);
+        m_leftLayout->addWidget(m_openButton, 0, Qt::AlignHCenter);
     }
 
 
-    rightLowerLayout = new QHBoxLayout();
-    rightLowerLayout->setContentsMargins(0, 0, 0, 0);
-    rightLowerLayout->addWidget(activityDescriptionLabel, 1);
+    m_rightLowerLayout = new QHBoxLayout();
+    m_rightLowerLayout->setContentsMargins(0, 0, 0, 0);
+    m_rightLowerLayout->addWidget(m_activityDescriptionLabel, 1);
     // This may also contain an AvatarButton for an "object person"
 
-    rightLayout = new QVBoxLayout();
-    rightLayout->setAlignment(Qt::AlignTop);
-    rightLayout->addWidget(timestampLabel);
-    rightLayout->addLayout(rightLowerLayout);
+    m_rightLayout = new QVBoxLayout();
+    m_rightLayout->setAlignment(Qt::AlignTop);
+    m_rightLayout->addWidget(m_timestampLabel);
+    m_rightLayout->addLayout(m_rightLowerLayout);
 
     // If the object is a person, such as someone following someone else, add an AvatarButton for them
-    if (activity->object()->getType() == "person")
+    if (activity->object()->getType() == QStringLiteral("person"))
     {
         ASPerson *personObject = activity->personObject();
-        if (personObject->getId() != authorId) // avoid cases like "JohnDoe updated JohnDoe"
+        if (personObject->getId() != authorId) // Avoid cases like "JohnDoe updated JohnDoe"
         {
-            this->haveTargetAvatar = true;
-            this->targetAvatarButton = new AvatarButton(personObject,
-                                                        this->pController,
-                                                        this->globalObj,
-                                                        globalObj->getMfAvatarSize(), // QSize(28,28)
-                                                        this);
-            rightLowerLayout->addWidget(targetAvatarButton, 0, Qt::AlignBottom);
+            m_haveTargetAvatar = true;
+            m_targetAvatarButton = new AvatarButton(personObject,
+                                                    m_pumpController,
+                                                    m_globalObject,
+                                                    m_globalObject->getMfAvatarSize(), // 28,28
+                                                    this);
+            m_rightLowerLayout->addWidget(m_targetAvatarButton, 0, Qt::AlignBottom);
         }
     }
 
 
 
-    topLayout = new QHBoxLayout();
-    topLayout->setContentsMargins(0, 0, 0, 0);
+    m_topLayout = new QHBoxLayout();
+    m_topLayout->setContentsMargins(0, 0, 0, 0);
 
     int iconSpacing = 0;
-    this->verbIconType = globalObj->getMfIconType();
+    m_verbIconType = m_globalObject->getMfIconType();
 
-    if (verbIconType != 0)
+    if (m_verbIconType != 0)
     {
-        this->verbIcons = MiscHelpers::iconsForActivity(activity->getVerb());
+        m_verbIcons = MiscHelpers::iconsForActivity(activity->getVerb());
 
         // Handle the different styles to prepare the paintEvent()
-        this->verbIconSize = globalObj->getMfAvatarSize().width();
-        this->verbIconSizeSubtle = verbIconSize * 1.4;
+        m_verbIconSize = m_globalObject->getMfAvatarSize().width();
+        m_verbIconSizeSubtle = m_verbIconSize * 1.4;
 
-        if (verbIconType == 1 || verbIconType == 3)
+        if (m_verbIconType == 1 || m_verbIconType == 3)
         {
-            iconSpacing = verbIconSize;
+            iconSpacing = m_verbIconSize;
         }
         else
         {
-            iconSpacing = verbIconSizeSubtle / 2;
+            iconSpacing = m_verbIconSizeSubtle / 2;
         }
     }
 
-    if (itemIsOwn) // For our items, text first
+    if (m_itemIsOwn) // For our items, text first
     {
-        topLayout->addLayout(rightLayout, 20);
+        m_topLayout->addLayout(m_rightLayout, 20);
 
-        if (verbIconType < 3) // 1 and 2 are icon-first (and this is reversed)
+        if (m_verbIconType < 3) // 1 and 2 are icon-first (and this is reversed)
         {
-            topLayout->addLayout(leftLayout, 1);
-            topLayout->addSpacing(iconSpacing);
+            m_topLayout->addLayout(m_leftLayout, 1);
+            m_topLayout->addSpacing(iconSpacing);
         }
         else                  // 3 and 4 are avatar-first
         {
-            topLayout->addSpacing(iconSpacing);
-            topLayout->addLayout(leftLayout, 1);
+            m_topLayout->addSpacing(iconSpacing);
+            m_topLayout->addLayout(m_leftLayout, 1);
         }
     }
     else // Normal item, not ours, layout with avatar/icon first
     {
-        if (verbIconType < 3) // 1 and 2 are icon-first
+        if (m_verbIconType < 3) // 1 and 2 are icon-first
         {
-            topLayout->addSpacing(iconSpacing);
-            topLayout->addLayout(leftLayout, 1);
+            m_topLayout->addSpacing(iconSpacing);
+            m_topLayout->addLayout(m_leftLayout, 1);
         }
         else
         {
-            topLayout->addLayout(leftLayout, 1);
-            topLayout->addSpacing(iconSpacing);
+            m_topLayout->addLayout(m_leftLayout, 1);
+            m_topLayout->addSpacing(iconSpacing);
         }
 
-        topLayout->addLayout(rightLayout, 20);
+        m_topLayout->addLayout(m_rightLayout, 20);
     }
 
 
-    mainLayout = new QVBoxLayout();
-    mainLayout->setContentsMargins(2, 1, 2, 4);
-    mainLayout->addLayout(topLayout);
+    m_mainLayout = new QVBoxLayout();
+    m_mainLayout->setContentsMargins(2, 1, 2, 4);
+    m_mainLayout->addLayout(m_topLayout);
 
     if (highlightedByFilter) // Show which filtering rules caused this item to be highlighted
     {
         QVariantMap filterMatches = activity->getFilterMatches();
         if (filterMatches.value("filterAction").toInt() == FilterChecker::Highlight)
         {
-            this->filterMatchesWidget = new FilterMatchesWidget(filterMatches, this);
-            mainLayout->addWidget(filterMatchesWidget);
+            m_filterMatchesWidget = new FilterMatchesWidget(filterMatches,
+                                                            this);
+            m_mainLayout->addWidget(m_filterMatchesWidget);
             // FIXME -- TODO: make this widget optional
         }
     }
 
-    this->setLayout(mainLayout);
+    this->setLayout(m_mainLayout);
 
     qDebug() << "MinorFeedItem created";
 }
@@ -388,40 +389,41 @@ MinorFeedItem::~MinorFeedItem()
  */
 void MinorFeedItem::setItemAsNew(bool isNew, bool informFeed)
 {
-    itemIsNew = isNew;
+    m_itemIsNew = isNew;
 
-    if (itemIsNew)
+    if (m_itemIsNew)
     {
         this->setAutoFillBackground(true);
         this->setBackgroundRole(QPalette::Mid);
 
-        timestampLabel->setStyleSheet("QLabel "
-                                      "{ background-color: qlineargradient(spread:pad,"
-                                      "                    x1:0, y1:0, x2:1, y2:0,"
-                                      "                    stop:0   palette(highlight),"
-                                      "                    stop:0.2 palette(base),"
-                                      "                    stop:0.8 palette(base),"
-                                      "                    stop:1   palette(highlight));"
-                                      "}"
-                                      "QLabel:hover "
-                                      "{ color: palette(highlighted-text);   "
-                                      "  background-color: palette(highlight)"
-                                      "}");
+        m_timestampLabel->setStyleSheet("QLabel "
+                                        "{ background-color: "
+                                        "      qlineargradient(spread:pad,"
+                                        "      x1:0, y1:0, x2:1, y2:0,"
+                                        "      stop:0   palette(highlight),"
+                                        "      stop:0.2 palette(base),"
+                                        "      stop:0.8 palette(base),"
+                                        "      stop:1   palette(highlight));"
+                                        "}"
+                                        "QLabel:hover "
+                                        "{ color: palette(highlighted-text);   "
+                                        "  background-color: palette(highlight)"
+                                        "}");
     }
     else
     {
         this->setAutoFillBackground(false);
         this->setBackgroundRole(QPalette::Window);
 
-        timestampLabel->setStyleSheet("QLabel:hover "
-                                      "{ color: palette(highlighted-text);   "
-                                      "  background-color: palette(highlight)"
-                                      "}");
+        m_timestampLabel->setStyleSheet("QLabel:hover "
+                                        "{ color: palette(highlighted-text);   "
+                                        "  background-color: palette(highlight)"
+                                        "}");
 
         if (informFeed)
         {
             bool wasHighlighted = false;
-            if (this->itemHighlightType != -1)
+            if (m_itemHighlightType != -1)
             {
                 wasHighlighted = true;
             }
@@ -433,7 +435,7 @@ void MinorFeedItem::setItemAsNew(bool isNew, bool informFeed)
 
 bool MinorFeedItem::isNew()
 {
-    return this->itemIsNew;
+    return m_itemIsNew;
 }
 
 
@@ -445,27 +447,28 @@ bool MinorFeedItem::isNew()
  */
 void MinorFeedItem::setFuzzyTimeStamp()
 {
-    this->timestampLabel->setText(Timestamp::fuzzyTime(createdAtTimestamp));
+    m_timestampLabel->setText(Timestamp::fuzzyTime(m_createdAtTimestamp));
 }
 
+
 void MinorFeedItem::syncAvatarFollowState()
 {
-    this->avatarButton->syncFollowState();
-    if (haveTargetAvatar)
+    m_avatarButton->syncFollowState();
+    if (m_haveTargetAvatar)
     {
-        this->targetAvatarButton->syncFollowState();
+        m_targetAvatarButton->syncFollowState();
     }
 }
 
 
 int MinorFeedItem::getItemHighlightType()
 {
-    return this->itemHighlightType;
+    return m_itemHighlightType;
 }
 
 QString MinorFeedItem::getActivityId()
 {
-    return this->activityId;
+    return m_activityId;
 }
 
 
@@ -480,31 +483,31 @@ void MinorFeedItem::openOriginalPost()
 {
     // Create a fake activity for the object
     QVariantMap originalPostMap;
-    if (!inReplyToMap.isEmpty())
+    if (!m_inReplyToMap.isEmpty())
     {
-        originalPostMap.insert("object", this->inReplyToMap);
-        originalPostMap.insert("actor",
-                               this->inReplyToMap.value("author").toMap());
+        originalPostMap.insert("object", m_inReplyToMap);
+        originalPostMap.insert("actor",  m_inReplyToMap.value("author")
+                                                       .toMap());
     }
     else
     {
-        originalPostMap.insert("object", this->originalObjectMap);
-        originalPostMap.insert("actor",
-                               this->originalObjectMap.value("author").toMap());
+        originalPostMap.insert("object", m_originalObjectMap);
+        originalPostMap.insert("actor",  m_originalObjectMap.value("author")
+                                                            .toMap());
     }
 
     ASActivity *originalPostActivity = new ASActivity(originalPostMap,
-                                                      pController->currentUserId(),
+                                                      m_pumpController->currentUserId(),
                                                       this);
 
     Post *referencedPost = new Post(originalPostActivity,
                                     false, // Not highlighted
                                     true,  // Post is standalone
-                                    pController,
-                                    globalObj,
+                                    m_pumpController,
+                                    m_globalObject,
                                     nullptr); // Make it an independent window
     referencedPost->show();
-    connect(pController, &PumpController::commentsReceived,
+    connect(m_pumpController, &PumpController::commentsReceived,
             referencedPost, &Post::setAllComments);
     referencedPost->requestCommenterComments();
 }
@@ -515,13 +518,13 @@ void MinorFeedItem::showUrlInfo(QString url)
 {
     if (!url.isEmpty())
     {
-        this->pController->showTransientMessage(url);
+        m_pumpController->showTransientMessage(url);
 
         qDebug() << "Link hovered in Minor Feed:" << url;
     }
     else
     {
-        this->pController->showTransientMessage("");
+        m_pumpController->showTransientMessage(QString());
     }
 }
 
@@ -537,13 +540,13 @@ void MinorFeedItem::showUrlInfo(QString url)
  */
 void MinorFeedItem::mousePressEvent(QMouseEvent *event)
 {
-    if (itemIsNew)
+    if (m_itemIsNew)
     {
         this->setItemAsNew(false, // Mark as not new
                            true); // Inform the feed
 
         // Avoid flickering of the "new" effect later
-        this->timestampLabel->repaint();
+        m_timestampLabel->repaint();
     }
 
     event->accept();
@@ -556,7 +559,7 @@ void MinorFeedItem::mousePressEvent(QMouseEvent *event)
  */
 void MinorFeedItem::leaveEvent(QEvent *event)
 {
-    this->pController->showTransientMessage("");
+    m_pumpController->showTransientMessage(QString());
 
     event->accept();
 }
@@ -564,7 +567,7 @@ void MinorFeedItem::leaveEvent(QEvent *event)
 
 void MinorFeedItem::paintEvent(QPaintEvent *event)
 {
-    if (verbIconType == 0 || verbIcons.size() < 2)
+    if (m_verbIconType == 0 || m_verbIcons.size() < 2)
     {
         // Set not to show activity icons, or icon definitions are wrong
         event->ignore();
@@ -573,11 +576,11 @@ void MinorFeedItem::paintEvent(QPaintEvent *event)
 
     //////////// FIXME - TODO -- This needs a lot of optimizing all around
 
-    QIcon icon = QIcon::fromTheme(verbIcons.first(),
-                                  QIcon(verbIcons.last()));
+    QIcon icon = QIcon::fromTheme(m_verbIcons.first(),
+                                  QIcon(m_verbIcons.last()));
 
     bool subtle = false;
-    if (verbIconType == 2 || verbIconType == 4)
+    if (m_verbIconType == 2 || m_verbIconType == 4)
     {
         subtle = true;
     }
@@ -586,24 +589,24 @@ void MinorFeedItem::paintEvent(QPaintEvent *event)
     int iconOffset = 0;
     if (subtle)
     {
-        iconPixmap = icon.pixmap(verbIconSizeSubtle, verbIconSizeSubtle);
-        if (verbIconType == 4) // icon-after, subtle
+        iconPixmap = icon.pixmap(m_verbIconSizeSubtle, m_verbIconSizeSubtle);
+        if (m_verbIconType == 4) // icon-after, subtle
         {
-            iconOffset =  verbIconSize / 2; // Based on original icon size
+            iconOffset =  m_verbIconSize / 2; // Based on original icon size
         }
     }
     else
     {
-        iconPixmap = icon.pixmap(verbIconSize, verbIconSize);
-        if (verbIconType == 3) // icon-after
+        iconPixmap = icon.pixmap(m_verbIconSize, m_verbIconSize);
+        if (m_verbIconType == 3) // icon-after
         {
-            iconOffset = verbIconSize + this->topLayout->spacing();
+            iconOffset = m_verbIconSize + m_topLayout->spacing();
         }
     }
 
 
     int iconPos;
-    if (itemIsOwn)
+    if (m_itemIsOwn)
     {
         iconPos = this->width() - iconPixmap.width() - iconOffset;
     }
