@@ -79,40 +79,41 @@ protected:
 
 
 private:
-    PumpController *pController;
-    GlobalObject *globalObj;
-
-    QVBoxLayout *mainLayout;
-    QHBoxLayout *topLayout;
-    QVBoxLayout *leftLayout;
-    QVBoxLayout *rightLayout;
-    QHBoxLayout *rightLowerLayout;
+    QVBoxLayout *m_mainLayout;
+    QHBoxLayout *m_topLayout;
+    QVBoxLayout *m_leftLayout;
+    QVBoxLayout *m_rightLayout;
+    QHBoxLayout *m_rightLowerLayout;
 
 
-    int verbIconType;
-    QStringList verbIcons;
-    int verbIconSize;
-    int verbIconSizeSubtle;
+    int m_verbIconType;
+    QStringList m_verbIcons;
+    int m_verbIconSize;
+    int m_verbIconSizeSubtle;
 
-    AvatarButton *avatarButton;
-    QLabel *timestampLabel;
-    QLabel *activityDescriptionLabel;
+    AvatarButton *m_avatarButton;
+    QLabel *m_timestampLabel;
+    QLabel *m_activityDescriptionLabel;
 
-    QPushButton *openButton;
+    QPushButton *m_openButton;
 
-    QVariantMap originalObjectMap;
-    QVariantMap inReplyToMap;
+    QVariantMap m_originalObjectMap;
+    QVariantMap m_inReplyToMap;
 
-    AvatarButton *targetAvatarButton;
-    bool haveTargetAvatar;
+    AvatarButton *m_targetAvatarButton;
+    bool m_haveTargetAvatar;
 
-    FilterMatchesWidget *filterMatchesWidget;
+    FilterMatchesWidget *m_filterMatchesWidget;
 
-    bool itemIsOwn;
-    bool itemIsNew;
-    int itemHighlightType;
-    QString createdAtTimestamp;
-    QString activityId;
+    bool m_itemIsOwn;
+    bool m_itemIsNew;
+    int m_itemHighlightType;
+    QString m_createdAtTimestamp;
+    QString m_activityId;
+
+
+    PumpController *m_pumpController;
+    GlobalObject *m_globalObject;
 };
 
 #endif // MINORFEEDITEM_H
