@@ -105,9 +105,9 @@ QString MiscHelpers::getSuggestedFilename(QString authorId,
         suggestedFilename.append("_" + postTitle);
     }
 
-    suggestedFilename.replace("@", "-"); // Avoid certain chars from author ID
-    suggestedFilename.replace(".", "-");
-    suggestedFilename.replace("/", "-");
+    suggestedFilename.replace("@", QStringLiteral("-")); // Avoid certain chars from author ID
+    suggestedFilename.replace(".", QStringLiteral("-"));
+    suggestedFilename.replace("/", QStringLiteral("-"));
     suggestedFilename.remove("?");
     suggestedFilename.remove("!");
     suggestedFilename.remove("*");
@@ -115,13 +115,13 @@ QString MiscHelpers::getSuggestedFilename(QString authorId,
     suggestedFilename.remove(";");
     suggestedFilename.remove("\"");
 
-    suggestedFilename.replace(" ", "_"); // Avoid spaces in filename
+    suggestedFilename.replace(" ", QStringLiteral("_")); // Avoid spaces in filename
 
     suggestedFilename.append("_" + originalFilename); // Something like A53r2w.png
 
 
     // Extension for 'file' attachments is given as .bin by server, for now
-    if (postType == "file") // so determine a proper one based on mime info
+    if (postType == QStringLiteral("file")) // so determine a proper one based on mime info
     {
         QMimeDatabase mimeDb;
         QMimeType mime = mimeDb.mimeTypeForName(mimeType);
@@ -129,7 +129,7 @@ QString MiscHelpers::getSuggestedFilename(QString authorId,
         QString suggestedExtension = mime.preferredSuffix();
         if (!suggestedExtension.isEmpty())
         {
-            if (suggestedFilename.endsWith(".bin"))
+            if (suggestedFilename.endsWith(QStringLiteral(".bin")))
             {
                 suggestedFilename.remove(-3, 3);
             }
