@@ -30,13 +30,10 @@
 #include <QTextDocument>
 #include <QImageReader>
 #include <QMovie>
-
-#include <QDesktopServices>
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 #include <QStandardPaths>
-#endif
-
-#include <magic.h>
+#include <QMimeDatabase>
+#include <QDesktopServices>
+#include <QMessageBox>
 
 
 #include <QDebug>
@@ -52,11 +49,18 @@ public:
     static QString getCachedImageFilename(QString url);
 
     static QString getSuggestedFilename(QString authorId, QString postType,
-                                        QString postTitle, QString fileUrl);
+                                        QString postTitle, QString fileUrl,
+                                        QString mimeType="");
 
     static QString getFileMimeType(QString fileUri);
     static int getImageWidth(QString fileURI);
     static bool isImageAnimated(QString fileUri);
+    static QStringList iconsForActivity(QString verb);
+
+    static const QStringList imageExtensions();
+    static const QStringList audioExtensions();
+    static const QStringList videoExtensions();
+    static const QString fileFilterString(QStringList extensions);
 
     static QString fixLongName(QString name);
 
@@ -76,6 +80,8 @@ public:
     static QString mediaHtmlBase(QString postType, QString attachmentFilename,
                                  QString tooltipMessage, QString belowMessage,
                                  int imageWidth = -1);
+
+    static bool openUrl(QUrl url, QWidget *parentWidget);
 };
 
 #endif // MISCHELPERS_H
