@@ -21,17 +21,20 @@
 #include "notifications.h"
 
 
-FDNotifications::FDNotifications(QObject* parent) : QObject(parent)
+FDNotifications::FDNotifications(QObject *parent) : QObject(parent)
 {
     qDebug() << "Creating FreeDesktop Notifier";
-    this->notificationsAvailable = false; // Init as false, detect later
-    this->notificationDuration = 4000; // Milliseconds
+    m_notificationsAvailable = false; // Init as false, detect later
+    m_notificationType = FDNotifications::SystemNotifications;
+    m_notificationDuration = 4000;    // Milliseconds
+
 
 #ifdef QT_DBUS_LIB
-    this->bus = new QDBusConnection(QDBusConnection::sessionBus());
-    if (bus->isConnected())
+    m_busConnection = new QDBusConnection(QDBusConnection::sessionBus());
+    if (m_busConnection->isConnected())
     {
-        QDBusReply<QStringList> busReply = bus->interface()->registeredServiceNames();
+        QDBusReply<QStringList> busReply = m_busConnection->interface()
+                                                          ->registeredServiceNames();
         qDebug() << "Listing D-Bus services...";
         if (busReply.isValid())
         {
@@ -40,7 +43,7 @@ FDNotifications::FDNotifications(QObject* parent) : QObject(parent)
                 if (serviceName == "org.freedesktop.Notifications")
                 {
                     qDebug() << "org.freedesktop.Notifications D-Bus service found!";
-                    this->notificationsAvailable = true;
+                    m_notificationsAvailable = true;
                 }
             }
         }
@@ -48,7 +51,7 @@ FDNotifications::FDNotifications(QObject* parent) : QObject(parent)
     else
     {
         qDebug() << "D-Bus unavailable!";
-        notificationsAvailable = false;
+        m_notificationsAvailable = false;
     }
 #endif
 
@@ -59,7 +62,7 @@ FDNotifications::FDNotifications(QObject* parent) : QObject(parent)
 FDNotifications::~FDNotifications()
 {
 #ifdef QT_DBUS_LIB
-    delete bus;
+    delete m_busConnection;
 #endif
     qDebug() << "FreeDesktop Notifier destroyed";
 }
@@ -69,8 +72,8 @@ FDNotifications::~FDNotifications()
 
 bool FDNotifications::areNotificationsAvailable()
 {
-    qDebug() << "Are notifications available?" << notificationsAvailable;
-    return notificationsAvailable;
+    qDebug() << "Are notifications available?" << m_notificationsAvailable;
+    return m_notificationsAvailable;
 }
 
 void FDNotifications::setNotificationOptions(int style, int duration,
@@ -78,52 +81,53 @@ void FDNotifications::setNotificationOptions(int style, int duration,
                                              bool notifyNewMW, bool notifyHLMW,
                                              bool notifyErr)
 {
-    this->notificationType = style;
-    this->notificationDuration = duration * 1000; // To ms
+    m_notificationType = style;
+    m_notificationDuration = duration * 1000; // To milliseconds
 
-    this->notifyNewTimeline  = notifyNewTL;
-    this->notifyHLTimeline   = notifyHLTL;
-    this->notifyNewMeanwhile = notifyNewMW;
-    this->notifyHLMeanwhile  = notifyHLMW;
-    this->notifyErrors       = notifyErr;
+    m_notifyNewTimeline  = notifyNewTL;
+    m_notifyHLTimeline   = notifyHLTL;
+    m_notifyNewMeanwhile = notifyNewMW;
+    m_notifyHLMeanwhile  = notifyHLMW;
+    m_notifyErrors       = notifyErr;
 
     qDebug() << "Notification type set to"
-             << this->notificationType << "-- FD.o/Qt/none; Duration:"
-             << this->notificationDuration;
-    qDebug() << this->notifyNewTimeline << this->notifyHLTimeline
-             << this->notifyNewMeanwhile << this->notifyHLMeanwhile
-             << this->notifyErrors;
+             << m_notificationType << "-- FD.o/Qt/none; Duration:"
+             << m_notificationDuration;
+    qDebug() << "Things to notify:"
+             << m_notifyNewTimeline << m_notifyHLTimeline
+             << m_notifyNewMeanwhile << m_notifyHLMeanwhile
+             << m_notifyErrors;
 }
 
 void FDNotifications::setCurrentUserId(QString newId)
 {
-    this->currentUserId = newId;
+    m_currentUserId = newId;
 }
 
 
 bool FDNotifications::getNotifyNewTimeline()
 {
-    return this->notifyNewTimeline;
+    return m_notifyNewTimeline;
 }
 
 bool FDNotifications::getNotifyHLTimeline()
 {
-    return this->notifyHLTimeline;
+    return m_notifyHLTimeline;
 }
 
 bool FDNotifications::getNotifyNewMeanwhile()
 {
-    return this->notifyNewMeanwhile;
+    return m_notifyNewMeanwhile;
 }
 
 bool FDNotifications::getNotifyHLMeanwhile()
 {
-    return this->notifyHLMeanwhile;
+    return m_notifyHLMeanwhile;
 }
 
 bool FDNotifications::getNotifyErrors()
 {
-    return this->notifyErrors;
+    return m_notifyErrors;
 }
 
 
@@ -137,16 +141,16 @@ bool FDNotifications::getNotifyErrors()
 void FDNotifications::showMessage(QString message)
 {
     // if notifications are disabled
-    if (this->notificationType == FDNotifications::NoNotifications)
+    if (m_notificationType == FDNotifications::NoNotifications)
     {
         return;
     }
 
-    QString notificationTitle = "Dianara - " + currentUserId;
+    const QString notificationTitle = "Dianara - " + m_currentUserId;
 
     // If FD.org notifications are not available, or Qt's Balloon ones are selected
-    if (!notificationsAvailable
-       || notificationType == FDNotifications::FallbackNotifications)
+    if (!m_notificationsAvailable
+       || m_notificationType == FDNotifications::FallbackNotifications)
     {
         qDebug() << "FreeDesktop Notifications are NOT available, "
                     "or balloon notifications selected";
@@ -159,10 +163,10 @@ void FDNotifications::showMessage(QString message)
         message.remove("<u>");
         message.remove("</u>");
         message.replace("<br>", "\n");
-        // FIXME: remove also <a href=...>
+
         emit showFallbackNotification(notificationTitle,
                                       message,
-                                      this->notificationDuration);
+                                      m_notificationDuration);
 
         return;
     }
@@ -178,8 +182,8 @@ void FDNotifications::showMessage(QString message)
     QDBusMessage dBusMessage = QDBusMessage::createMethodCall(
                                  "org.freedesktop.Notifications",
                                  "/org/freedesktop/Notifications",
-                                 "",
-                                 "Notify");
+                                 QString(),
+                                 QStringLiteral("Notify"));
 
 
     // --- D-Bus Notify call ----------------------------------------------
@@ -188,26 +192,30 @@ void FDNotifications::showMessage(QString message)
     // QStringList actions, QVariantMap hints, int timeout)
 
     QList<QVariant> arguments;
-    arguments << QString("Dianara");   // app_name
-    arguments << uint(0);              // replaces_id
+    arguments << QStringLiteral("Dianara");     // app_name
+    arguments << uint(0);                       // replaces_id
     if (QIcon::hasThemeIcon("dianara"))
     {
-        arguments << QString("dianara"); // app_icon, if "dianara" icon is in theme
+        arguments << QStringLiteral("dianara"); // app_icon, if "dianara" icon is in theme
     }
     else
-    {
-        arguments << QString("dialog-information");   // app_icon otherwise
+    {                                           // app_icon otherwise
+        arguments << QStringLiteral("dialog-information");
     }
+
+    QStringList actions; // Handled on MainWindow::onNotificationAction()
+    actions << QString("dianara_%1_show").arg(qApp->applicationPid())
+            << tr("Show");
     arguments << notificationTitle;
     arguments << message;
-    arguments << QStringList();              // actions
-    arguments << QVariantMap();              // hints
-    arguments << this->notificationDuration; // timeout, in milliseconds
+    arguments << actions;
+    arguments << QVariantMap();                 // hints
+    arguments << m_notificationDuration;        // timeout, in milliseconds
 
     dBusMessage.setArguments(arguments);
 
 
-    qDebug() << "sending DBUS call to org.freedesktop.Notifications Notify";
-    this->bus->asyncCall(dBusMessage);
+    qDebug() << "Sending DBUS call to org.freedesktop.Notifications Notify()";
+    m_busConnection->asyncCall(dBusMessage);
 #endif
 }
