@@ -38,7 +38,7 @@ class FDNotifications : public QObject
     Q_OBJECT
 
 public:
-    FDNotifications(QObject* parent);
+    FDNotifications(QObject *parent);
     ~FDNotifications();
 
     bool areNotificationsAvailable();
@@ -66,7 +66,8 @@ public:
 
 
 signals:
-    void showFallbackNotification(QString title, QString message, int duration);
+    void showFallbackNotification(QString title, QString message,
+                                  int duration);
 
 
 public slots:
@@ -75,21 +76,21 @@ public slots:
 
 private:
 #ifdef QT_DBUS_LIB
-    QDBusConnection *bus;
+    QDBusConnection *m_busConnection;
 #endif
 
-    bool notificationsAvailable;
+    bool m_notificationsAvailable;
 
-    int notificationType;
-    int notificationDuration;
+    int m_notificationType;
+    int m_notificationDuration;
 
-    bool notifyNewTimeline;
-    bool notifyHLTimeline;
-    bool notifyNewMeanwhile;
-    bool notifyHLMeanwhile;
-    bool notifyErrors;
+    bool m_notifyNewTimeline;
+    bool m_notifyHLTimeline;
+    bool m_notifyNewMeanwhile;
+    bool m_notifyHLMeanwhile;
+    bool m_notifyErrors;
 
-    QString currentUserId;
+    QString m_currentUserId;
 };
 
 #endif // NOTIFICATIONS_H
