@@ -62,28 +62,28 @@ public slots:
 
 
 private:
-    QVBoxLayout *mainLayout;
-    QHBoxLayout *topLayout;
-    QHBoxLayout *middleLayout;
-    QHBoxLayout *bottomLayout;
+    QVBoxLayout *m_mainLayout;
+    QHBoxLayout *m_topLayout;
+    QHBoxLayout *m_middleLayout;
+    QHBoxLayout *m_bottomLayout;
 
-    QLabel *messageLabel;
-    QSpinBox *pageNumberSpinbox;
-    QLabel *rangeLabel;
+    QLabel *m_messageLabel;
+    QSpinBox *m_pageNumberSpinbox;
+    QLabel *m_rangeLabel;
 
-    QPushButton *firstButton;
-    QPushButton *lastButton;
+    QPushButton *m_firstButton;
+    QPushButton *m_lastButton;
 
-    QPushButton *newerButton;
-    QSlider *pageNumberSlider;
-    QPushButton *olderButton;
+    QPushButton *m_newerButton;
+    QSlider *m_pageNumberSlider;
+    QPushButton *m_olderButton;
 
-    QPushButton *goButton;
-    QPushButton *closeButton;
+    QPushButton *m_goButton;
+    QPushButton *m_closeButton;
 
-    QAction *closeAction;
+    QAction *m_closeAction;
 
-    int initialPage;
+    int m_initialPage;
 };
 
 #endif // PAGESELECTOR_H
