@@ -25,64 +25,68 @@ PeopleWidget::PeopleWidget(QString buttonText,
                            PumpController *pumpController,
                            QWidget *parent) : QWidget(parent)
 {
-    this->setMinimumSize(120, 120);
-
-    this->pController = pumpController;
-    connect(pController, &PumpController::contactListReceived,
+    m_pumpController = pumpController;
+    connect(m_pumpController, &PumpController::contactListReceived,
             this, &PeopleWidget::updateAllContactsList);
 
-    connect(pController, &PumpController::contactFollowed,
+    connect(m_pumpController, &PumpController::contactFollowed,
             this, &PeopleWidget::addContact);
-    connect(pController, &PumpController::contactUnfollowed,
+    connect(m_pumpController, &PumpController::contactUnfollowed,
             this, &PeopleWidget::removeContact);
 
 
-    this->searchLabel = new QLabel(tr("&Search:"), this);
+    this->setMinimumSize(240, 280);
 
-    this->searchLineEdit = new QLineEdit(this);
-    searchLineEdit->setPlaceholderText(tr("Enter a name here to search for it"));
-    searchLineEdit->setClearButtonEnabled(true);
+    m_searchLabel = new QLabel(tr("&Search:"), this);
 
-    searchLabel->setBuddy(searchLineEdit);
-    connect(searchLineEdit, &QLineEdit::textChanged,
+    m_searchLineEdit = new QLineEdit(this);
+    m_searchLineEdit->setPlaceholderText(tr("Enter a name here to search for it"));
+    m_searchLineEdit->setClearButtonEnabled(true);
+
+    m_searchLabel->setBuddy(m_searchLineEdit);
+    connect(m_searchLineEdit, &QLineEdit::textChanged,
             this, &PeopleWidget::filterList);
 
 
-    itemModel = new QStandardItemModel(this);
+    m_itemModel = new QStandardItemModel(this);
 
-    filterModel = new QSortFilterProxyModel(this);
-    filterModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
-    filterModel->setSortCaseSensitivity(Qt::CaseInsensitive);
-    filterModel->setSourceModel(itemModel);
+    m_filterModel = new QSortFilterProxyModel(this);
+    m_filterModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
+    m_filterModel->setSortCaseSensitivity(Qt::CaseInsensitive);
+    m_filterModel->setSourceModel(m_itemModel);
 
-    allContactsListView = new QListView(this);
-    allContactsListView->setAlternatingRowColors(true);
-    allContactsListView->setEditTriggers(QAbstractItemView::NoEditTriggers);
-    allContactsListView->setDragDropMode(QListView::DragDrop);
-    allContactsListView->setDefaultDropAction(Qt::CopyAction);
-    allContactsListView->setModel(filterModel);
-    connect(allContactsListView, &QAbstractItemView::activated,
+    m_allContactsListView = new QListView(this);
+    m_allContactsListView->setAlternatingRowColors(true);
+    m_allContactsListView->setEditTriggers(QAbstractItemView::NoEditTriggers);
+    m_allContactsListView->setDragDropMode(QListView::DragDrop);
+    m_allContactsListView->setDefaultDropAction(Qt::CopyAction);
+    m_allContactsListView->setModel(m_filterModel);
+    connect(m_allContactsListView, &QAbstractItemView::activated,
             this, &PeopleWidget::returnClickedContact);
 
 
-    addToButton = new QPushButton(QIcon::fromTheme("list-add",
-                                                   QIcon(":/images/list-add.png")),
-                                  buttonText,
-                                  this);
-    connect(addToButton, &QAbstractButton::clicked,
+    m_addToButton = new QPushButton(QIcon::fromTheme("list-add",
+                                                     QIcon(":/images/list-add.png")),
+                                    buttonText,
+                                    this);
+    connect(m_addToButton, &QAbstractButton::clicked,
             this, &PeopleWidget::returnContact);
 
 
 
     // Layout
-    mainLayout = new QVBoxLayout();
-    mainLayout->addWidget(searchLabel);
-    mainLayout->addWidget(searchLineEdit);
-    mainLayout->addSpacing(2);
-    mainLayout->addWidget(allContactsListView);
-    mainLayout->addSpacing(4);
-    mainLayout->addWidget(addToButton);
-    this->setLayout(mainLayout);
+    m_buttonsLayout = new QHBoxLayout();
+    m_buttonsLayout->addWidget(m_addToButton);
+    m_buttonsLayout->addStretch();
+
+    m_mainLayout = new QVBoxLayout();
+    m_mainLayout->addWidget(m_searchLabel);
+    m_mainLayout->addWidget(m_searchLineEdit);
+    m_mainLayout->addSpacing(2);
+    m_mainLayout->addWidget(m_allContactsListView);
+    m_mainLayout->addSpacing(4);
+    m_mainLayout->addLayout(m_buttonsLayout);
+    this->setLayout(m_mainLayout);
 
 
 
@@ -91,28 +95,29 @@ PeopleWidget::PeopleWidget(QString buttonText,
         //allContactsListWidget->setSelectionMode(QListView::ExtendedSelection);
 
         // FIXME 1.4.x: For now, Single selection mode in both cases
-        allContactsListView->setSelectionMode(QListView::SingleSelection);
+        m_allContactsListView->setSelectionMode(QListView::SingleSelection);
     }
     else     // StandaloneWidget
     {
         this->setWindowTitle(tr("Add a contact to a list")
                              + " - Dianara");
-        this->setWindowIcon(QIcon::fromTheme("system-users"));
+        this->setWindowIcon(QIcon::fromTheme("system-users",
+                                             QIcon(":/images/button-users.png")));
         this->setWindowFlags(Qt::Dialog);
         this->setWindowModality(Qt::WindowModal);
+        this->setMinimumSize(520, 500);
 
-        allContactsListView->setSelectionMode(QListView::SingleSelection);
+        m_allContactsListView->setSelectionMode(QListView::SingleSelection);
 
-        cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
-                                                        QIcon(":/images/button-cancel.png")),
-                                       tr("&Cancel"),
-                                       this);
-        connect(cancelButton, &QAbstractButton::clicked,
+        m_cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel",
+                                                          QIcon(":/images/button-cancel.png")),
+                                         tr("&Cancel"),
+                                         this);
+        connect(m_cancelButton, &QAbstractButton::clicked,
                 this, &QWidget::hide);
-        mainLayout->addWidget(cancelButton);
+        m_buttonsLayout->addWidget(m_cancelButton);
     }
 
-
     qDebug() << "PeopleWidget created";
 }
 
@@ -125,10 +130,10 @@ PeopleWidget::~PeopleWidget()
 
 void PeopleWidget::resetWidget()
 {
-    this->allContactsListView->scrollToTop();
+    m_allContactsListView->scrollToTop();
 
-    this->searchLineEdit->clear(); // Might also trigger filterLists()
-    this->searchLineEdit->setFocus();
+    m_searchLineEdit->clear(); // Might also trigger filterLists()
+    m_searchLineEdit->setFocus();
 }
 
 
@@ -139,7 +144,7 @@ QStandardItem *PeopleWidget::createContactItem(ASPerson *contact)
     QString singleContactString = contact->getNameWithFallback()
                                   + "   <" + contact->getId() + ">";
 
-    QString avatarFilename = MiscHelpers::getCachedAvatarFilename(contact->getAvatar());
+    QString avatarFilename = MiscHelpers::getCachedAvatarFilename(contact->getAvatarUrl());
     QPixmap avatarPixmap = QPixmap(avatarFilename);
     if (!avatarPixmap.isNull())
     {
@@ -154,7 +159,9 @@ QStandardItem *PeopleWidget::createContactItem(ASPerson *contact)
     }
 
     item->setToolTip(contact->getTooltipInfo());
-    item->setData(contact->getUrl(), Qt::UserRole + 1);
+    item->setData(contact->getNameWithFallback(), Qt::UserRole + 1);
+    item->setData(contact->getId(),               Qt::UserRole + 2);
+    item->setData(contact->getUrl(),              Qt::UserRole + 3);
 
     return item;
 }
@@ -173,8 +180,8 @@ QStandardItem *PeopleWidget::createContactItem(ASPerson *contact)
  */
 void PeopleWidget::filterList(QString searchTerms)
 {
-    this->filterModel->setFilterFixedString(searchTerms);
-    filterModel->sort(0);
+    m_filterModel->setFilterFixedString(searchTerms);
+    m_filterModel->sort(0);
 }
 
 
@@ -195,26 +202,26 @@ void PeopleWidget::updateAllContactsList(QString listType,
 
     if (totalReceivedCount <= 200)  // Only on first batch
     {
-        this->itemModel->clear();
+        m_itemModel->clear();
     }
 
     foreach (QVariant contactVariant, contactsVariantList)
     {
         ASPerson *contact = new ASPerson(contactVariant.toMap(), this);
         QStandardItem *item = this->createContactItem(contact);
-        itemModel->appendRow(item);
+        m_itemModel->appendRow(item);
 
         delete contact;
     }
 
-    filterModel->sort(0); // Sort by first column
+    m_filterModel->sort(0); // Sort by first column
 }
 
 
 
 void PeopleWidget::addContact(ASPerson *contact)
 {
-    itemModel->appendRow(this->createContactItem(contact));
+    m_itemModel->appendRow(this->createContactItem(contact));
 
     contact->deleteLater();
 }
@@ -222,10 +229,10 @@ void PeopleWidget::addContact(ASPerson *contact)
 
 void PeopleWidget::removeContact(ASPerson *contact)
 {
-    foreach (QStandardItem *item, itemModel->findItems("<" + contact->getId() + ">",
-                                                       Qt::MatchEndsWith))
+    foreach (QStandardItem *item, m_itemModel->findItems("<" + contact->getId() + ">",
+                                                         Qt::MatchEndsWith))
     {
-        itemModel->removeRow(item->row());
+        m_itemModel->removeRow(item->row());
     }
 
     contact->deleteLater();
@@ -241,19 +248,18 @@ void PeopleWidget::removeContact(ASPerson *contact)
  */
 void PeopleWidget::returnContact()
 {
-    if (this->allContactsListView->currentIndex().row() != -1)
+    if (m_allContactsListView->currentIndex().row() != -1)
     {
-        QStandardItem *item = itemModel->itemFromIndex(filterModel->mapToSource(allContactsListView->currentIndex()));
+        QStandardItem *item = m_itemModel->itemFromIndex(m_filterModel->mapToSource(m_allContactsListView->currentIndex()));
 
-        QIcon icon;
         if (item != 0)
         {
-            icon = item->icon();
+            emit addButtonPressed(item->icon(),
+                                  item->text(),
+                                  item->data(Qt::UserRole + 1).toString(),
+                                  item->data(Qt::UserRole + 2).toString(),
+                                  item->data(Qt::UserRole + 3).toString());
         }
-
-        emit addButtonPressed(icon,
-                              allContactsListView->currentIndex().data().toString(), // name <id>
-                              allContactsListView->currentIndex().data(Qt::UserRole + 1).toString()); // URL
     }
 }
 
@@ -264,7 +270,7 @@ void PeopleWidget::returnContact()
  */
 void PeopleWidget::returnClickedContact(QModelIndex modelIndex)
 {
-    QStandardItem *item = itemModel->itemFromIndex(filterModel->mapToSource(modelIndex));
+    QStandardItem *item = m_itemModel->itemFromIndex(m_filterModel->mapToSource(modelIndex));
 
     QIcon icon;
     if (item != 0) // Valid item
@@ -274,5 +280,7 @@ void PeopleWidget::returnClickedContact(QModelIndex modelIndex)
 
     emit contactSelected(icon,
                          modelIndex.data().toString(),
-                         modelIndex.data(Qt::UserRole + 1).toString());
+                         modelIndex.data(Qt::UserRole + 1).toString(),
+                         modelIndex.data(Qt::UserRole + 2).toString(),
+                         modelIndex.data(Qt::UserRole + 3).toString());
 }
