@@ -375,7 +375,6 @@ Post::Post(ASActivity *activity,
     postAuthorNameLabel->setWordWrap(true); ///////////////// FIXME: make optional
     postAuthorNameLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     postAuthorNameLabel->setFont(authorFont);
-    postAuthorNameLabel->setToolTip(authorPerson->getTooltipInfo());
     // Ensure a certain width for the metadata column, by setting a minimum width for this label
     postAuthorNameLabel->setMinimumWidth(90); // FIXME: use font metrics for some chars instead
 
@@ -389,7 +388,7 @@ Post::Post(ASActivity *activity,
     // Timestamp format is "Combined date and time in UTC", like
     // "2012-02-07T01:32:02Z" as per ISO8601 http://en.wikipedia.org/wiki/ISO_8601
 
-    postCreatedAtLabel = new HClabel("", this);
+    postCreatedAtLabel = new HClabel(QString(), this);
     postCreatedAtLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     postCreatedAtLabel->setFont(detailsFont);
     postCreatedAtLabel->setSizePolicy(QSizePolicy::Ignored,
@@ -414,7 +413,7 @@ Post::Post(ASActivity *activity,
 
 
     // Location information, if any
-    this->postLocationLabel = new HClabel("", this);
+    this->postLocationLabel = new HClabel(QString(), this);
     postLocationLabel->setFont(detailsFont);
     postLocationLabel->setSizePolicy(QSizePolicy::Ignored,
                                      QSizePolicy::Expanding);
@@ -466,7 +465,7 @@ Post::Post(ASActivity *activity,
     // Set these labels with parent=this, since we're gonna hide them right away
     // They'll be reparented to the layout, but not having a parent before that
     // would cause visual glitches
-    postLikesCountLabel = new HClabel("", this);
+    postLikesCountLabel = new HClabel(QString(), this);
     postLikesCountLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     postLikesCountLabel->setFont(detailsFont);
     postLikesCountLabel->setOpenExternalLinks(true);
@@ -486,7 +485,7 @@ Post::Post(ASActivity *activity,
     postCommentsCountLabel->hide();
 
 
-    postSharesCountLabel = new HClabel("", this);
+    postSharesCountLabel = new HClabel(QString(), this);
     postSharesCountLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     postSharesCountLabel->setFont(detailsFont);
     postSharesCountLabel->setOpenExternalLinks(true);
@@ -1024,7 +1023,7 @@ void Post::updateDataFromObject(ASObject *object)
     */
 
     // Set the initial likes, comments and shares (4 most recent)
-    int likesCount = object->getLikesCount().toInt();
+    int likesCount = object->getLikesCount();
     if (likesCount > 0)
     {
         this->postLikesCount = likesCount;
@@ -1034,7 +1033,7 @@ void Post::updateDataFromObject(ASObject *object)
     }
 
 
-    int commentsCount = object->getCommentsCount().toInt();
+    int commentsCount = object->getCommentsCount();
     if (commentsCount > 0
      && !standalone) // Don't set initial comments in standalone mode
     {                // It's unnecessary and messes up comment area size
@@ -1043,7 +1042,7 @@ void Post::updateDataFromObject(ASObject *object)
                                      commentsCount);
     }
 
-    int sharesCount = object->getSharesCount().toInt();
+    int sharesCount = object->getSharesCount();
     this->setSharesLabel(sharesCount);
     this->setShares(object->getLastSharesList(),
                     sharesCount);
@@ -1609,7 +1608,7 @@ void Post::setPostUnreadStatus()
     }
     else
     {
-        rightColumnFrame->setStyleSheet("");
+        rightColumnFrame->setStyleSheet(QString());
         postCreatedAtLabel->setHighlighted(false);
     }
 
@@ -1760,7 +1759,7 @@ void Post::likePost(bool like)
     this->pController->likePost(this->postId, this->postType,
                                 this->postAuthorId, like);
 
-    this->fixLikeButton(like ? "true" : "false");
+    this->fixLikeButton(like);
 
     connect(pController, SIGNAL(likeSet()),
             this, SLOT(getAllLikes()));
@@ -1774,22 +1773,22 @@ void Post::likePost(bool like)
  * Set the right labels and tooltips to the like button, depending on its state
  *
  */
-void Post::fixLikeButton(QString state)
+void Post::fixLikeButton(bool isLiked)
 {
-    if (state == "true")
+    if (isLiked)
     {
         likeButton->setToolTip("<b></b>"
                                + tr("You like this"));
         likeButton->setText(tr("Unlike"));
-        likeButton->setChecked(true);
     }
     else
     {
         likeButton->setToolTip("<b></b>"
                                + tr("Like this post"));
         likeButton->setText(tr("Like"));
-        likeButton->setChecked(false);
     }
+
+    likeButton->setChecked(isLiked);
 }
 
 
@@ -1949,7 +1948,7 @@ void Post::sharePost()
                                              shareConfirmString
                                              + "\n\n\n",
                                              tr("&Yes, share it"), tr("&No"),
-                                             "", 1, 1);
+                                             QString(), 1, 1);
 
     if (confirmation == 0)
     {
@@ -1968,7 +1967,7 @@ void Post::unsharePost()
                                              tr("Do you want to unshare %1's post?")
                                               .arg(this->postAuthorName),
                                              tr("&Yes, unshare it"), tr("&No"),
-                                             "", 1, 1);
+                                             QString(), 1, 1);
 
     if (confirmation == 0)
     {
@@ -2012,7 +2011,7 @@ void Post::deletePost()
                                              tr("Are you sure you want to "
                                                 "delete this post?"),
                                              tr("&Yes, delete it"), tr("&No"),
-                                             "", 1, 1);
+                                             QString(), 1, 1);
     if (confirmation == 0)
     {
         qDebug() << "Deleting post";
@@ -2082,7 +2081,7 @@ void Post::showHighlightedUrl(QString url)
 {
     if (!url.isEmpty())
     {
-        if (url.startsWith("image:/")) // Own image:/ URL
+        if (url.startsWith(QStringLiteral("image:/"))) // Own image:/ URL
         {
             QString statusMessage = this->seeFullImageString
                                     + " ("
@@ -2092,7 +2091,7 @@ void Post::showHighlightedUrl(QString url)
 
             this->pController->showTransientMessage(statusMessage);
         }
-        else if (url.startsWith("attachment:/"))
+        else if (url.startsWith(QStringLiteral("attachment:/")))
         {
             this->pController->showTransientMessage(this->downloadAttachmentString);
         }
@@ -2104,7 +2103,7 @@ void Post::showHighlightedUrl(QString url)
     }
     else
     {
-        this->pController->showTransientMessage("");
+        this->pController->showTransientMessage(QString());
     }
 }
 
@@ -2278,7 +2277,7 @@ void Post::keyPressEvent(QKeyEvent *event)
  */
 void Post::leaveEvent(QEvent *event)
 {
-    this->pController->showTransientMessage("");
+    this->pController->showTransientMessage(QString());
 
     event->accept();
 }
