@@ -129,7 +129,7 @@ signals:
 
 public slots:
     void likePost(bool like);
-    void fixLikeButton(QString state);
+    void fixLikeButton(bool isLiked);
     void getAllLikes();
 
     void commentOnPost();
