@@ -54,11 +54,15 @@ public:
                         QString hometown, QString bio,
                         QString eMail);
 
+    void setAvatar(QString filename);
+
     void toggleWidgetsEnabled(bool state);
 
 signals:
 
+
 public slots:
+    void redrawAvatar(QString avatarUrl, QString avatarFilename);
     void findAvatarFile();
     void saveProfile();
     void sendProfileData(QString newImageUrl = QString());
@@ -70,38 +74,39 @@ protected:
 
 
 private:
-    PumpController *pController;
+    QVBoxLayout *m_mainLayout;
+    QFormLayout *m_topLayout;
+    QHBoxLayout *m_emailLayout;
+    QHBoxLayout *m_avatarLayout;
+    QHBoxLayout *m_bottomLayout;
 
+    QLabel *m_webfingerLabel;
 
-    QVBoxLayout *mainLayout;
-    QFormLayout *topLayout;
-    QHBoxLayout *emailLayout;
-    QHBoxLayout *avatarLayout;
-    QHBoxLayout *bottomLayout;
+    QLabel *m_emailLabel;
+    QPushButton *m_changeEmailButton;
+    EmailChanger *m_emailChanger;
 
-    QLabel *avatarLabel;
-    QPushButton *changeAvatarButton;
-    bool avatarChanged;
+    QLabel *m_avatarLabel;
+    QPushButton *m_changeAvatarButton;
+    bool m_avatarHasChanged;
 
-    QLabel *webfingerLabel;
-    QLabel *emailLabel;
-    QPushButton *changeEmailButton;
-    EmailChanger *emailChanger;
+    QLineEdit *m_fullNameLineEdit;
+    QLineEdit *m_hometownLineEdit;
+    QTextEdit *m_bioTextEdit;
 
-    QLineEdit *fullNameLineEdit;
-    QLineEdit *hometownLineEdit;
-    QTextEdit *bioTextEdit;
+    QLabel *m_newAvatarInfoLabel;
 
-    QLabel *newAvatarInfoLabel;
+    QPushButton *m_saveButton;
+    QPushButton *m_cancelButton;
 
-    QPushButton *saveButton;
-    QPushButton *cancelButton;
+    QAction *m_cancelAction;
 
-    QAction *cancelAction;
+    QString m_currentAvatarUrl;
+    QString m_oldAvatarFilename;
+    QString m_newAvatarFilename;
+    QString m_newAvatarContentType;
 
-    QString currentAvatarURL;
-    QString newAvatarFilename;
-    QString newAvatarContentType;
+    PumpController *m_pumpController;
 };
 
 #endif // PROFILEEDITOR_H
