@@ -56,22 +56,22 @@ public slots:
     void saveSettings();
 
 private:
-    QVBoxLayout *mainLayout;
-    QFormLayout *fieldsLayout;
-    QHBoxLayout *buttonsLayout;
+    QVBoxLayout *m_mainLayout;
+    QFormLayout *m_fieldsLayout;
+    QHBoxLayout *m_buttonsLayout;
 
-    QComboBox *proxyTypeComboBox;
-    QLineEdit *hostnameLineEdit;
-    QLineEdit *portLineEdit;
-    QCheckBox *authCheckBox;
-    QLineEdit *userLineEdit;
-    QLineEdit *passwordLineEdit;
-    QLabel *passwordNoteLabel;
+    QComboBox *m_proxyTypeComboBox;
+    QLineEdit *m_hostnameLineEdit;
+    QLineEdit *m_portLineEdit;
+    QCheckBox *m_authCheckBox;
+    QLineEdit *m_userLineEdit;
+    QLineEdit *m_passwordLineEdit;
+    QLabel *m_passwordNoteLabel;
 
-    QPushButton *saveButton;
-    QPushButton *cancelButton;
+    QPushButton *m_saveButton;
+    QPushButton *m_cancelButton;
 
-    QAction *closeAction;
+    QAction *m_closeAction;
 };
 
 #endif // PROXYDIALOG_H
