@@ -145,10 +145,10 @@ public:
     QString currentUserId();
     QString currentUsername();
     QString currentServerScheme();
-    QString currentServerUrl();
+    QString currentServerDomain();
     QString currentFollowersUrl();
-    int currentFollowersCount();
     int currentFollowingCount();
+    int currentFollowersCount();
     bool currentlyAuthorized();
 
     void getUserProfile(QString userId);
@@ -204,7 +204,6 @@ public:
     QNetworkReply *uploadFile(QString filename, QString contentType,
                               requestTypes uploadType = UploadFileRequest);
 
-    QList<QVariantList> processAudience(QMap<QString,QString> audienceMap);
 
     bool urlIsInOurHost(QString url);
     void addCommentUrlToSeenList(QString id, QString url);
@@ -322,10 +321,10 @@ public slots:
     void getInitialData();
 
 
-    void postNote(QMap<QString,QString> audienceMap,
+    void postNote(QVariantMap audienceMap,
                   QString postText,
                   QString postTitle);
-    QNetworkReply *postMedia(QMap<QString,QString> audienceMap,
+    QNetworkReply *postMedia(QVariantMap audienceMap,
                              QString postText, QString postTitle,
                              QString mediaFilename, QString mediaType,
                              QString mimeContentType);
@@ -352,83 +351,85 @@ public slots:
 
 
 private:
-    QNetworkAccessManager nam;
-    QByteArray userAgentString;
+    QNetworkAccessManager m_nam;
+    QByteArray m_userAgentString;
 
     // QOAuth-related
-    QOAuth::Interface *qoauth;
+    QOAuth::Interface *m_qoauth;
 
-    bool isApplicationAuthorized;
+    bool m_applicationAuthorized;
 
-    QString clientID;
-    QString clientSecret;
-
-    QByteArray token;
-    QByteArray tokenSecret;
+    QString m_clientId;
+    QString m_clientSecret;
+    QByteArray m_token;
+    QByteArray m_tokenSecret;
 
 
-    QString userId;  // Full webfinger address, user@host.tld
-    QString userName;
-    QString serverURL;
-    QString apiBaseUrl;
-    QString apiFeedUrl;
-    QString serverScheme;
+    QString m_userId;  // Full Webfinger address, user@host.tld
+    QString m_userName;
+    QString m_serverDomain;
+    QString m_apiBaseUrl;
+    QString m_apiFeedUrl;
+    QString m_serverScheme;
 
-    bool proxyUsesAuth;
+    bool m_proxyUsesAuth;
 
-    QString userFollowersURL;
-    int userFollowersCount;
-    int userFollowingCount;
-    QStringList followingIdList;
-    int totalReceivedFollowers;
-    int totalReceivedFollowing;
-
-    QVariantMap postsEverSeen;
-
-    QTimer *initialDataTimer;
-    int initialDataStep;
-    int initialDataAttempts;
-    bool haveProfile;
-    bool haveFollowing;
-    bool haveFollowers;
-    bool havePersonLists;
-    bool haveMainTL;
-    bool haveDirectTL;
-    bool haveActivityTL;
-    bool haveFavoritesTL;
-    bool haveMainMF;
-    bool haveDirectMF;
-    bool haveActivityMF;
+    QString m_userFollowersUrl;
+    int m_userFollowingCount;
+    int m_userFollowersCount;
+    QStringList m_followingIdList;
+    int m_totalReceivedFollowing;
+    int m_totalReceivedFollowers;
 
 
-    int postsPerPageMain;
-    int postsPerPageOther;
+    QVariantMap m_postsEverSeen;
+
+
+    QTimer *m_initialDataTimer;
+    int m_initialDataStep;
+    int m_initialDataAttempts;
+    bool m_haveProfile;
+    bool m_haveFollowing;
+    bool m_haveFollowers;
+    bool m_havePersonLists;
+    bool m_haveMainTL;
+    bool m_haveDirectTL;
+    bool m_haveActivityTL;
+    bool m_haveFavoritesTL;
+    bool m_haveMainMF;
+    bool m_haveDirectMF;
+    bool m_haveActivityMF;
 
 
     // For multi-step operations in posts
-    QString currentPostTitle;
-    QString currentPostDescription;
-    QMap<QString, QString> currentAudienceMap;
-    QString currentPostType;
+    QString m_currentPostTitle;
+    QString m_currentPostDescription;
+    QVariantMap m_currentPostAudience;
+    QString m_currentPostType;
 
 
     // For multi-step verify+follow operations
-    QNetworkReply *addressCheckReply;
-    QTimer *addressCheckTimer;
-    bool addressCheckTimedOut;
-    QString addressPendingToFollow;
+    QNetworkReply *m_webfingerCheckReply;
+    QTimer *m_webfingerCheckTimer;
+    bool m_webfingerCheckTimedOut;
+    QString m_addressPendingToFollow;
 
 
     // Avatars / Images queue
-    QStringList pendingAvatarsList;
-    QStringList pendingImagesList;
+    QStringList m_pendingAvatarsList;
+    QStringList m_pendingImagesList;
 
-    bool ignoreSslErrors;
-    bool ignoreSslInImages;
 
-    bool silentFollows;
-    bool silentListsHandling;
-    bool silentLikes;
+    // Settings stuff
+    int m_postsPerPageMain;  // FIXME: get rid of these, query globalObject
+    int m_postsPerPageOther;
+
+    bool m_ignoreSslErrors;
+    bool m_ignoreSslInImages;
+
+    bool m_silentFollows;
+    bool m_silentListsHandling;
+    bool m_silentLikes;
 };
 
 #endif // PUMPCONTROLLER_H
