@@ -52,6 +52,8 @@ public:
              QWidget *parent = 0);
     ~TimeLine();
 
+    void createKeyboardActions();
+
     void setCustomUrl(QString url);
 
     void clearTimeLineContents(bool showMessage=true);
@@ -61,7 +63,6 @@ public:
     int getCurrentPage();
     int getTotalPages();
     int getTotalPosts();
-    QString getCurrentPageAndTotalString() const;
     void updateCurrentPageNumber();
     void syncPostsPerPage();
     void enablePaginationButtons();
@@ -78,7 +79,7 @@ public:
 
     QList<Post *> getPostsInTimeline();
 
-    QFrame *getSeparatorFrame();
+    QFrame *getSeparatorWidget();
 
     void showMessage(QString message);
 
@@ -118,8 +119,8 @@ public slots:
     void setPostsDeletedFromMinorFeed(ASObject *object);
 
 
-    void setLikesInPost(QVariantList likesList, QString originatingPostURL);
-    void setCommentsInPost(QVariantList commentsList, QString originatingPostURL);
+    void setLikesInPost(QVariantList likesList, QString originatingPostUrl);
+    void setCommentsInPost(QVariantList commentsList, QString originatingPostUrl);
     //void setSharesInPost(...)
 
     void goToFirstPage();
@@ -146,64 +147,66 @@ protected:
 
 
 private:
-    QVBoxLayout *mainLayout;
-    QVBoxLayout *postsLayout;
-    QHBoxLayout *bottomLayout;
+    QVBoxLayout *m_mainLayout;
+    QVBoxLayout *m_postsLayout;
+    QHBoxLayout *m_bottomLayout;
 
-    PumpController *pController;
-    GlobalObject *globalObj;
-    FilterChecker *fChecker;
+    QPushButton *m_getNewPendingButton;
+    QLabel *m_infoLabel;
+
+    QWidget *m_postsWidget;
+    QFrame *m_separatorFrame;
+
+    QPushButton *m_firstPageButton;
+    QPushButton *m_previousPageButton;
+    QPushButton *m_currentPageButton;
+    QPushButton *m_nextPageButton;
 
 
-    QPushButton *getNewPendingButton;
-    QLabel *infoLabel;
+    QString m_customUrl;
+    QString m_previousPageLink;
+    QString m_nextPageLink;
+    int m_fullTimelinePostCount;
+    int m_postsPendingForNextTime;
+    bool m_firstLoad;
+    bool m_gettingNew;
+    bool m_wasOnFirstPage;
 
-    QWidget *postsWidget;
-    QFrame *separatorFrame;
-
-    QPushButton *firstPageButton;
-    QPushButton *currentPageButton;
-    QPushButton *previousPageButton;
-    QPushButton *nextPageButton;
+    int m_timelineOffset;
+    int m_oldTimelineOffset;
+    int m_postsPerPage;
+    int m_unreadPostsCount;
+    int m_highlightedPostsCount;
+    QString m_currentPageTotalString;
 
 
-    QString customUrl;
-    QString previousPageLink;
-    QString nextPageLink;
-    int fullTimelinePostCount;
-    int pendingToReceiveNextTime;
-    bool firstLoad;
-    bool gettingNew;
-    bool wasOnFirstPage;
-
-    int timelineOffset;
-    int oldTimelineOffset;
-    int postsPerPage;
-    int unreadPostsCount;
-    int highlightedPostsCount;
-    QString currentPageTotalString;
-
-    QAction *scrollUpAction;
-    QAction *scrollDownAction;
-    QAction *scrollPageUpAction;
-    QAction *scrollPageDownAction;
-    QAction *scrollTopAction;
-    QAction *scrollBottomAction;
-
-    QAction *previousPageAction;
-    QAction *nextPageAction;
-    QAction *showPageSelectorAction;
-
-    PageSelector *pageSelector;
-
-    PumpController::requestTypes timelineType;
-    bool favoritesTimeline;
+    // QActions to enhance keyboard control
+    QAction *m_scrollUpAction;
+    QAction *m_scrollDownAction;
+    QAction *m_scrollPageUpAction;
+    QAction *m_scrollPageDownAction;
+    QAction *m_scrollTopAction;
+    QAction *m_scrollBottomAction;
+    QAction *m_previousPageAction;
+    QAction *m_nextPageAction;
+    QAction *m_showPageSelectorAction;
 
 
-    QString previousNewestPostId;
+    PageSelector *m_pageSelector;
 
-    QList<Post *> postsInTimeline;
-    QStringList objectsIdList;
+
+    PumpController::requestTypes m_timelineType;
+    bool m_isFavoritesTimeline;
+
+    QString m_previousNewestPostId;
+
+    QList<Post *> m_postsInTimeline;
+    QStringList m_objectsIdList;
+
+
+    PumpController *m_pumpController;
+    GlobalObject *m_globalObject;
+    FilterChecker *m_filterChecker;
 };
 
 #endif // TIMELINE_H
