@@ -28,16 +28,16 @@ UserPosts::UserPosts(QString userId, QString userName,
                      FilterChecker *filterChecker,
                      QWidget *parent) : QWidget(parent)
 {
-    this->pController = pumpController;
-    this->globalObj = globalObject;
-    connect(globalObj, &GlobalObject::programShuttingDown,
+    m_pumpController = pumpController;
+    m_globalObject = globalObject;
+    connect(m_globalObject, &GlobalObject::programShuttingDown,
             this, &QWidget::close);
 
     this->setWindowFlags(Qt::Window);
     this->setWindowModality(Qt::NonModal);
 
-    this->timelineTitle = tr("Posts by %1").arg(userName);
-    this->setWindowTitle(timelineTitle + " - Dianara");
+    m_timelineTitle = tr("Posts by %1").arg(userName);
+    this->setWindowTitle(m_timelineTitle + " - Dianara");
     this->setWindowIcon(userAvatar);
     this->setMinimumSize(200, 300);
 
@@ -45,70 +45,72 @@ UserPosts::UserPosts(QString userId, QString userName,
     this->resize(settings.value("UserTimeline/userTimelineSize",
                                 QSize(560, 720)).toSize());
 
-    timeline = new TimeLine(PumpController::UserTimelineRequest,
-                            this->pController,
-                            this->globalObj,
-                            filterChecker,
-                            this);
+    m_timeline = new TimeLine(PumpController::UserTimelineRequest,
+                              m_pumpController,
+                              m_globalObject,
+                              filterChecker,
+                              this);
 
-    this->scrollArea = new QScrollArea(this);
-    this->scrollArea->setContentsMargins(1, 1, 1, 1);
-    this->scrollArea->setWidget(timeline);
-    this->scrollArea->setWidgetResizable(true);
-    this->scrollArea->setFrameStyle(QFrame::Box | QFrame::Raised);
-    this->scrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
-    connect(timeline, &TimeLine::scrollTo,
+    m_scrollArea = new QScrollArea(this);
+    m_scrollArea->setContentsMargins(1, 1, 1, 1);
+    m_scrollArea->setWidget(m_timeline);
+    m_scrollArea->setWidgetResizable(true);
+    m_scrollArea->setFrameStyle(QFrame::Box | QFrame::Raised);
+    m_scrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
+    connect(m_timeline, &TimeLine::scrollTo,
             this, &UserPosts::scrollTimelineTo);
 
 
-    this->infoLabel = new QLabel(tr("Loading..."), this);
-    this->closeButton = new QPushButton(QIcon::fromTheme("window-close",
-                                                         QIcon(":/images/button-close.png")),
-                                        tr("&Close"),
-                                        this);
-    connect(closeButton, &QAbstractButton::clicked,
+    m_infoLabel = new QLabel(tr("Loading..."), this);
+    m_infoLabel->setTextFormat(Qt::RichText);
+
+    m_closeButton = new QPushButton(QIcon::fromTheme("window-close",
+                                                     QIcon(":/images/button-close.png")),
+                                    tr("&Close"),
+                                    this);
+    connect(m_closeButton, &QAbstractButton::clicked,
             this, &QWidget::close);
 
     // PumpController's connections
-    connect(pController, &PumpController::userTimelineReceived,
+    connect(m_pumpController, &PumpController::userTimelineReceived,
             this, &UserPosts::fillTimeLine);
-    connect(pController, &PumpController::userTimelineFailed,
+    connect(m_pumpController, &PumpController::userTimelineFailed,
             this, &UserPosts::onTimelineFailed);
-    connect(pController, &PumpController::commentsReceived,
-            timeline, &TimeLine::setCommentsInPost);
+    connect(m_pumpController, &PumpController::commentsReceived,
+            m_timeline, &TimeLine::setCommentsInPost);
 
-    connect(timeline, &TimeLine::timelineRendered,
+    connect(m_timeline, &TimeLine::timelineRendered,
             this, &UserPosts::notifyTimelineUpdate);
 
     // Initial load
-    this->timeline->setCustomUrl(userOutbox);
-    this->timeline->setDisabled(true);
-    this->timeline->clearTimeLineContents(); // Hack to get comments properly resized
+    m_timeline->setCustomUrl(userOutbox);
+    m_timeline->setDisabled(true);
+    m_timeline->clearTimeLineContents(); // Hack to get comments properly resized
     // FIXME: On first load, should set showMessage=false so initial "Requesting..." is not erased
     // Not doing that for 1.3.1 due to problems
 
-    pController->getFeed(PumpController::UserTimelineRequest,
-                         this->globalObj->getPostsPerPageMain(),
-                         userOutbox);
+    m_pumpController->getFeed(PumpController::UserTimelineRequest,
+                              m_globalObject->getPostsPerPageMain(),
+                              userOutbox);
 
 
 
-    // String shown at the bottom
-    userInfoString = userName + " - " + userId; // kinda TMP -- FIXME
+    // First part of message shown at the bottom
+    m_userInfoString = userName + " - " + userId;
 
 
     // Layout
-    this->bottomLayout = new QHBoxLayout();
-    bottomLayout->addWidget(infoLabel);
-    bottomLayout->addStretch(1);
-    bottomLayout->addWidget(closeButton);
+    m_bottomLayout = new QHBoxLayout();
+    m_bottomLayout->addWidget(m_infoLabel);
+    m_bottomLayout->addStretch(1);
+    m_bottomLayout->addWidget(m_closeButton);
 
-    this->mainLayout = new QVBoxLayout();
-    mainLayout->setContentsMargins(2, 2, 2, 2);
-    mainLayout->addWidget(scrollArea);
-    mainLayout->addSpacing(6);
-    mainLayout->addLayout(bottomLayout);
-    this->setLayout(mainLayout);
+    m_mainLayout = new QVBoxLayout();
+    m_mainLayout->setContentsMargins(2, 2, 2, 2);
+    m_mainLayout->addWidget(m_scrollArea);
+    m_mainLayout->addSpacing(6);
+    m_mainLayout->addLayout(m_bottomLayout);
+    this->setLayout(m_mainLayout);
 
     qDebug() << "UserPosts timeline container created for" << userName;
 }
@@ -132,15 +134,15 @@ UserPosts::~UserPosts()
 void UserPosts::fillTimeLine(QVariantList postList, QString previousLink,
                              QString nextLink, int totalItems, QString url)
 {
-    if (this->timelineUrl.isEmpty()) // Set it the first time
+    if (m_timelineUrl.isEmpty()) // Set it the first time
     {
-        this->timelineUrl = url;
+        m_timelineUrl = url;
     }
 
-    if (url == this->timelineUrl)
+    if (url == m_timelineUrl)
     {
-        this->timeline->setTimeLineContents(postList, previousLink,
-                                            nextLink, totalItems);
+        m_timeline->setTimeLineContents(postList, previousLink,
+                                        nextLink, totalItems);
     }
 }
 
@@ -148,31 +150,32 @@ void UserPosts::fillTimeLine(QVariantList postList, QString previousLink,
 
 void UserPosts::notifyTimelineUpdate()
 {
-    QString message = tr("Received '%1'.").arg(this->timelineTitle);
-    this->globalObj->setStatusMessage(message);
-    this->globalObj->logMessage(message);
+    const QString message = tr("Received '%1'.").arg(m_timelineTitle);
+    m_globalObject->setStatusMessage(message);
+    m_globalObject->logMessage(message);
 
-    QString postCount = QLocale::system().toString(timeline->getTotalPosts());
-    this->infoLabel->setText(this->userInfoString
-                             + " - "
-                             + tr("%1 posts").arg(postCount));
+    QString postCount = QLocale::system().toString(m_timeline->getTotalPosts());
+    m_infoLabel->setText(m_userInfoString
+                         + " &mdash; " //// Long dash
+                         + tr("%1 posts").arg(postCount));
 
-    this->timeline->resizePosts(QList<Post *>(), true); // resize all posts
+    m_timeline->resizePosts(QList<Post *>(), true); // Resize all posts
 }
 
+
 // Set error messages if timeline fails to load
 void UserPosts::onTimelineFailed()
 {
-    QString message = tr("Error loading the timeline");
-    this->infoLabel->setText(message + ".");
-    this->timeline->showMessage(message);
+    const QString message = tr("Error loading the timeline");
+    m_infoLabel->setText(message + ".");
+    m_timeline->showMessage(message);
 }
 
 
 // React to Control+PgUp/PgDn, etc. sent from TimeLine()
 void UserPosts::scrollTimelineTo(QAbstractSlider::SliderAction sliderAction)
 {
-    this->scrollArea->verticalScrollBar()->triggerAction(sliderAction);
+    m_scrollArea->verticalScrollBar()->triggerAction(sliderAction);
 }
 
 
@@ -183,7 +186,7 @@ void UserPosts::scrollTimelineTo(QAbstractSlider::SliderAction sliderAction)
 
 void UserPosts::resizeEvent(QResizeEvent *event)
 {
-    this->timeline->resizePosts(QList<Post *>(), true); // resizeAll=true
+    m_timeline->resizePosts(QList<Post *>(), true); // resizeAll=true
 
     event->accept();
 }
@@ -198,7 +201,7 @@ void UserPosts::closeEvent(QCloseEvent *event)
                           this->size());
     }
 
-    delete this->timeline;
+    delete m_timeline;
     this->deleteLater();
 
     this->hide();
@@ -210,7 +213,7 @@ void UserPosts::keyPressEvent(QKeyEvent *event)
 {
     // ESC to close, if there are no comments in progress
     if (event->key() == Qt::Key_Escape
-     && !this->timeline->commentingOnAnyPost())
+     && !m_timeline->commentingOnAnyPost())
     {
         event->accept();
         this->close();
