@@ -69,21 +69,21 @@ protected:
 
 
 private:
-    QVBoxLayout *mainLayout;
-    QHBoxLayout *bottomLayout;
+    QVBoxLayout *m_mainLayout;
+    QHBoxLayout *m_bottomLayout;
 
-    QScrollArea *scrollArea;
-    TimeLine *timeline;
+    QScrollArea *m_scrollArea;
+    TimeLine *m_timeline;
 
-    QLabel *infoLabel;
-    QPushButton *closeButton;
+    QLabel *m_infoLabel;
+    QPushButton *m_closeButton;
 
-    QString timelineTitle;
-    QString timelineUrl;
-    QString userInfoString;
+    QString m_timelineTitle;
+    QString m_timelineUrl;
+    QString m_userInfoString;
 
-    PumpController *pController;
-    GlobalObject *globalObj;
+    PumpController *m_pumpController;
+    GlobalObject *m_globalObject;
 };
 
 #endif // USERPOSTS_H
